@@ -17,16 +17,16 @@ module RuboCop
         MSG = 'Do not specify cop behavior using `described_class::MSG`.'.freeze
 
         def_node_search :described_class_msg, <<-PATTERN
-          (const (send nil :described_class) :MSG)
+          (const (send nil? :described_class) :MSG)
         PATTERN
 
         def_node_matcher :rspec_expectation_on_msg?, <<-PATTERN
-          (send (send nil :expect #contains_described_class_msg?) :to ...)
+          (send (send nil? :expect #contains_described_class_msg?) :to ...)
         PATTERN
 
         def investigate(_processed_source)
           assertions_using_described_class_msg.each do |node|
-            add_offense(node, :expression)
+            add_offense(node)
           end
         end
 
