@@ -8,20 +8,20 @@ module RuboCop
       #
       # @example
       #   # bad
-      #   a = [1, 2, 3
+      #   a = [1, 2, 3,
       #     4, 5, 6]
       #   array = ['run',
       #        'forrest',
       #        'run']
       #
       #   # good
-      #   a = [1, 2, 3
+      #   a = [1, 2, 3,
       #        4, 5, 6]
       #   a = ['run',
       #        'forrest',
       #        'run']
       class AlignArray < Cop
-        include AutocorrectAlignment
+        include Alignment
 
         MSG = 'Align the elements of an array literal if they span more ' \
               'than one line.'.freeze
@@ -29,6 +29,10 @@ module RuboCop
         def on_array(node)
           check_alignment(node.children)
         end
+
+        def autocorrect(node)
+          AlignmentCorrector.correct(processed_source, node, column_delta)
+        end
       end
     end
   end
