@@ -25,7 +25,8 @@ module RuboCop
       #     foo(i)
       #   }
       class BlockEndNewline < Cop
-        MSG = 'Expression at %d, %d should be on its own line.'.freeze
+        MSG = 'Expression at %<line>d, %<column>d should be on its own line.'
+              .freeze
 
         def on_block(node)
           return if node.single_line?
@@ -35,26 +36,39 @@ module RuboCop
           # If the end is on its own line, there is no offense
           return if end_loc.source_line =~ /^\s*#{end_loc.source}/
 
-          add_offense(node, end_loc)
+          add_offense(node, location: end_loc)
         end
 
-        private
-
         def autocorrect(node)
           lambda do |corrector|
             indentation = indentation_of_block_start_line(node)
-            corrector.insert_before(node.loc.end, "\n" + (' ' * indentation))
+            new_block_end = "\n" + node.loc.end.source + (' ' * indentation)
+            corrector.replace(delimiter_range(node), new_block_end)
           end
         end
 
+        private
+
         def message(node)
-          format(MSG, node.loc.end.line, node.loc.end.column + 1)
+          format(MSG, line: node.loc.end.line, column: node.loc.end.column + 1)
         end
 
         def indentation_of_block_start_line(node)
           match = /\S.*/.match(node.loc.begin.source_line)
           match.begin(0)
         end
+
+        def delimiter_range(node)
+          Parser::Source::Range.new(
+            node.loc.end.source_buffer,
+            index_of_delimiter_with_whitespaces(node),
+            node.source.length
+          )
+        end
+
+        def index_of_delimiter_with_whitespaces(node)
+          node.source =~ /\s*#{node.closing_delimiter}/
+        end
       end
     end
   end
