@@ -10,24 +10,28 @@ module RuboCop
       #   # good
       #
       #   def foo
-      #     ...
+      #     # ...
       #   end
       #
       #   # bad
       #
       #   def bar
       #
-      #     ...
+      #     # ...
       #
       #   end
       class EmptyLinesAroundMethodBody < Cop
         include EmptyLinesAroundBody
-        include OnMethodDef
 
         KIND = 'method'.freeze
 
-        def on_method_def(node, _method_name, _args, body)
-          check(node, body)
+        def on_def(node)
+          check(node, node.body)
+        end
+        alias on_defs on_def
+
+        def autocorrect(node)
+          EmptyLineCorrector.correct(node)
         end
 
         private
