@@ -27,14 +27,18 @@ module RuboCop
       #       do_something
       #     end
       class FirstMethodParameterLineBreak < Cop
-        include OnMethodDef
         include FirstElementLineBreak
 
         MSG = 'Add a line break before the first parameter of a ' \
               'multi-line method parameter list.'.freeze
 
-        def on_method_def(node, _method_name, args, _body)
-          check_method_line_break(node, args.to_a)
+        def on_def(node)
+          check_method_line_break(node, node.arguments)
+        end
+        alias on_defs on_def
+
+        def autocorrect(node)
+          EmptyLineCorrector.insert_before(node)
         end
       end
     end
