@@ -23,7 +23,7 @@ module RuboCop
       # other cops such as `IndentationConsistency` and `EndAlignment`.
       class IndentAssignment < Cop
         include CheckAssignment
-        include AutocorrectAlignment
+        include Alignment
 
         MSG = 'Indent the first line of the right-hand-side of a ' \
               'multi-line assignment.'.freeze
@@ -31,11 +31,15 @@ module RuboCop
         def check_assignment(node, rhs)
           return unless rhs
           return unless node.loc.operator
-          return if node.loc.operator.line == rhs.loc.line
+          return if node.loc.operator.line == rhs.first_line
 
           base = display_column(node.source_range)
           check_alignment([rhs], base + configured_indentation_width)
         end
+
+        def autocorrect(node)
+          AlignmentCorrector.correct(processed_source, node, column_delta)
+        end
       end
     end
   end
