@@ -14,8 +14,7 @@ module RuboCop
       #     end
       #   end
       class IndentationConsistency < Cop
-        include AutocorrectAlignment
-        include AccessModifierNode
+        include Alignment
         include ConfigurableEnforcedStyle
 
         MSG = 'Inconsistent indentation detected.'.freeze
@@ -28,6 +27,10 @@ module RuboCop
           check(node)
         end
 
+        def autocorrect(node)
+          AlignmentCorrector.correct(processed_source, node, column_delta)
+        end
+
         private
 
         def check(node)
@@ -37,7 +40,7 @@ module RuboCop
             # the AccessModifierIndentation cop. This cop uses them as dividers
             # in rails mode. Then consistency is checked only within each
             # section delimited by a modifier node.
-            if modifier_node?(child)
+            if child.send_type? && child.access_modifier?
               children_to_check << [] if style == :rails
             else
               children_to_check.last << child
