@@ -6,6 +6,13 @@ module RuboCop
       # Checks for colon (:) not followed by some kind of space.
       # N.B. this cop does not handle spaces after a ternary operator, which are
       # instead handled by Layout/SpaceAroundOperators.
+      #
+      # @example
+      #   # bad
+      #   def f(a:, b:2); {a:3}; end
+      #
+      #   # good
+      #   def f(a:, b: 2); {a: 3}; end
       class SpaceAfterColon < Cop
         MSG = 'Space missing after colon.'.freeze
 
@@ -14,7 +21,7 @@ module RuboCop
 
           colon = node.loc.operator
 
-          add_offense(colon, colon) unless followed_by_space?(colon)
+          add_offense(colon, location: colon) unless followed_by_space?(colon)
         end
 
         def on_kwoptarg(node)
@@ -22,7 +29,11 @@ module RuboCop
           # optional keyword argument's name, so must construct one.
           colon = node.loc.name.end.resize(1)
 
-          add_offense(colon, colon) unless followed_by_space?(colon)
+          add_offense(colon, location: colon) unless followed_by_space?(colon)
+        end
+
+        def autocorrect(range)
+          ->(corrector) { corrector.insert_after(range, ' ') }
         end
 
         private
@@ -30,10 +41,6 @@ module RuboCop
         def followed_by_space?(colon)
           colon.source_buffer.source[colon.end_pos] =~ /\s/
         end
-
-        def autocorrect(range)
-          ->(corrector) { corrector.insert_after(range, ' ') }
-        end
       end
     end
   end
