@@ -28,21 +28,6 @@ module RuboCop
           check(node)
         end
 
-        private
-
-        def check(node)
-          expression = node.source
-          op = node.loc.operator.source
-          escaped_op = op.gsub(/\./, '\.')
-
-          # account for multiline range literals
-          expression.sub!(/#{escaped_op}\n\s*/, op)
-
-          return unless expression =~ /(\s#{escaped_op})|(#{escaped_op}\s)/
-
-          add_offense(node, :expression)
-        end
-
         def autocorrect(node)
           expression = node.source
           operator = node.loc.operator.source
@@ -57,6 +42,21 @@ module RuboCop
             )
           end
         end
+
+        private
+
+        def check(node)
+          expression = node.source
+          op = node.loc.operator.source
+          escaped_op = op.gsub(/\./, '\.')
+
+          # account for multiline range literals
+          expression.sub!(/#{escaped_op}\n\s*/, op)
+
+          return unless expression =~ /(\s#{escaped_op})|(#{escaped_op}\s)/
+
+          add_offense(node)
+        end
       end
     end
   end
