@@ -12,7 +12,7 @@ module RuboCop
       #   # bad
       #
       #   if something
-      #     ...
+      #     # ...
       #   else do_this
       #     do_that
       #   end
@@ -22,7 +22,7 @@ module RuboCop
       #   # good
       #
       #   if something
-      #     ...
+      #     # ...
       #   else
       #     do_this
       #     do_that
@@ -57,7 +57,7 @@ module RuboCop
 
           return unless first_else.source_range.line == node.loc.else.line
 
-          add_offense(first_else, :expression)
+          add_offense(first_else)
         end
       end
     end
