@@ -21,7 +21,7 @@ module RuboCop
 
         def on_dstr(node)
           node.each_child_node(:begin) do |begin_node|
-            add_offense(begin_node, :expression) if begin_node.children.empty?
+            add_offense(begin_node) if begin_node.children.empty?
           end
         end
 
