@@ -10,12 +10,19 @@ module RuboCop
         SHEBANG = '#!'.freeze
 
         def investigate(processed_source)
+          return if @options.key?(:stdin)
           return if Platform.windows?
           return unless start_with_shebang?(processed_source)
           return if executable?(processed_source)
           comment = processed_source.comments[0]
           message = format_message_from(processed_source)
-          add_offense(comment, :expression, message)
+          add_offense(comment, message: message)
+        end
+
+        def autocorrect(node)
+          lambda do |_corrector|
+            FileUtils.chmod('+x', node.loc.expression.source_buffer.name)
+          end
         end
 
         private
