@@ -29,16 +29,10 @@ module RuboCop
             next unless final_node && final_node.send_type? &&
                         final_node.method?(:to_s) && !final_node.arguments?
 
-            add_offense(final_node, :selector)
+            add_offense(final_node, location: :selector)
           end
         end
 
-        private
-
-        def message(node)
-          node.receiver ? MSG_DEFAULT : MSG_SELF
-        end
-
         def autocorrect(node)
           lambda do |corrector|
             receiver, _method_name, *_args = *node
@@ -52,6 +46,12 @@ module RuboCop
             )
           end
         end
+
+        private
+
+        def message(node)
+          node.receiver ? MSG_DEFAULT : MSG_SELF
+        end
       end
     end
   end
