@@ -16,7 +16,9 @@ module RuboCop
         private
 
         def message(length, max_length)
-          format('Module has too many lines. [%d/%d]', length, max_length)
+          format('Module has too many lines. [%<length>d/%<max>d]',
+                 length: length,
+                 max: max_length)
         end
       end
     end
