@@ -6,6 +6,8 @@ module RuboCop
     module CodeLength
       include ConfigurableMax
 
+      private
+
       def max_length
         cop_config['Max']
       end
@@ -18,7 +20,7 @@ module RuboCop
         length = code_length(node)
         return unless length > max_length
 
-        add_offense(node, :expression, message(length, max_length)) do
+        add_offense(node, message: message(length, max_length)) do
           self.max = length
         end
       end
