@@ -7,10 +7,10 @@ module RuboCop
       extend NodePattern::Macros
       include Style::AnnotationComment
 
-      def_node_matcher :constant_definition?, '{class module casgn}'
-
       private
 
+      def_node_matcher :constant_definition?, '{class module casgn}'
+
       def documentation_comment?(node)
         preceding_lines = preceding_lines(node)
 
@@ -24,7 +24,7 @@ module RuboCop
       end
 
       def preceding_comment?(n1, n2)
-        n1 && n2 && preceed?(n2, n1) &&
+        n1 && n2 && precede?(n2, n1) &&
           comment_line?(n2.loc.expression.source)
       end
 
