@@ -6,15 +6,14 @@ module RuboCop
       # This cop checks for consistent uses of `request.referer` or
       # `request.referrer`, depending on the cop's configuration.
       #
-      # @example
-      #   # EnforcedStyle: referer
+      # @example EnforcedStyle: referer (default)
       #   # bad
       #   request.referrer
       #
       #   # good
       #   request.referer
       #
-      #   # EnforcedStyle: referrer
+      # @example EnforcedStyle: referrer
       #   # bad
       #   request.referer
       #
@@ -26,14 +25,14 @@ module RuboCop
         MSG = 'Use `request.%s` instead of `request.%s`.'.freeze
 
         def_node_matcher :referer?, <<-PATTERN
-          (send (send nil :request) {:referer :referrer})
+          (send (send nil? :request) {:referer :referrer})
         PATTERN
 
         def on_send(node)
           referer?(node) do
             return unless node.method?(wrong_method_name)
 
-            add_offense(node.source_range, node.source_range, message)
+            add_offense(node.source_range, location: node.source_range)
           end
         end
 
@@ -43,7 +42,7 @@ module RuboCop
 
         private
 
-        def message
+        def message(_node)
           format(MSG, style, wrong_method_name)
         end
 
