@@ -18,13 +18,13 @@ module RuboCop
       class YAMLLoad < Cop
         MSG = 'Prefer using `YAML.safe_load` over `YAML.load`.'.freeze
 
-        def_node_matcher :yaml_load, <<-END
-          (send (const {nil cbase} :YAML) :load ...)
-        END
+        def_node_matcher :yaml_load, <<-PATTERN
+          (send (const {nil? cbase} :YAML) :load ...)
+        PATTERN
 
         def on_send(node)
           yaml_load(node) do
-            add_offense(node, :selector)
+            add_offense(node, location: :selector)
           end
         end
 
