@@ -12,7 +12,7 @@ module RuboCop
       class CollectionMethods < Cop
         include MethodPreference
 
-        MSG = 'Prefer `%s` over `%s`.'.freeze
+        MSG = 'Prefer `%<prefer>s` over `%<current>s`.'.freeze
 
         def on_block(node)
           check_method_node(node.send_node)
@@ -35,13 +35,15 @@ module RuboCop
         private
 
         def message(node)
-          format(MSG, preferred_method(node.method_name), node.method_name)
+          format(MSG,
+                 prefer: preferred_method(node.method_name),
+                 current: node.method_name)
         end
 
         def check_method_node(node)
           return unless preferred_methods[node.method_name]
 
-          add_offense(node, :selector)
+          add_offense(node, location: :selector)
         end
       end
     end
