@@ -6,18 +6,44 @@ module RuboCop
       # This cop checks for parentheses in the definition of a method,
       # that does not take any arguments. Both instance and
       # class/singleton methods are checked.
+      #
+      # @example
+      #
+      #   # bad
+      #   def foo()
+      #     # does a thing
+      #   end
+      #
+      #   # good
+      #   def foo
+      #     # does a thing
+      #   end
+      #
+      #   # also good
+      #   def foo() does_a_thing end
+      #
+      # @example
+      #
+      #   # bad
+      #   def Baz.foo()
+      #     # does a thing
+      #   end
+      #
+      #   # good
+      #   def Baz.foo
+      #     # does a thing
+      #   end
       class DefWithParentheses < Cop
-        include OnMethodDef
-
         MSG = "Omit the parentheses in defs when the method doesn't accept " \
               'any arguments.'.freeze
 
-        def on_method_def(node, _method_name, args, _body)
+        def on_def(node)
           return if node.single_line?
-          return unless args.children.empty? && args.loc.begin
+          return unless !node.arguments? && node.arguments.loc.begin
 
-          add_offense(args, :begin)
+          add_offense(node.arguments, location: :begin)
         end
+        alias on_defs on_def
 
         def autocorrect(node)
           lambda do |corrector|
