@@ -8,16 +8,7 @@ module RuboCop
       # This helps to keep the nesting level from getting too deep.
       #
       # @example
-      #   @good
-      #   if condition_a
-      #     action_a
-      #   elsif condition_b
-      #     action_b
-      #   else
-      #     action_c
-      #   end
-      #
-      #   @bad
+      #   # bad
       #   if condition_a
       #     action_a
       #   else
@@ -27,6 +18,15 @@ module RuboCop
       #       action_c
       #     end
       #   end
+      #
+      #   # good
+      #   if condition_a
+      #     action_a
+      #   elsif condition_b
+      #     action_b
+      #   else
+      #     action_c
+      #   end
       class IfInsideElse < Cop
         MSG = 'Convert `if` nested inside `else` to `elsif`.'.freeze
 
@@ -37,7 +37,7 @@ module RuboCop
 
           return unless else_branch && else_branch.if_type? && else_branch.if?
 
-          add_offense(else_branch, :keyword)
+          add_offense(else_branch, location: :keyword)
         end
       end
     end
