@@ -7,8 +7,6 @@ module RuboCop
       class NegatedWhile < Cop
         include NegativeConditional
 
-        MSG = 'Favor `%s` over `%s` for negative conditions.'.freeze
-
         def on_while(node)
           check_negative_conditional(node)
         end
@@ -17,14 +15,14 @@ module RuboCop
           check_negative_conditional(node)
         end
 
-        def message(node)
-          format(MSG, node.inverse_keyword, node.keyword)
+        def autocorrect(node)
+          ConditionCorrector.correct_negative_condition(node)
         end
 
         private
 
-        def autocorrect(node)
-          negative_conditional_corrector(node)
+        def message(node)
+          format(MSG, inverse: node.inverse_keyword, current: node.keyword)
         end
       end
     end
