@@ -5,15 +5,23 @@ module RuboCop
     module Style
       # This cops checks for uses of Proc.new where Kernel#proc
       # would be more appropriate.
+      #
+      # @example
+      #   # bad
+      #   p = Proc.new { |n| puts n }
+      #
+      #   # good
+      #   p = proc { |n| puts n }
+      #
       class Proc < Cop
         MSG = 'Use `proc` instead of `Proc.new`.'.freeze
 
         def_node_matcher :proc_new?,
-                         '(block $(send (const nil :Proc) :new) ...)'
+                         '(block $(send (const nil? :Proc) :new) ...)'
 
         def on_block(node)
           proc_new?(node) do |block_method|
-            add_offense(block_method, :expression)
+            add_offense(block_method)
           end
         end
 
