@@ -25,14 +25,17 @@ module RuboCop
       #     something
       #   end
       class RedundantBegin < Cop
-        include OnMethodDef
-
         MSG = 'Redundant `begin` block detected.'.freeze
 
-        def on_method_def(_node, _method_name, _args, body)
-          return unless body && body.kwbegin_type?
+        def on_def(node)
+          check(node)
+        end
+        alias on_defs on_def
 
-          add_offense(body, :begin)
+        def on_block(node)
+          return if target_ruby_version < 2.5
+          return if node.braces?
+          check(node)
         end
 
         def autocorrect(node)
@@ -41,6 +44,14 @@ module RuboCop
             corrector.remove(node.loc.end)
           end
         end
+
+        private
+
+        def check(node)
+          return unless node.body && node.body.kwbegin_type?
+
+          add_offense(node.body, location: :begin)
+        end
       end
     end
   end
