@@ -4,15 +4,26 @@ module RuboCop
   module Cop
     module Style
       # This cop checks for uses of rescue in its modifier form.
+      #
+      # @example
+      #   # bad
+      #   some_method rescue handle_error
+      #
+      #   # good
+      #   begin
+      #     some_method
+      #   rescue
+      #     handle_error
+      #   end
       class RescueModifier < Cop
-        include AutocorrectAlignment
+        include Alignment
         include RescueNode
 
         MSG = 'Avoid using `rescue` in its modifier form.'.freeze
 
         def on_resbody(node)
           return unless rescue_modifier?(node)
-          add_offense(node.parent, :expression)
+          add_offense(node.parent)
         end
 
         def autocorrect(node)
