@@ -1,17 +1,17 @@
 # frozen_string_literal: true
 
-describe RuboCop::AST::EnsureNode do
+RSpec.describe RuboCop::AST::EnsureNode do
   let(:ensure_node) { parse_source(source).ast.children.first }
 
   describe '.new' do
     let(:source) { 'begin; beginbody; ensure; ensurebody; end' }
 
-    it { expect(ensure_node).to be_a(described_class) }
+    it { expect(ensure_node.is_a?(described_class)).to be(true) }
   end
 
   describe '#body' do
     let(:source) { 'begin; beginbody; ensure; :ensurebody; end' }
 
-    it { expect(ensure_node.body).to be_sym_type }
+    it { expect(ensure_node.body.sym_type?).to be(true) }
   end
 end
