@@ -1,12 +1,12 @@
 # frozen_string_literal: true
 
-describe RuboCop::AST::ForNode do
+RSpec.describe RuboCop::AST::ForNode do
   let(:for_node) { parse_source(source).ast }
 
   describe '.new' do
     let(:source) { 'for foo in bar; baz; end' }
 
-    it { expect(for_node).to be_a(described_class) }
+    it { expect(for_node.is_a?(described_class)).to be(true) }
   end
 
   describe '#keyword' do
@@ -29,21 +29,35 @@ describe RuboCop::AST::ForNode do
     end
   end
 
+  describe '#void_context?' do
+    context 'with a do keyword' do
+      let(:source) { 'for foo in bar do baz; end' }
+
+      it { expect(for_node.void_context?).to be_truthy }
+    end
+
+    context 'without a do keyword' do
+      let(:source) { 'for foo in bar; baz; end' }
+
+      it { expect(for_node.void_context?).to be_truthy }
+    end
+  end
+
   describe '#variable' do
     let(:source) { 'for foo in :bar; :baz; end' }
 
-    it { expect(for_node.variable).to be_lvasgn_type }
+    it { expect(for_node.variable.lvasgn_type?).to be(true) }
   end
 
   describe '#collection' do
     let(:source) { 'for foo in :bar; baz; end' }
 
-    it { expect(for_node.collection).to be_sym_type }
+    it { expect(for_node.collection.sym_type?).to be(true) }
   end
 
   describe '#body' do
     let(:source) { 'for foo in bar; :baz; end' }
 
-    it { expect(for_node.body).to be_sym_type }
+    it { expect(for_node.body.sym_type?).to be(true) }
   end
 end
