@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::AST::ResbodyNode do
+RSpec.describe RuboCop::AST::ResbodyNode do
   let(:resbody_node) do
     begin_node = parse_source(source).ast
     rescue_node, = *begin_node
@@ -10,12 +10,12 @@ describe RuboCop::AST::ResbodyNode do
   describe '.new' do
     let(:source) { 'begin; beginbody; rescue; rescuebody; end' }
 
-    it { expect(resbody_node).to be_a(described_class) }
+    it { expect(resbody_node.is_a?(described_class)).to be(true) }
   end
 
   describe '#body' do
     let(:source) { 'begin; beginbody; rescue Error => ex; :rescuebody; end' }
 
-    it { expect(resbody_node.body).to be_sym_type }
+    it { expect(resbody_node.body.sym_type?).to be(true) }
   end
 end
