@@ -1,20 +1,20 @@
 # frozen_string_literal: true
 
-describe RuboCop::AST::SendNode do
+RSpec.describe RuboCop::AST::SendNode do
   let(:send_node) { parse_source(source).ast }
 
   describe '.new' do
     context 'with a regular method send' do
       let(:source) { 'foo.bar(:baz)' }
 
-      it { expect(send_node).to be_a(described_class) }
+      it { expect(send_node.is_a?(described_class)).to be(true) }
     end
 
     context 'with a safe navigation method send' do
       let(:ruby_version) { 2.3 }
       let(:source) { 'foo&.bar(:baz)' }
 
-      it { expect(send_node).to be_a(described_class) }
+      it { expect(send_node.is_a?(described_class)).to be(true) }
     end
   end
 
@@ -22,19 +22,19 @@ describe RuboCop::AST::SendNode do
     context 'with no receiver' do
       let(:source) { 'bar(:baz)' }
 
-      it { expect(send_node.receiver).to be_nil }
+      it { expect(send_node.receiver.nil?).to be(true) }
     end
 
     context 'with a literal receiver' do
       let(:source) { "'foo'.bar(:baz)" }
 
-      it { expect(send_node.receiver).to be_str_type }
+      it { expect(send_node.receiver.str_type?).to be(true) }
     end
 
     context 'with a variable receiver' do
       let(:source) { 'foo.bar(:baz)' }
 
-      it { expect(send_node.receiver).to be_send_type }
+      it { expect(send_node.receiver.send_type?).to be(true) }
     end
   end
 
@@ -94,6 +94,70 @@ describe RuboCop::AST::SendNode do
     end
   end
 
+  describe '#access_modifier?' do
+    let(:send_node) { parse_source(source).ast.children[1] }
+
+    context 'when node is a bare `module_function`' do
+      let(:source) do
+        ['module Foo',
+         '  module_function',
+         'end'].join("\n")
+      end
+
+      it { expect(send_node.access_modifier?).to be_truthy }
+    end
+
+    context 'when node is a bare `private`' do
+      let(:source) do
+        ['module Foo',
+         '  private',
+         'end'].join("\n")
+      end
+
+      it { expect(send_node.access_modifier?).to be_truthy }
+    end
+
+    context 'when node is a bare `protected`' do
+      let(:source) do
+        ['module Foo',
+         '  protected',
+         'end'].join("\n")
+      end
+
+      it { expect(send_node.access_modifier?).to be_truthy }
+    end
+
+    context 'when node is a bare `public`' do
+      let(:source) do
+        ['module Foo',
+         '  public',
+         'end'].join("\n")
+      end
+
+      it { expect(send_node.access_modifier?).to be_truthy }
+    end
+
+    context 'when node has an argument' do
+      let(:source) do
+        ['module Foo',
+         '  private :foo',
+         'end'].join("\n")
+      end
+
+      it { expect(send_node.access_modifier?).to be_falsey }
+    end
+
+    context 'when node is not an access modifier' do
+      let(:source) do
+        ['module Foo',
+         '  some_command',
+         'end'].join("\n")
+      end
+
+      it { expect(send_node.access_modifier?).to be_falsey }
+    end
+  end
+
   describe '#macro?' do
     context 'without a receiver' do
       context 'when parent is a class' do
@@ -122,6 +186,77 @@ describe RuboCop::AST::SendNode do
         it { expect(send_node.macro?).to be_truthy }
       end
 
+      context 'when parent is a class constructor' do
+        let(:send_node) { parse_source(source).ast.children[2].children[0] }
+
+        let(:source) do
+          ['Module.new do',
+           '  bar :baz',
+           '  bar :qux',
+           'end'].join("\n")
+        end
+
+        it { expect(send_node.macro?).to be_truthy }
+      end
+
+      context 'when parent is a singleton class' do
+        let(:send_node) { parse_source(source).ast.children[1].children[0] }
+
+        let(:source) do
+          ['class << self',
+           '  bar :baz',
+           '  bar :qux',
+           'end'].join("\n")
+        end
+
+        it { expect(send_node.macro?).to be_truthy }
+      end
+
+      context 'when parent is a block' do
+        let(:send_node) { parse_source(source).ast.children[2].children[0] }
+
+        let(:source) do
+          ['concern :Auth do',
+           '  bar :baz',
+           '  bar :qux',
+           'end'].join("\n")
+        end
+
+        it { expect(send_node.macro?).to be_truthy }
+      end
+
+      context 'when parent is a keyword begin inside of an class' do
+        let(:send_node) { parse_source(source).ast.children[2].children[0] }
+
+        let(:source) do
+          ['class Foo',
+           '  begin',
+           '    bar :qux',
+           '  end',
+           'end'].join("\n")
+        end
+
+        it { expect(send_node.macro?).to be_truthy }
+      end
+
+      context 'without a parent' do
+        let(:source) { 'bar :baz' }
+
+        it { expect(send_node.macro?).to be_truthy }
+      end
+
+      context 'when parent is a begin without a parent' do
+        let(:send_node) { parse_source(source).ast.children[0] }
+
+        let(:source) do
+          ['begin',
+           '  bar :qux',
+           'end'].join("\n")
+        end
+
+        it { expect(send_node.macro?).to be_truthy }
+      end
+
       context 'when parent is a method definition' do
         let(:send_node) { parse_source(source).ast.children[2] }
 
@@ -133,12 +268,6 @@ describe RuboCop::AST::SendNode do
 
         it { expect(send_node.macro?).to be_falsey }
       end
-
-      context 'without a parent' do
-        let(:source) { 'bar :baz' }
-
-        it { expect(send_node.macro?).to be_falsey }
-      end
     end
 
     context 'with a receiver' do
@@ -202,7 +331,7 @@ describe RuboCop::AST::SendNode do
     context 'with no arguments' do
       let(:source) { 'foo.bar' }
 
-      it { expect(send_node.arguments).to be_empty }
+      it { expect(send_node.arguments.empty?).to be(true) }
     end
 
     context 'with a single literal argument' do
@@ -234,31 +363,31 @@ describe RuboCop::AST::SendNode do
     context 'with no arguments' do
       let(:source) { 'foo.bar' }
 
-      it { expect(send_node.first_argument).to be_nil }
+      it { expect(send_node.first_argument.nil?).to be(true) }
     end
 
     context 'with a single literal argument' do
       let(:source) { 'foo.bar(:baz)' }
 
-      it { expect(send_node.first_argument).to be_sym_type }
+      it { expect(send_node.first_argument.sym_type?).to be(true) }
     end
 
     context 'with a single splat argument' do
       let(:source) { 'foo.bar(*baz)' }
 
-      it { expect(send_node.first_argument).to be_splat_type }
+      it { expect(send_node.first_argument.splat_type?).to be(true) }
     end
 
     context 'with multiple literal arguments' do
       let(:source) { 'foo.bar(:baz, :qux)' }
 
-      it { expect(send_node.first_argument).to be_sym_type }
+      it { expect(send_node.first_argument.sym_type?).to be(true) }
     end
 
     context 'with multiple mixed arguments' do
       let(:source) { 'foo.bar(:baz, *qux)' }
 
-      it { expect(send_node.first_argument).to be_sym_type }
+      it { expect(send_node.first_argument.sym_type?).to be(true) }
     end
   end
 
@@ -266,31 +395,31 @@ describe RuboCop::AST::SendNode do
     context 'with no arguments' do
       let(:source) { 'foo.bar' }
 
-      it { expect(send_node.last_argument).to be_nil }
+      it { expect(send_node.last_argument.nil?).to be(true) }
     end
 
     context 'with a single literal argument' do
       let(:source) { 'foo.bar(:baz)' }
 
-      it { expect(send_node.last_argument).to be_sym_type }
+      it { expect(send_node.last_argument.sym_type?).to be(true) }
     end
 
     context 'with a single splat argument' do
       let(:source) { 'foo.bar(*baz)' }
 
-      it { expect(send_node.last_argument).to be_splat_type }
+      it { expect(send_node.last_argument.splat_type?).to be(true) }
     end
 
     context 'with multiple literal arguments' do
       let(:source) { 'foo.bar(:baz, :qux)' }
 
-      it { expect(send_node.last_argument).to be_sym_type }
+      it { expect(send_node.last_argument.sym_type?).to be(true) }
     end
 
     context 'with multiple mixed arguments' do
       let(:source) { 'foo.bar(:baz, *qux)' }
 
-      it { expect(send_node.last_argument).to be_splat_type }
+      it { expect(send_node.last_argument.splat_type?).to be(true) }
     end
   end
 
@@ -384,7 +513,7 @@ describe RuboCop::AST::SendNode do
 
   describe '#operator_method?' do
     context 'with a binary operator method' do
-      let(:source) { 'foo.bar == :baz' }
+      let(:source) { 'foo.bar + :baz' }
 
       it { expect(send_node.operator_method?).to be_truthy }
     end
@@ -410,7 +539,7 @@ describe RuboCop::AST::SendNode do
 
   describe '#comparison_method?' do
     context 'with a comparison method' do
-      let(:source) { 'foo.bar <=> :baz' }
+      let(:source) { 'foo.bar >= :baz' }
 
       it { expect(send_node.comparison_method?).to be_truthy }
     end
@@ -420,6 +549,12 @@ describe RuboCop::AST::SendNode do
 
       it { expect(send_node.comparison_method?).to be_falsey }
     end
+
+    context 'with a negation method' do
+      let(:source) { '!foo' }
+
+      it { expect(send_node.comparison_method?).to be_falsey }
+    end
   end
 
   describe '#assignment_method?' do
@@ -520,6 +655,26 @@ describe RuboCop::AST::SendNode do
     end
   end
 
+  describe '#const_receiver?' do
+    context 'with a self receiver' do
+      let(:source) { 'self.bar' }
+
+      it { expect(send_node.const_receiver?).to be_falsey }
+    end
+
+    context 'with a non-constant receiver' do
+      let(:source) { 'foo.bar' }
+
+      it { expect(send_node.const_receiver?).to be_falsey }
+    end
+
+    context 'with a constant receiver' do
+      let(:source) { 'Foo.bar' }
+
+      it { expect(send_node.const_receiver?).to be_truthy }
+    end
+  end
+
   describe '#implicit_call?' do
     context 'with an implicit call method' do
       let(:source) { 'foo.(:bar)' }
@@ -648,19 +803,19 @@ describe RuboCop::AST::SendNode do
 
       let(:source) { 'foo.bar { |q| baz(q) }' }
 
-      it { expect(send_node.block_node).to be_block_type }
+      it { expect(send_node.block_node.block_type?).to be(true) }
     end
 
     context 'with a block argument' do
       let(:source) { 'foo.bar(&baz)' }
 
-      it { expect(send_node.block_node).to be_nil }
+      it { expect(send_node.block_node.nil?).to be(true) }
     end
 
     context 'with no block' do
       let(:source) { 'foo.bar' }
 
-      it { expect(send_node.block_node).to be_nil }
+      it { expect(send_node.block_node.nil?).to be(true) }
     end
   end
 
@@ -689,4 +844,90 @@ describe RuboCop::AST::SendNode do
       it { expect(send_node.splat_argument?).to be_truthy }
     end
   end
+
+  describe '#def_modifier?' do
+    context 'with a prefixed def modifier' do
+      let(:source) { 'foo def bar; end' }
+
+      it { expect(send_node.def_modifier?).to be_truthy }
+    end
+
+    context 'with several prefixed def modifiers' do
+      let(:source) { 'foo bar def baz; end' }
+
+      it { expect(send_node.def_modifier?).to be_truthy }
+    end
+  end
+
+  describe '#negation_method?' do
+    context 'with keyword `not`' do
+      let(:source) { 'not foo' }
+
+      it { expect(send_node.negation_method?).to be_truthy }
+    end
+
+    context 'with a bang method' do
+      let(:source) { '!foo' }
+
+      it { expect(send_node.negation_method?).to be_truthy }
+    end
+
+    context 'with a non-negated method' do
+      let(:source) { 'foo.bar' }
+
+      it { expect(send_node.negation_method?).to be_falsey }
+    end
+  end
+
+  describe '#lambda?' do
+    context 'with a lambda method' do
+      let(:source) { 'lambda { |foo| bar(foo) }' }
+      let(:send_node) { parse_source(source).ast.send_node }
+
+      it { expect(send_node.lambda?).to be_truthy }
+    end
+
+    context 'with a stabby lambda method' do
+      let(:source) { '-> (foo) { do_something(foo) }' }
+      let(:send_node) { parse_source(source).ast.send_node }
+
+      it { expect(send_node.lambda?).to be_truthy }
+    end
+
+    context 'with a non-lambda method' do
+      let(:source) { 'foo.bar' }
+
+      it { expect(send_node.lambda?).to be_falsey }
+    end
+  end
+
+  describe '#stabby_lambda?' do
+    context 'with a stabby lambda' do
+      let(:send_node) { parse_source(source).ast.send_node }
+      let(:source) { '-> (foo) { do_something(foo) }' }
+
+      it { expect(send_node.stabby_lambda?).to be(true) }
+    end
+
+    context 'with a lambda method' do
+      let(:send_node) { parse_source(source).ast.send_node }
+      let(:source) { 'lambda { |foo| bar(foo) }' }
+
+      it { expect(send_node.stabby_lambda?).to be(false) }
+    end
+
+    context 'with a non-lambda method' do
+      let(:source) { 'foo.bar' }
+
+      it { expect(send_node.lambda?).to be_falsey }
+    end
+
+    # Regression test https://github.com/bbatsov/rubocop/pull/5194
+    context 'with `a.() {}` style method' do
+      let(:send_node) { parse_source(source).ast.send_node }
+      let(:source) { 'a.() {}' }
+
+      it { expect(send_node.lambda?).to be_falsey }
+    end
+  end
 end
