@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::ConfigLoader do
+RSpec.describe RuboCop::ConfigLoader do
   include FileHelper
 
   let(:default_config) { described_class.default_configuration }
@@ -12,6 +12,7 @@ describe RuboCop::ConfigLoader do
 
     context 'when no config file exists in ancestor directories' do
       let(:dir_path) { 'dir' }
+
       before { create_file('dir/example.rb', '') }
 
       context 'but a config file exists in home directory' do
@@ -74,10 +75,10 @@ describe RuboCop::ConfigLoader do
       let(:file_path) { '.rubocop.yml' }
 
       before do
-        create_file(file_path, <<-END.strip_indent)
+        create_file(file_path, <<-YAML.strip_indent)
           Style/Encoding:
             Enabled: false
-        END
+        YAML
       end
 
       it 'returns a configuration inheriting from default.yml' do
@@ -92,16 +93,16 @@ describe RuboCop::ConfigLoader do
       let(:file_path) { 'dir/.rubocop.yml' }
 
       before do
-        create_file('.rubocop.yml', <<-END.strip_indent)
+        create_file('.rubocop.yml', <<-YAML.strip_indent)
           AllCops:
             Exclude:
               - vendor/**
-        END
+        YAML
 
-        create_file(file_path, <<-END.strip_indent)
+        create_file(file_path, <<-YAML.strip_indent)
           AllCops:
             Exclude: []
-        END
+        YAML
       end
 
       it 'gets AllCops/Exclude from the highest directory level' do
@@ -114,10 +115,10 @@ describe RuboCop::ConfigLoader do
       let(:file_path) { '.rubocop.yml' }
 
       before do
-        create_file('disable.yml', <<-END.strip_indent)
+        create_file('disable.yml', <<-YAML.strip_indent)
           AllCops:
             DisabledByDefault: true
-        END
+        YAML
 
         create_file(file_path, ['inherit_from: disable.yml'])
       end
@@ -132,12 +133,12 @@ describe RuboCop::ConfigLoader do
       let(:file_path) { 'dir/.rubocop.yml' }
 
       before do
-        create_file('.rubocop.yml', <<-END.strip_indent)
+        create_file('.rubocop.yml', <<-YAML.strip_indent)
           AllCops:
             Exclude:
               - vendor/**
               - !ruby/regexp /[A-Z]/
-        END
+        YAML
 
         create_file(file_path, ['inherit_from: ../.rubocop.yml'])
       end
@@ -146,6 +147,24 @@ describe RuboCop::ConfigLoader do
         excludes = configuration_from_file['AllCops']['Exclude']
         expect(excludes).to eq([File.expand_path('vendor/**'), /[A-Z]/])
       end
+
+      it 'ignores parent AllCops/Exclude if ignore_parent_exclusion is true' do
+        sub_file_path = 'vendor/.rubocop.yml'
+        create_file(sub_file_path, <<-YAML.strip_indent)
+        AllCops:
+          Exclude:
+            - 'foo'
+        YAML
+        # dup the class so that setting ignore_parent_exclusion doesn't
+        # interfere with other specs
+        config_loader = described_class.dup
+        config_loader.ignore_parent_exclusion = true
+
+        configuration = config_loader.configuration_from_file(sub_file_path)
+        excludes = configuration['AllCops']['Exclude']
+        expect(excludes).not_to include(File.expand_path('vendor/**'))
+        expect(excludes).to include(File.expand_path('vendor/foo'))
+      end
     end
 
     context 'when a file inherits from an empty parent file' do
@@ -166,11 +185,11 @@ describe RuboCop::ConfigLoader do
       let(:file_path) { 'dir/.rubocop.yml' }
 
       before do
-        create_file('src/.rubocop.yml', <<-END.strip_indent)
+        create_file('src/.rubocop.yml', <<-YAML.strip_indent)
           AllCops:
             Exclude:
               - vendor/**
-        END
+        YAML
 
         create_file(file_path, ['inherit_from: ../src/.rubocop.yml'])
       end
@@ -189,7 +208,7 @@ describe RuboCop::ConfigLoader do
             RuboCop::Cop::Registry.new(RuboCop::Cop::Cop.registry.cops)
           )
 
-        create_file('third_party/gem.rb', <<-END.strip_indent)
+        create_file('third_party/gem.rb', <<-RUBY.strip_indent)
           module RuboCop
             module Cop
               module Custom
@@ -198,18 +217,18 @@ describe RuboCop::ConfigLoader do
               end
             end
           end
-        END
+        RUBY
 
-        create_file('.rubocop.yml', <<-END.strip_indent)
+        create_file('.rubocop.yml', <<-YAML.strip_indent)
           Custom/FilePath:
             Enabled: false
-        END
+        YAML
 
-        create_file('.rubocop_with_require.yml', <<-END.strip_indent)
+        create_file('.rubocop_with_require.yml', <<-YAML.strip_indent)
           require: ./third_party/gem
           Custom/FilePath:
             Enabled: false
-        END
+        YAML
       end
 
       it 'does not emit a warning' do
@@ -235,22 +254,22 @@ describe RuboCop::ConfigLoader do
       before do
         create_file('dir/subdir/example.rb', '')
 
-        create_file('.rubocop.yml', <<-END.strip_indent)
+        create_file('.rubocop.yml', <<-YAML.strip_indent)
           Metrics/LineLength:
             Enabled: false
             Max: 77
-        END
+        YAML
 
-        create_file('dir/.rubocop.yml', <<-END.strip_indent)
+        create_file('dir/.rubocop.yml', <<-YAML.strip_indent)
           inherit_from: ../.rubocop.yml
 
           Metrics/MethodLength:
             Enabled: true
             CountComments: false
             Max: 10
-        END
+        YAML
 
-        create_file(file_path, <<-END.strip_indent)
+        create_file(file_path, <<-YAML.strip_indent)
           inherit_from: ../.rubocop.yml
 
           Metrics/LineLength:
@@ -258,7 +277,7 @@ describe RuboCop::ConfigLoader do
 
           Metrics/MethodLength:
             Max: 5
-        END
+        YAML
       end
 
       it 'returns the ancestor configuration plus local overrides' do
@@ -295,35 +314,37 @@ describe RuboCop::ConfigLoader do
       before do
         create_file('example.rb', '')
 
-        create_file('normal.yml', <<-END.strip_indent)
+        create_file('normal.yml', <<-YAML.strip_indent)
           Metrics/MethodLength:
             Enabled: false
             CountComments: true
             Max: 80
-        END
+        YAML
 
-        create_file('special.yml', <<-END.strip_indent)
+        create_file('special.yml', <<-YAML.strip_indent)
           Metrics/MethodLength:
             Enabled: false
             Max: 200
-        END
+        YAML
 
-        create_file(file_path, <<-END.strip_indent)
+        create_file(file_path, <<-YAML.strip_indent)
           inherit_from:
             - normal.yml
             - special.yml
 
           Metrics/MethodLength:
             Enabled: true
-        END
+        YAML
       end
 
       it 'returns values from the last one when possible' do
         expected = { 'Enabled' => true,        # overridden in .rubocop.yml
                      'CountComments' => true,  # only defined in normal.yml
                      'Max' => 200 }            # special.yml takes precedence
-        expect(configuration_from_file['Metrics/MethodLength'].to_set)
-          .to be_superset(expected.to_set)
+        expect(
+          configuration_from_file['Metrics/MethodLength']
+            .to_set.superset?(expected.to_set)
+        ).to be(true)
       end
     end
 
@@ -333,18 +354,18 @@ describe RuboCop::ConfigLoader do
       before do
         create_file('example.rb', '')
 
-        create_file('line_length.yml', <<-END.strip_indent)
+        create_file('line_length.yml', <<-YAML.strip_indent)
           LineLength:
             Max: 120
-        END
+        YAML
 
-        create_file(file_path, <<-END.strip_indent)
+        create_file(file_path, <<-YAML.strip_indent)
           inherit_from:
             - line_length.yml
 
           LineLength:
             AllowHeredoc: false
-        END
+        YAML
       end
 
       it 'returns includes both of the cop changes' do
@@ -385,10 +406,10 @@ describe RuboCop::ConfigLoader do
       let(:file_path) { '.rubocop.yml' }
 
       before do
-        create_file(file_path, <<-END.strip_indent)
+        create_file(file_path, <<-YAML.strip_indent)
           inherit_gem:
             not_a_real_gem: config/rubocop.yml
-        END
+        YAML
       end
 
       it 'fails to load' do
@@ -400,10 +421,10 @@ describe RuboCop::ConfigLoader do
       let(:file_path) { '.rubocop.yml' }
 
       before do
-        create_file(file_path, <<-END.strip_indent)
+        create_file(file_path, <<-YAML.strip_indent)
           inherit_gem:
             rubocop: config/default.yml
-        END
+        YAML
       end
 
       it 'fails to load' do
@@ -415,26 +436,26 @@ describe RuboCop::ConfigLoader do
       let(:file_path) { '.rubocop.yml' }
 
       before do
-        create_file('gemone/config/rubocop.yml', <<-END.strip_indent)
+        create_file('gemone/config/rubocop.yml', <<-YAML.strip_indent)
           Metrics/MethodLength:
             Enabled: false
             Max: 200
             CountComments: false
-        END
-        create_file('gemtwo/config/default.yml', <<-END.strip_indent)
+        YAML
+        create_file('gemtwo/config/default.yml', <<-YAML.strip_indent)
           Metrics/LineLength:
             Enabled: true
-        END
-        create_file('gemtwo/config/strict.yml', <<-END.strip_indent)
+        YAML
+        create_file('gemtwo/config/strict.yml', <<-YAML.strip_indent)
           Metrics/LineLength:
             Max: 72
             AllowHeredoc: false
-        END
-        create_file('local.yml', <<-END.strip_indent)
+        YAML
+        create_file('local.yml', <<-YAML.strip_indent)
           Metrics/MethodLength:
             CountComments: true
-        END
-        create_file(file_path, <<-END.strip_indent)
+        YAML
+        create_file(file_path, <<-YAML.strip_indent)
           inherit_gem:
             gemone: config/rubocop.yml
             gemtwo:
@@ -448,7 +469,7 @@ describe RuboCop::ConfigLoader do
 
           Metrics/LineLength:
             AllowURI: false
-        END
+        YAML
       end
 
       it 'returns values from the gem config with local overrides' do
@@ -462,15 +483,19 @@ describe RuboCop::ConfigLoader do
         expected = { 'Enabled' => true,        # overridden in .rubocop.yml
                      'CountComments' => true,  # overridden in local.yml
                      'Max' => 200 }            # inherited from somegem
-        expect(configuration_from_file['Metrics/MethodLength'].to_set)
-          .to be_superset(expected.to_set)
+        expect(
+          configuration_from_file['Metrics/MethodLength']
+            .to_set.superset?(expected.to_set)
+        ).to be(true)
 
         expected = { 'Enabled' => true,        # gemtwo/config/default.yml
                      'Max' => 72,              # gemtwo/config/strict.yml
                      'AllowHeredoc' => false,  # gemtwo/config/strict.yml
                      'AllowURI' => false }     # overridden in .rubocop.yml
-        expect(configuration_from_file['Metrics/LineLength'].to_set)
-          .to be_superset(expected.to_set)
+        expect(
+          configuration_from_file['Metrics/LineLength']
+            .to_set.superset?(expected.to_set)
+        ).to be(true)
       end
     end
 
@@ -495,15 +520,31 @@ describe RuboCop::ConfigLoader do
       end
     end
 
-    context 'when a file inherits from a non http/https url' do
-      let(:file_path) { '.rubocop.yml' }
+    context 'when a file inherits from a url inheriting from another file' do
+      let(:file_path) { '.robocop.yml' }
+      let(:cache_file) { '.rubocop-http---example-com-rubocop-yml' }
+      let(:cache_file_2) { '.rubocop-http---example-com-inherit-yml' }
 
       before do
-        create_file(file_path, ['inherit_from: c:\\\\foo\\bar.yml'])
+        stub_request(:get, %r{example.com/rubocop})
+          .to_return(status: 200, body: "inherit_from:\n    - inherit.yml")
+
+        stub_request(:get, %r{example.com/inherit})
+          .to_return(status: 200, body: "Style/Encoding:\n    Enabled: true")
+
+        create_file(file_path, ['inherit_from: http://example.com/rubocop.yml'])
       end
 
-      it 'fails to load the resulting path' do
-        expect { configuration_from_file }.to raise_error(Errno::ENOENT)
+      after do
+        [cache_file, cache_file_2].each do |f|
+          File.unlink f if File.exist? f
+        end
+      end
+
+      it 'downloads the inherited file from the same url and caches it' do
+        configuration_from_file
+        expect(File.exist?(cache_file)).to be true
+        expect(File.exist?(cache_file_2)).to be true
       end
     end
 
@@ -520,13 +561,13 @@ describe RuboCop::ConfigLoader do
 
       context 'when DisabledByDefault is true' do
         let(:config) do
-          <<-END.strip_indent
+          <<-YAML.strip_indent
             AllCops:
               DisabledByDefault: true
             Style/Copyright:
               Exclude:
               - foo
-          END
+          YAML
         end
 
         it 'enables cops that are explicitly in the config file '\
@@ -542,12 +583,12 @@ describe RuboCop::ConfigLoader do
 
         context 'and a department is enabled' do
           let(:config) do
-            <<-END.strip_indent
+            <<-YAML.strip_indent
               AllCops:
                 DisabledByDefault: true
               Style:
                 Enabled: true
-            END
+            YAML
           end
 
           it 'enables cops in that department' do
@@ -568,14 +609,14 @@ describe RuboCop::ConfigLoader do
 
         context 'and the Rails department is enabled' do
           let(:config) do
-            <<-END.strip_indent
+            <<-YAML.strip_indent
               AllCops:
                 DisabledByDefault: true
               Rails:
                 Enabled: true
               Rails/ActionFilter:
                 EnforcedStyle: filter
-            END
+            YAML
           end
 
           it 'enables explicitly mentioned cops in that department' do
@@ -591,14 +632,14 @@ describe RuboCop::ConfigLoader do
 
         context 'and the Rails department is disabled' do
           let(:config) do
-            <<-END.strip_indent
+            <<-YAML.strip_indent
               AllCops:
                 DisabledByDefault: true
               Rails:
                 Enabled: false
               Rails/ActionFilter:
                 Enabled: true
-            END
+            YAML
           end
 
           it 'disables explicitly mentioned cops in that department' do
@@ -615,12 +656,12 @@ describe RuboCop::ConfigLoader do
 
       context 'when EnabledByDefault is true' do
         let(:config) do
-          <<-END.strip_indent
+          <<-YAML.strip_indent
             AllCops:
               EnabledByDefault: true
             Layout/TrailingWhitespace:
               Enabled: false
-          END
+          YAML
         end
 
         it 'enables cops that are disabled by default' do
@@ -644,10 +685,10 @@ describe RuboCop::ConfigLoader do
     let(:configuration_path) { '.rubocop.yml' }
 
     it 'returns a configuration loaded from the passed path' do
-      create_file(configuration_path, <<-END.strip_indent)
+      create_file(configuration_path, <<-YAML.strip_indent)
         Style/Encoding:
           Enabled: true
-      END
+      YAML
       configuration = load_file
       expect(configuration['Style/Encoding']).to eq(
         'Enabled' => true
@@ -662,20 +703,20 @@ describe RuboCop::ConfigLoader do
     end
 
     it 'changes target ruby version with a patch to float' do
-      create_file(configuration_path, <<-END.strip_indent)
+      create_file(configuration_path, <<-YAML.strip_indent)
         AllCops:
           TargetRubyVersion: 2.3.4
-      END
+      YAML
 
       expect(load_file.to_h).to eq('AllCops' => { 'TargetRubyVersion' => 2.3 })
     end
 
     it 'loads configuration properly when it includes non-ascii characters ' do
-      create_file(configuration_path, <<-END.strip_indent)
+      create_file(configuration_path, <<-YAML.strip_indent)
         # All these cops of mine are ❤
         Style/Encoding:
           Enabled: false
-      END
+      YAML
 
       expect(load_file.to_h).to eq('Style/Encoding' => { 'Enabled' => false })
     end
@@ -688,10 +729,10 @@ describe RuboCop::ConfigLoader do
 
     context 'when SafeYAML is required' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           Style/WordArray:
             WordRegex: !ruby/regexp '/\\A[\\p{Word}]+\\z/'
-        END
+        YAML
       end
 
       context 'when it is fully required' do
@@ -700,7 +741,7 @@ describe RuboCop::ConfigLoader do
             configuration = described_class.load_file('.rubocop.yml')
 
             word_regexp = configuration['Style/WordArray']['WordRegex']
-            expect(word_regexp).to be_a(::Regexp)
+            expect(word_regexp.is_a?(::Regexp)).to be(true)
           end
         end
       end
@@ -711,7 +752,7 @@ describe RuboCop::ConfigLoader do
             configuration = described_class.load_file('.rubocop.yml')
 
             word_regexp = configuration['Style/WordArray']['WordRegex']
-            expect(word_regexp).to be_a(::Regexp)
+            expect(word_regexp.is_a?(::Regexp)).to be(true)
           end
         end
 
@@ -724,12 +765,26 @@ describe RuboCop::ConfigLoader do
               configuration = described_class.load_file('.rubocop.yml')
 
               word_regexp = configuration['Style/WordArray']['WordRegex']
-              expect(word_regexp).to be_a(::Regexp)
+              expect(word_regexp.is_a?(::Regexp)).to be(true)
             end
           end
         end
       end
     end
+
+    context 'when the file does not exist' do
+      let(:configuration_path) { 'file_that_does_not_exist.yml' }
+
+      it 'prints a friendly (concise) message to stderr and exits' do
+        expect { load_file }.to(
+          output(/Configuration file not found/).to_stderr.and(
+            raise_error(SystemExit) do |e|
+              expect(e.status).to(eq(Errno::ENOENT::Errno))
+            end
+          )
+        )
+      end
+    end
   end
 
   describe '.merge' do
@@ -766,11 +821,11 @@ describe RuboCop::ConfigLoader do
     context 'when .rubocop.yml inherits from a file with a name starting ' \
             'with .rubocop' do
       before do
-        create_file('test/.rubocop_rules.yml', <<-END.strip_indent)
+        create_file('test/.rubocop_rules.yml', <<-YAML.strip_indent)
           Style/CharacterLiteral:
             Exclude:
               - blargh/blah.rb
-        END
+        YAML
         create_file('test/.rubocop.yml', 'inherit_from: .rubocop_rules.yml')
       end
 
