@@ -1,9 +1,10 @@
 # frozen_string_literal: true
 
-describe RuboCop::Config do
+RSpec.describe RuboCop::Config do
   include FileHelper
 
   subject(:configuration) { described_class.new(hash, loaded_path) }
+
   let(:hash) { {} }
   let(:loaded_path) { 'example/.rubocop.yml' }
 
@@ -16,11 +17,11 @@ describe RuboCop::Config do
 
     context 'when the configuration includes any unrecognized cop name' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           LyneLenth:
             Enabled: true
             Max: 100
-        END
+        YAML
         $stderr = StringIO.new
       end
 
@@ -59,10 +60,10 @@ describe RuboCop::Config do
 
     context 'when the configuration is in the base RuboCop config folder' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           InvalidProperty:
             Enabled: true
-        END
+        YAML
         stub_const('RuboCop::ConfigLoader::RUBOCOP_HOME', rubocop_home_path)
       end
 
@@ -76,11 +77,11 @@ describe RuboCop::Config do
 
     context 'when the configuration includes any unrecognized parameter' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           Metrics/LineLength:
             Enabled: true
             Min: 10
-        END
+        YAML
         $stderr = StringIO.new
       end
 
@@ -100,7 +101,7 @@ describe RuboCop::Config do
       # Common parameters are parameters that are not in the default
       # configuration, but are nonetheless allowed for any cop.
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           Metrics/ModuleLength:
             Exclude:
               - lib/file.rb
@@ -108,7 +109,7 @@ describe RuboCop::Config do
               - lib/file.xyz
             Severity: warning
             StyleGuide: https://example.com/some-style.html
-        END
+        YAML
       end
 
       it 'does not raise validation error' do
@@ -118,10 +119,10 @@ describe RuboCop::Config do
 
     context 'when the configuration includes a valid EnforcedStyle' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           Style/AndOr:
             EnforcedStyle: conditionals
-        END
+        YAML
       end
 
       it 'does not raise validation error' do
@@ -129,12 +130,12 @@ describe RuboCop::Config do
       end
     end
 
-    context 'when the configration includes an invalid EnforcedStyle' do
+    context 'when the configuration includes an invalid EnforcedStyle' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           Style/AndOr:
             EnforcedStyle: itisinvalid
-        END
+        YAML
       end
 
       it 'raises validation error' do
@@ -143,12 +144,12 @@ describe RuboCop::Config do
       end
     end
 
-    context 'when the configration includes a valid Enforced.+Style' do
+    context 'when the configuration includes a valid EnforcedStyle' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           Layout/SpaceAroundBlockParameters:
             EnforcedStyleInsidePipes: space
-        END
+        YAML
       end
 
       it 'does not raise validation error' do
@@ -156,12 +157,12 @@ describe RuboCop::Config do
       end
     end
 
-    context 'when the configration includes an invalid Enforced.+Style' do
+    context 'when the configuration includes an invalid EnforcedStyle' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           Layout/SpaceAroundBlockParameters:
             EnforcedStyleInsidePipes: itisinvalid
-        END
+        YAML
       end
 
       it 'raises validation error' do
@@ -172,10 +173,10 @@ describe RuboCop::Config do
 
     context 'when the configuration includes an obsolete cop' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           Style/MethodCallParentheses:
             Enabled: true
-        END
+        YAML
       end
 
       it 'raises validation error' do
@@ -187,10 +188,10 @@ describe RuboCop::Config do
 
     context 'when the configuration includes an obsolete parameter' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           Rails/UniqBeforePluck:
             EnforcedMode: conservative
-        END
+        YAML
       end
 
       it 'raises validation error' do
@@ -199,9 +200,32 @@ describe RuboCop::Config do
       end
     end
 
+    shared_examples 'obsolete MaxLineLength parameter' do |cop_name|
+      context "when the configuration includes the obsolete #{cop_name}: " \
+              'MaxLineLength parameter' do
+        before do
+          create_file(configuration_path, <<-YAML.strip_indent)
+            #{cop_name}:
+              MaxLineLength: 100
+          YAML
+        end
+
+        it 'raises validation error' do
+          expect { configuration.validate }
+            .to raise_error(RuboCop::ValidationError,
+                            /`#{cop_name}: MaxLineLength` has been removed./)
+        end
+      end
+    end
+
+    include_examples 'obsolete MaxLineLength parameter',
+                     'Style/WhileUntilModifier'
+    include_examples 'obsolete MaxLineLength parameter',
+                     'Style/IfUnlessModifier'
+
     context 'when the configuration includes obsolete parameters and cops' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           Rails/UniqBeforePluck:
             EnforcedMode: conservative
           Style/MethodCallParentheses:
@@ -210,7 +234,7 @@ describe RuboCop::Config do
             AlignWith: either
           Layout/SpaceBeforeModifierKeyword:
             Enabled: false
-        END
+        YAML
       end
 
       it 'raises validation error' do
@@ -227,11 +251,11 @@ describe RuboCop::Config do
 
     context 'when all cops are both Enabled and Disabled by default' do
       before do
-        create_file(configuration_path, <<-END.strip_indent)
+        create_file(configuration_path, <<-YAML.strip_indent)
           AllCops:
             EnabledByDefault: true
             DisabledByDefault: true
-        END
+        YAML
       end
 
       it 'raises validation error' do
@@ -242,6 +266,43 @@ describe RuboCop::Config do
           )
       end
     end
+
+    context 'when the configuration includes Lint/Syntax cop' do
+      before do
+        # Force reloading default configuration
+        RuboCop::ConfigLoader.default_configuration = nil
+      end
+
+      context 'when the configuration matches the default' do
+        before do
+          create_file(configuration_path, <<-YAML.strip_indent)
+            Lint/Syntax:
+              Enabled: true
+          YAML
+        end
+
+        it 'does not raise validation error' do
+          expect { configuration.validate }.not_to raise_error
+        end
+      end
+
+      context 'when the configuration does not match the default' do
+        before do
+          create_file(configuration_path, <<-YAML.strip_indent)
+            Lint/Syntax:
+              Enabled: false
+          YAML
+        end
+
+        it 'raises validation error' do
+          expect { configuration.validate }
+            .to raise_error(
+              RuboCop::ValidationError,
+              /configuration for Syntax cop found/
+            )
+        end
+      end
+    end
   end
 
   describe '#make_excludes_absolute' do
@@ -455,6 +516,28 @@ describe RuboCop::Config do
     end
   end
 
+  describe '#check' do
+    subject(:configuration) do
+      described_class.new(hash, loaded_path)
+    end
+
+    let(:loaded_path) { 'example/.rubocop.yml' }
+
+    context 'when a deprecated configuration is detected' do
+      let(:hash) { { 'AllCops' => { 'Includes' => [] } } }
+
+      before { $stderr = StringIO.new }
+      after { $stderr = STDERR }
+
+      it 'prints a warning message for the loaded path' do
+        configuration.check
+        expect($stderr.string).to include(
+          "#{loaded_path} - AllCops/Includes was renamed"
+        )
+      end
+    end
+  end
+
   describe '#deprecation_check' do
     context 'when there is no AllCops configuration' do
       let(:hash) { {} }
@@ -579,7 +662,7 @@ describe RuboCop::Config do
     end
   end
 
-  describe '#target_ruby_version' do
+  describe '#target_ruby_version', :isolated_environment do
     context 'when TargetRubyVersion is set' do
       let(:ruby_version) { 2.1 }
 
@@ -592,7 +675,7 @@ describe RuboCop::Config do
       end
 
       before do
-        allow(File).to receive(:file?).with('.ruby-version')
+        allow(File).to receive(:file?).and_call_original
       end
 
       it 'uses TargetRubyVersion' do
@@ -608,11 +691,8 @@ describe RuboCop::Config do
     context 'when TargetRubyVersion is not set' do
       context 'when .ruby-version is present' do
         before do
-          allow(File).to receive(:file?).with('.ruby-version').and_return true
-          allow(File)
-            .to receive(:read)
-            .with('.ruby-version')
-            .and_return ruby_version
+          dir = configuration.base_dir_for_path_parameters
+          create_file(File.join(dir, '.ruby-version'), ruby_version)
         end
 
         context 'when .ruby-version contains an MRI version' do
@@ -671,15 +751,22 @@ describe RuboCop::Config do
       end
 
       context 'when .ruby-version is not present' do
-        before do
-          allow(File).to receive(:file?).with('.ruby-version').and_return false
-        end
-
         it 'uses the default target ruby version' do
           expect(configuration.target_ruby_version)
             .to eq described_class::DEFAULT_RUBY_VERSION
         end
       end
+
+      context 'when .ruby-version is in a parent directory' do
+        before do
+          dir = configuration.base_dir_for_path_parameters
+          create_file(File.join(dir, '..', '.ruby-version'), '2.4.1')
+        end
+
+        it 'reads it to determine the target ruby version' do
+          expect(configuration.target_ruby_version).to eq 2.4
+        end
+      end
     end
   end
 end
