@@ -1,7 +1,8 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Layout::CaseIndentation do
+RSpec.describe RuboCop::Cop::Layout::CaseIndentation do
   subject(:cop) { described_class.new(config) }
+
   let(:config) do
     merged = RuboCop::ConfigLoader
              .default_configuration['Layout/CaseIndentation'].merge(cop_config)
@@ -23,14 +24,14 @@ describe RuboCop::Cop::Layout::CaseIndentation do
 
       context 'regarding assignment where the right hand side is a case' do
         let(:correct_source) do
-          <<-END.strip_indent
+          <<-RUBY.strip_indent
             output = case variable
                      when 'value1'
               'output1'
             else
               'output2'
             end
-          END
+          RUBY
         end
 
         it 'accepts a correctly indented assignment' do
@@ -46,67 +47,67 @@ describe RuboCop::Cop::Layout::CaseIndentation do
 
         context 'an assignment indented as end' do
           let(:source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
               when 'value1'
                 'output1'
               else
                 'output2'
               end
-            END
+            RUBY
           end
 
           it 'registers an offense' do
-            inspect_source(cop, source)
+            inspect_source(source)
             expect(cop.messages).to eq(['Indent `when` as deep as `case`.'])
             expect(cop.config_to_allow_offenses).to eq('EnforcedStyle' =>
                                                        'end')
           end
 
           it 'does auto-correction' do
-            corrected = autocorrect_source(cop, source)
+            corrected = autocorrect_source(source)
             expect(corrected).to eq correct_source
           end
         end
 
         context 'an assignment indented some other way' do
           let(:source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
                 when 'value1'
                   'output1'
                 else
                   'output2'
               end
-            END
+            RUBY
           end
 
           let(:correct_source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
                        when 'value1'
                   'output1'
                 else
                   'output2'
               end
-            END
+            RUBY
           end
 
           it 'registers an offense' do
-            inspect_source(cop, source)
+            inspect_source(source)
             expect(cop.messages).to eq(['Indent `when` as deep as `case`.'])
             expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
           end
 
           it 'does auto-correction' do
-            corrected = autocorrect_source(cop, source)
+            corrected = autocorrect_source(source)
             expect(corrected).to eq correct_source
           end
         end
 
         context 'correct + opposite' do
           let(:source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
                        when 'value1'
                          'output1'
@@ -119,11 +120,11 @@ describe RuboCop::Cop::Layout::CaseIndentation do
               else
                 'output2'
               end
-            END
+            RUBY
           end
 
           let(:correct_source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
                        when 'value1'
                          'output1'
@@ -136,17 +137,17 @@ describe RuboCop::Cop::Layout::CaseIndentation do
               else
                 'output2'
               end
-            END
+            RUBY
           end
 
           it 'registers an offense' do
-            inspect_source(cop, source)
+            inspect_source(source)
             expect(cop.messages).to eq(['Indent `when` as deep as `case`.'])
             expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
           end
 
           it 'does auto-correction' do
-            corrected = autocorrect_source(cop, source)
+            corrected = autocorrect_source(source)
             expect(corrected).to eq(correct_source)
           end
         end
@@ -154,7 +155,7 @@ describe RuboCop::Cop::Layout::CaseIndentation do
 
       context "a when clause that's deeper than case" do
         let(:source) do
-          <<-END.strip_indent
+          <<-RUBY.strip_indent
             case a
                 when 0 then return
                 else
@@ -162,7 +163,7 @@ describe RuboCop::Cop::Layout::CaseIndentation do
                      when 1 then return
                     end
             end
-          END
+          RUBY
         end
 
         it 'registers an offense' do
@@ -180,8 +181,8 @@ describe RuboCop::Cop::Layout::CaseIndentation do
         end
 
         it 'does auto-correction' do
-          corrected = autocorrect_source(cop, source)
-          expect(corrected).to eq(<<-END.strip_indent)
+          corrected = autocorrect_source(source)
+          expect(corrected).to eq(<<-RUBY.strip_indent)
             case a
             when 0 then return
                 else
@@ -189,7 +190,7 @@ describe RuboCop::Cop::Layout::CaseIndentation do
                     when 1 then return
                     end
             end
-          END
+          RUBY
         end
       end
 
@@ -279,25 +280,25 @@ describe RuboCop::Cop::Layout::CaseIndentation do
 
         context 'an assignment indented some other way' do
           let(:source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
                        when 'value1'
                          'output1'
                        else
                          'output2'
                        end
-            END
+            RUBY
           end
 
           let(:correct_source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
                          when 'value1'
                          'output1'
                        else
                          'output2'
                        end
-            END
+            RUBY
           end
 
           it 'registers an offense' do
@@ -313,7 +314,7 @@ describe RuboCop::Cop::Layout::CaseIndentation do
           end
 
           it 'does auto-correction' do
-            corrected = autocorrect_source(cop, source)
+            corrected = autocorrect_source(source)
             expect(corrected).to eq correct_source
           end
         end
@@ -333,7 +334,7 @@ describe RuboCop::Cop::Layout::CaseIndentation do
 
       context "a when clause that's equally indented with case" do
         let(:source) do
-          <<-END.strip_indent
+          <<-RUBY.strip_indent
             y = case a
                 when 0 then break
                 when 0 then return
@@ -345,7 +346,7 @@ describe RuboCop::Cop::Layout::CaseIndentation do
             case c
             when 2 then encoding
             end
-          END
+          RUBY
         end
 
         it 'registers an offense' do
@@ -370,8 +371,8 @@ describe RuboCop::Cop::Layout::CaseIndentation do
         end
 
         it 'does auto-correction' do
-          corrected = autocorrect_source(cop, source)
-          expect(corrected).to eq(<<-END.strip_indent)
+          corrected = autocorrect_source(source)
+          expect(corrected).to eq(<<-RUBY.strip_indent)
             y = case a
                   when 0 then break
                   when 0 then return
@@ -383,7 +384,7 @@ describe RuboCop::Cop::Layout::CaseIndentation do
             case c
               when 2 then encoding
             end
-          END
+          RUBY
         end
       end
 
@@ -436,25 +437,25 @@ describe RuboCop::Cop::Layout::CaseIndentation do
 
         context 'an assignment indented some other way' do
           let(:source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
                 when 'value1'
                   'output1'
                 else
                   'output2'
               end
-            END
+            RUBY
           end
 
           let(:correct_source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
               when 'value1'
                   'output1'
                 else
                   'output2'
               end
-            END
+            RUBY
           end
 
           it 'registers an offense' do
@@ -470,7 +471,7 @@ describe RuboCop::Cop::Layout::CaseIndentation do
           end
 
           it 'does auto-correction' do
-            corrected = autocorrect_source(cop, source)
+            corrected = autocorrect_source(source)
             expect(corrected).to eq correct_source
           end
         end
@@ -502,29 +503,29 @@ describe RuboCop::Cop::Layout::CaseIndentation do
 
         context 'an assignment indented as case' do
           let(:source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
                        when 'value1'
                          'output1'
                        else
                          'output2'
                        end
-            END
+            RUBY
           end
 
           let(:correct_source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
                          when 'value1'
                          'output1'
                        else
                          'output2'
                        end
-            END
+            RUBY
           end
 
           it 'registers an offense' do
-            inspect_source(cop, source)
+            inspect_source(source)
             expect(cop.messages)
               .to eq(['Indent `when` one step more than `end`.'])
             expect(cop.config_to_allow_offenses).to eq('EnforcedStyle' =>
@@ -532,43 +533,43 @@ describe RuboCop::Cop::Layout::CaseIndentation do
           end
 
           it 'does auto-correction' do
-            corrected = autocorrect_source(cop, source)
+            corrected = autocorrect_source(source)
             expect(corrected).to eq correct_source
           end
         end
 
         context 'an assignment indented some other way' do
           let(:source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
                      when 'value1'
                        'output1'
                      else
                        'output2'
                      end
-            END
+            RUBY
           end
 
           let(:correct_source) do
-            <<-END.strip_indent
+            <<-RUBY.strip_indent
               output = case variable
                        when 'value1'
                        'output1'
                      else
                        'output2'
                      end
-            END
+            RUBY
           end
 
           it 'registers an offense' do
-            inspect_source(cop, source)
+            inspect_source(source)
             expect(cop.messages)
               .to eq(['Indent `when` one step more than `end`.'])
             expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
           end
 
           it 'does auto-correction' do
-            corrected = autocorrect_source(cop, source)
+            corrected = autocorrect_source(source)
             expect(corrected).to eq correct_source
           end
         end
@@ -579,10 +580,10 @@ describe RuboCop::Cop::Layout::CaseIndentation do
   context 'when case is preceded by something else than whitespace' do
     let(:cop_config) { {} }
     let(:source) do
-      <<-END.strip_indent
+      <<-RUBY.strip_indent
         case test when something
         end
-      END
+      RUBY
     end
 
     it 'registers an offense' do
@@ -594,7 +595,7 @@ describe RuboCop::Cop::Layout::CaseIndentation do
     end
 
     it "doesn't auto-correct" do
-      expect(autocorrect_source(cop, source))
+      expect(autocorrect_source(source))
         .to eq(source)
       expect(cop.offenses.map(&:corrected?)).to eq [false]
     end
