@@ -1,17 +1,15 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Layout::EmptyLines do
+RSpec.describe RuboCop::Cop::Layout::EmptyLines do
   subject(:cop) { described_class.new }
 
   it 'registers an offense for consecutive empty lines' do
-    inspect_source(cop,
-                   ['test = 5', '', '', '', 'top'])
+    inspect_source(['test = 5', '', '', '', 'top'])
     expect(cop.offenses.size).to eq(2)
   end
 
   it 'auto-corrects consecutive empty lines' do
-    corrected = autocorrect_source(cop,
-                                   ['test = 5', '', '', '', 'top'])
+    corrected = autocorrect_source(['test = 5', '', '', '', 'top'])
     expect(corrected).to eq ['test = 5', '', 'top'].join("\n")
   end
 
@@ -39,7 +37,7 @@ describe RuboCop::Cop::Layout::EmptyLines do
   end
 
   it 'does not register an offense for heredocs with empty lines inside' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       str = <<-TEXT
       line 1
 
@@ -47,6 +45,6 @@ describe RuboCop::Cop::Layout::EmptyLines do
       line 2
       TEXT
       puts str
-    END
+    RUBY
   end
 end
