@@ -1,14 +1,15 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Layout::MultilineArrayBraceLayout, :config do
+RSpec.describe RuboCop::Cop::Layout::MultilineArrayBraceLayout, :config do
   subject(:cop) { described_class.new(config) }
+
   let(:cop_config) { { 'EnforcedStyle' => 'symmetrical' } }
 
   it 'ignores implicit arrays' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       foo = a,
       b
-    END
+    RUBY
   end
 
   it 'ignores single-line arrays' do
