@@ -1,7 +1,8 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
+RSpec.describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
   subject(:cop) { described_class.new(config) }
+
   let(:config) do
     merged = RuboCop::ConfigLoader
              .default_configuration['Layout/MultilineMethodCallIndentation']
@@ -16,14 +17,14 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
 
   shared_examples 'common' do
     it 'accepts indented methods in LHS of []= assignment' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         a
           .b[c] = 0
-      END
+      RUBY
     end
 
     it 'accepts indented methods inside and outside a block' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         a = b.map do |c|
           c
             .b
@@ -32,97 +33,104 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
                 .y
             end
         end
-      END
-      expect(cop.messages).to be_empty
+      RUBY
+      expect(cop.messages.empty?).to be(true)
     end
 
     it 'accepts indentation relative to first receiver' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         node
           .children.map { |n| string_source(n) }.compact
           .any? { |s| preferred.any? { |d| s.include?(d) } }
-      END
+      RUBY
     end
 
     it 'accepts indented methods in ordinary statement' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         a.
           b
-      END
-      expect(cop.messages).to be_empty
+      RUBY
+      expect(cop.messages.empty?).to be(true)
     end
 
     it 'accepts no extra indentation of third line' do
-      inspect_source(cop, <<-END.strip_margin('|'))
+      inspect_source(<<-RUBY.strip_margin('|'))
         |   a.
         |     b.
         |     c
-      END
-      expect(cop.offenses).to be_empty
+      RUBY
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'accepts indented methods in for body' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         for x in a
           something.
             something_else
         end
-      END
-      expect(cop.highlights).to be_empty
+      RUBY
+      expect(cop.highlights.empty?).to be(true)
     end
 
     it 'accepts alignment inside a grouped expression' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         (a.
          b)
-      END
-      expect(cop.messages).to be_empty
+      RUBY
+      expect(cop.messages.empty?).to be(true)
     end
 
     it 'accepts an expression where the first method spans multiple lines' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         subject.each do |item|
           result = resolve(locale) and return result
         end.a
-      END
-      expect(cop.messages).to be_empty
+      RUBY
+      expect(cop.messages.empty?).to be(true)
     end
 
     it 'accepts any indentation of parameters to #[]' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         payment = Models::IncomingPayments[
                 id:      input['incoming-payment-id'],
                    user_id: @user[:id]]
-      END
-      expect(cop.messages).to be_empty
+      RUBY
+      expect(cop.messages.empty?).to be(true)
     end
 
     it "doesn't fail on unary operators" do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         def foo
           !0
           .nil?
         end
-      END
+      RUBY
       expect(cop.offenses.size).to eq(1)
     end
+
+    it "doesn't crash on unaligned multiline lambdas" do
+      expect_no_offenses(<<-RUBY.strip_indent)
+        MyClass.(my_args)
+          .my_method
+      RUBY
+    end
   end
 
   shared_examples 'common for aligned and indented' do
     it 'accepts even indentation of consecutive lines in typical RSpec code' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         expect { Foo.new }.
           to change { Bar.count }.
           from(1).to(2)
-      END
-      expect(cop.messages).to be_empty
+      RUBY
+      expect(cop.messages.empty?).to be(true)
     end
 
     it 'registers an offense for no indentation of second line' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         a.
         b
-      END
+      RUBY
       expect(cop.messages)
         .to eq(['Use 2 (not 0) spaces for indenting an expression spanning ' \
                 'multiple lines.'])
@@ -130,12 +138,12 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     end
 
     it 'registers an offense for 3 spaces indentation of second line' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         a.
            b
         c.
            d
-      END
+      RUBY
       expect(cop.messages)
         .to eq(['Use 2 (not 3) spaces for indenting an expression spanning ' \
                 'multiple lines.'] * 2)
@@ -143,11 +151,11 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     end
 
     it 'registers an offense for extra indentation of third line' do
-      inspect_source(cop, <<-END.strip_margin('|'))
+      inspect_source(<<-RUBY.strip_margin('|'))
         |   a.
         |     b.
         |       c
-      END
+      RUBY
       expect(cop.messages)
         .to eq(['Use 2 (not 4) spaces for indenting an expression spanning ' \
                 'multiple lines.'])
@@ -156,12 +164,12 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
 
     it 'registers an offense for the emacs ruby-mode 1.1 indentation of an ' \
        'expression in an array' do
-      inspect_source(cop, <<-END.strip_margin('|'))
+      inspect_source(<<-RUBY.strip_margin('|'))
         |  [
         |   a.
         |   b
         |  ]
-      END
+      RUBY
       expect(cop.messages)
         .to eq(['Use 2 (not 0) spaces for indenting an expression spanning ' \
                 'multiple lines.'])
@@ -170,31 +178,31 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
 
     it 'registers an offense for extra indentation of 3rd line in typical ' \
        'RSpec code' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         expect { Foo.new }.
           to change { Bar.count }.
               from(1).to(2)
-      END
+      RUBY
       expect(cop.messages).to eq(['Use 2 (not 6) spaces for indenting an ' \
                                   'expression spanning multiple lines.'])
       expect(cop.highlights).to eq(['from'])
     end
 
     it 'registers an offense for proc call without a selector' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         a
          .(args)
-      END
+      RUBY
       expect(cop.messages).to eq(['Use 2 (not 1) spaces for indenting an ' \
                                   'expression spanning multiple lines.'])
       expect(cop.highlights).to eq(['.('])
     end
 
     it 'registers an offense for one space indentation of second line' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         a
          .b
-      END
+      RUBY
       expect(cop.messages).to eq(['Use 2 (not 1) spaces for indenting an ' \
                                   'expression spanning multiple lines.'])
       expect(cop.highlights).to eq(['.b'])
@@ -211,10 +219,10 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     # a chain of calls, and that first dot does not begin its line.
     context 'for semantic alignment' do
       it 'accepts method being aligned with method' do
-        expect_no_offenses(<<-END.strip_indent)
+        expect_no_offenses(<<-RUBY.strip_indent)
           User.all.first
               .age.to_s
-        END
+        RUBY
       end
 
       it 'accepts method being aligned with method that is an argument' do
@@ -226,33 +234,32 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
 
       it 'accepts method being aligned with method that is an argument in ' \
          'assignment' do
-        inspect_source(cop,
-                       ['user = authorize scope.includes(:user)',
+        inspect_source(['user = authorize scope.includes(:user)',
                         '                      .order(:name)'])
-        expect(cop.offenses).to be_empty
+        expect(cop.offenses.empty?).to be(true)
       end
 
       it 'accepts method being aligned with method in assignment' do
-        expect_no_offenses(<<-END.strip_indent)
+        expect_no_offenses(<<-RUBY.strip_indent)
           age = User.all.first
                     .age.to_s
-        END
+        RUBY
       end
 
       it 'accepts aligned method even when an aref is in the chain' do
-        expect_no_offenses(<<-END.strip_indent)
+        expect_no_offenses(<<-RUBY.strip_indent)
           foo = '123'.a
                      .b[1]
                      .c
-        END
+        RUBY
       end
 
       it 'accepts aligned method even when an aref is first in the chain' do
-        expect_no_offenses(<<-END.strip_indent)
+        expect_no_offenses(<<-RUBY.strip_indent)
           foo = '123'[1].a
                         .b
                         .c
-        END
+        RUBY
       end
 
       it "doesn't fail on a chain of aref calls" do
@@ -260,20 +267,20 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
       end
 
       it 'accepts aligned method with blocks in operation assignment' do
-        expect_no_offenses(<<-END.strip_indent)
+        expect_no_offenses(<<-RUBY.strip_indent)
           @comment_lines ||=
             src.comments
                .select { |c| begins_its_line?(c) }
                .map { |c| c.loc.line }
-        END
+        RUBY
       end
 
       it 'accepts 3 aligned methods' do
-        expect_no_offenses(<<-END.strip_indent)
+        expect_no_offenses(<<-RUBY.strip_indent)
           a_class.new(severity, location, 'message', 'CopName')
                  .severity
                  .level
-        END
+        RUBY
       end
 
       it 'registers an offense for unaligned methods' do
@@ -297,39 +304,39 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
       end
 
       it 'auto-corrects' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           User.all.first
             .age.to_s
-        END
-        expect(new_source).to eq(<<-END.strip_indent)
+        RUBY
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           User.all.first
               .age.to_s
-        END
+        RUBY
       end
     end
 
     it 'accepts correctly aligned methods in operands' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         1 + a
             .b
             .c + d.
                  e
-      END
+      RUBY
     end
 
     it 'accepts correctly aligned methods in assignment' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         def investigate(processed_source)
           @modifier = processed_source
                       .tokens
                       .select { |t| t.type == :k }
                       .map(&:pos)
         end
-      END
+      RUBY
     end
 
     it 'accepts aligned methods in if + assignment' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         KeyMap = Hash.new do |map, key|
           value = if key.respond_to?(:to_str)
             key
@@ -340,14 +347,14 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
           end
           keymap_mutex.synchronize { map[key] = value }
         end
-      END
+      RUBY
     end
 
     it 'accepts indented method when there is nothing to align with' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         expect { custom_formatter_class('NonExistentClass') }
           .to raise_error(NameError)
-      END
+      RUBY
     end
 
     it 'registers an offense for one space indentation of third line' do
@@ -362,11 +369,11 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     it 'accepts indented and aligned methods in binary operation' do
       # b is indented relative to a
       # .d is aligned with c
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         a.
           b + c
               .d
-      END
+      RUBY
     end
 
     it 'accepts aligned methods in if condition' do
@@ -381,7 +388,7 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     it 'accepts aligned methods in a begin..end block' do
       expect_no_offenses(<<-RUBY.strip_indent)
         @dependencies ||= begin
-          DEFAULT_DEPENDENCIES
+          DEFAULT_DEPRUBYENCIES
             .reject { |e| e }
             .map { |e| e }
         end
@@ -389,12 +396,12 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     end
 
     it 'registers an offense for misaligned methods in if condition' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         if a.
             b
           something
         end
-      END
+      RUBY
       expect(cop.messages).to eq(['Align `b` with `a.` on line 1.'])
       expect(cop.highlights).to eq(['b'])
       expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
@@ -409,11 +416,11 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     end
 
     it 'does not check binary operations when string wrapped with +' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         flash[:error] = 'Here is a string ' +
                         'That spans' <<
           'multiple lines'
-      END
+      RUBY
     end
 
     it 'registers an offense for misaligned method in []= call' do
@@ -426,12 +433,12 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     end
 
     it 'registers an offense for misaligned methods in unless condition' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         unless a
         .b
           something
         end
-      END
+      RUBY
       expect(cop.messages).to eq(['Align `.b` with `a` on line 1.'])
       expect(cop.highlights).to eq(['.b'])
       expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
@@ -458,21 +465,21 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     end
 
     it 'accepts aligned method in return' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         def a
           return b.
                  c
         end
-      END
+      RUBY
     end
 
     it 'accepts aligned method in assignment + block + assignment' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         a = b do
           c.d = e.
                 f
         end
-      END
+      RUBY
     end
 
     it 'accepts aligned methods in assignment' do
@@ -486,27 +493,27 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
 
     it 'registers an offense for misaligned methods in local variable ' \
        'assignment' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         a = b.c.
          d
-      END
+      RUBY
       expect(cop.messages).to eq(['Align `d` with `b.c.` on line 1.'])
       expect(cop.highlights).to eq(['d'])
     end
 
     it 'accepts aligned methods in constant assignment' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         A = b
             .c
-      END
+      RUBY
     end
 
     it 'accepts aligned methods in operator assignment' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         a +=
           b
           .c
-      END
+      RUBY
     end
 
     it 'registers an offense for unaligned methods in assignment' do
@@ -519,18 +526,18 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     end
 
     it 'auto-corrects' do
-      new_source = autocorrect_source(cop, <<-END.strip_indent)
+      new_source = autocorrect_source(<<-RUBY.strip_indent)
         until a.
             b
           something
         end
-      END
-      expect(new_source).to eq(<<-END.strip_indent)
+      RUBY
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         until a.
               b
           something
         end
-      END
+      RUBY
     end
   end
 
@@ -540,14 +547,14 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     # indented style, it doesn't come into play.
     context 'for possible semantic alignment' do
       it 'accepts indented methods' do
-        inspect_source(cop, <<-END.strip_indent)
+        inspect_source(<<-RUBY.strip_indent)
           User.a
             .c
             .b
-        END
-        expect(cop.messages).to be_empty
-        expect(cop.highlights).to be_empty
-        expect(cop.offenses).to be_empty
+        RUBY
+        expect(cop.messages.empty?).to be(true)
+        expect(cop.highlights.empty?).to be(true)
+        expect(cop.offenses.empty?).to be(true)
       end
     end
   end
@@ -559,13 +566,13 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     include_examples 'both indented* styles'
 
     it 'accepts correctly indented methods in operation' do
-      inspect_source(cop, <<-END.strip_margin('|'))
+      inspect_source(<<-RUBY.strip_margin('|'))
         |        1 + a
         |              .b
         |              .c
-      END
-      expect(cop.highlights).to be_empty
-      expect(cop.offenses).to be_empty
+      RUBY
+      expect(cop.highlights.empty?).to be(true)
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'accepts indentation of consecutive lines in typical RSpec code' do
@@ -585,11 +592,11 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
 
     it 'registers an offense for extra indentation of 3rd line in typical ' \
        'RSpec code' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         expect { Foo.new }.
           to change { Bar.count }.
               from(1).to(2)
-      END
+      RUBY
       expect(cop.messages).to eq(['Indent `from` 2 spaces more than `change ' \
                                   '{ Bar.count }` on line 2.'])
       expect(cop.highlights).to eq(['from'])
@@ -633,30 +640,30 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
 
     it 'registers an offense for the emacs ruby-mode 1.1 indentation of an ' \
        'expression in an array' do
-      inspect_source(cop, <<-END.strip_margin('|'))
+      inspect_source(<<-RUBY.strip_margin('|'))
         |  [
         |   a.
         |   b
         |  ]
-      END
+      RUBY
       expect(cop.messages)
         .to eq(['Indent `b` 2 spaces more than `a` on line 2.'])
       expect(cop.highlights).to eq(['b'])
     end
 
     it 'auto-corrects' do
-      new_source = autocorrect_source(cop, <<-END.strip_indent)
+      new_source = autocorrect_source(<<-RUBY.strip_indent)
         until a.
               b
           something
         end
-      END
-      expect(new_source).to eq(<<-END.strip_indent)
+      RUBY
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         until a.
                 b
           something
         end
-      END
+      RUBY
     end
   end
 
@@ -668,13 +675,13 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     include_examples 'both indented* styles'
 
     it 'accepts correctly indented methods in operation' do
-      inspect_source(cop, <<-END.strip_margin('|'))
+      inspect_source(<<-RUBY.strip_margin('|'))
         |        1 + a
         |          .b
         |          .c
-      END
-      expect(cop.offenses).to be_empty
-      expect(cop.highlights).to be_empty
+      RUBY
+      expect(cop.offenses.empty?).to be(true)
+      expect(cop.highlights.empty?).to be(true)
     end
 
     it 'registers an offense for one space indentation of third line' do
@@ -696,12 +703,12 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     end
 
     it 'registers an offense for aligned methods in if condition' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         if a.
            b
           something
         end
-      END
+      RUBY
       expect(cop.messages).to eq(['Use 4 (not 3) spaces for indenting a ' \
                                   'condition in an `if` statement spanning ' \
                                   'multiple lines.'])
@@ -741,23 +748,23 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
       %w[an until]
     ].each do |article, keyword|
       it "accepts double indentation of #{keyword} condition" do
-        inspect_source(cop, <<-END.strip_indent)
+        inspect_source(<<-RUBY.strip_indent)
           #{keyword} receiver.
               nil? &&
               !args.empty?
           end
-        END
-        expect(cop.messages).to be_empty
+        RUBY
+        expect(cop.messages.empty?).to be(true)
       end
 
       it "registers an offense for a 2 space indentation of #{keyword} " \
          'condition' do
-        inspect_source(cop, <<-END.strip_indent)
+        inspect_source(<<-RUBY.strip_indent)
           #{keyword} receiver
             .nil? &&
             !args.empty?
           end
-        END
+        RUBY
         expect(cop.highlights).to eq(['.nil?'])
         expect(cop.messages).to eq(['Use 4 (not 2) spaces for indenting a ' \
                                     "condition in #{article} `#{keyword}` " \
@@ -765,24 +772,24 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
       end
 
       it "accepts indented methods in #{keyword} body" do
-        inspect_source(cop, <<-END.strip_indent)
+        inspect_source(<<-RUBY.strip_indent)
           #{keyword} a
             something.
               something_else
           end
-        END
-        expect(cop.highlights).to be_empty
+        RUBY
+        expect(cop.highlights.empty?).to be(true)
       end
     end
 
     %w[unless if].each do |keyword|
       it "accepts special indentation of return #{keyword} condition" do
-        inspect_source(cop, <<-END.strip_indent)
+        inspect_source(<<-RUBY.strip_indent)
           return #{keyword} receiver.nil? &&
               !args.empty? &&
               BLACKLIST.include?(method_name)
-        END
-        expect(cop.messages).to be_empty
+        RUBY
+        expect(cop.messages.empty?).to be(true)
       end
     end
 
@@ -815,12 +822,12 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
     end
 
     it 'registers an offense for correct + unrecognized style' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         a.
           b
         c.
             d
-      END
+      RUBY
       expect(cop.messages).to eq(['Use 2 (not 4) spaces for indenting an ' \
                                   'expression spanning multiple lines.'])
       expect(cop.highlights).to eq(%w[d])
@@ -831,49 +838,49 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
       msg = 'Use %d (not %d) spaces for indenting an expression ' \
               'in an assignment spanning multiple lines.'
 
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         formatted_int = int_part
                         .abs
                         ^^^^ #{format(msg, 2, 16)}
                         .reverse
                         ^^^^^^^^ #{format(msg, 2, 16)}
-      END
+      RUBY
     end
 
     it 'auto-corrects' do
-      new_source = autocorrect_source(cop, <<-END.strip_indent)
+      new_source = autocorrect_source(<<-RUBY.strip_indent)
         until a.
               b
           something
         end
-      END
-      expect(new_source).to eq(<<-END.strip_indent)
+      RUBY
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         until a.
             b
           something
         end
-      END
+      RUBY
     end
 
     context 'when indentation width is overridden for this cop' do
       let(:cop_indent) { 7 }
 
       it 'accepts indented methods' do
-        expect_no_offenses(<<-END.strip_indent)
+        expect_no_offenses(<<-RUBY.strip_indent)
           User.a
                  .c
                  .b
-        END
+        RUBY
       end
 
       it 'accepts correctly indented methods in operation' do
-        inspect_source(cop, <<-END.strip_margin('|'))
+        inspect_source(<<-RUBY.strip_margin('|'))
           |        1 + a
           |               .b
           |               .c
-        END
-        expect(cop.offenses).to be_empty
-        expect(cop.highlights).to be_empty
+        RUBY
+        expect(cop.offenses.empty?).to be(true)
+        expect(cop.highlights.empty?).to be(true)
       end
 
       it 'accepts indented methods in if condition' do
@@ -905,23 +912,23 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
           # normal code indentation is 2 spaces, and we have configured
           # multiline method indentation to 7 spaces
           # so in this case, 9 spaces are required
-          inspect_source(cop, <<-END.strip_indent)
+          inspect_source(<<-RUBY.strip_indent)
             #{keyword} receiver.
                      nil? &&
                      !args.empty?
             end
-          END
-          expect(cop.messages).to be_empty
+          RUBY
+          expect(cop.messages.empty?).to be(true)
         end
 
         it "registers an offense for a 4 space indentation of #{keyword} " \
            'condition' do
-          inspect_source(cop, <<-END.strip_indent)
+          inspect_source(<<-RUBY.strip_indent)
             #{keyword} receiver
                 .nil? &&
                 !args.empty?
             end
-          END
+          RUBY
           expect(cop.highlights).to eq(['.nil?'])
           expect(cop.messages).to eq(['Use 9 (not 4) spaces for indenting a ' \
                                       "condition in #{article} `#{keyword}` " \
@@ -929,13 +936,13 @@ describe RuboCop::Cop::Layout::MultilineMethodCallIndentation do
         end
 
         it "accepts indented methods in #{keyword} body" do
-          inspect_source(cop, <<-END.strip_indent)
+          inspect_source(<<-RUBY.strip_indent)
             #{keyword} a
               something.
                      something_else
             end
-          END
-          expect(cop.highlights).to be_empty
+          RUBY
+          expect(cop.highlights.empty?).to be(true)
         end
       end
     end
