@@ -1,29 +1,30 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Layout::MultilineMethodDefinitionBraceLayout, :config do
+RSpec.describe RuboCop::Cop::Layout::MultilineMethodDefinitionBraceLayout, :config do # rubocop:disable Metrics/LineLength
   subject(:cop) { described_class.new(config) }
+
   let(:cop_config) { { 'EnforcedStyle' => 'symmetrical' } }
 
   it 'ignores implicit defs' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       def foo a: 1,
       b: 2
       end
-    END
+    RUBY
   end
 
   it 'ignores single-line defs' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       def foo(a,b)
       end
-    END
+    RUBY
   end
 
   it 'ignores defs without params' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       def foo
       end
-    END
+    RUBY
   end
 
   include_examples 'multiline literal brace layout' do
