@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Layout::SpaceAfterNot do
+RSpec.describe RuboCop::Cop::Layout::SpaceAfterNot do
   subject(:cop) { described_class.new }
 
   it 'reports an offense for space after !' do
@@ -20,7 +20,7 @@ describe RuboCop::Cop::Layout::SpaceAfterNot do
 
   it 'reports an offense for space after ! with the negated receiver ' \
      'wrapped in parentheses' do
-    inspect_source(cop, '! (model)')
+    inspect_source('! (model)')
 
     expect(cop.messages)
       .to eq(['Do not leave space between `!` and its argument.'])
@@ -29,19 +29,19 @@ describe RuboCop::Cop::Layout::SpaceAfterNot do
 
   context 'auto-correct' do
     it 'removes redundant space' do
-      new_source = autocorrect_source(cop, '!  something')
+      new_source = autocorrect_source('!  something')
 
       expect(new_source).to eq('!something')
     end
 
     it 'keeps space after not keyword' do
-      new_source = autocorrect_source(cop, 'not something')
+      new_source = autocorrect_source('not something')
 
       expect(new_source).to eq('not something')
     end
 
     it 'removes redundant space when there is a parentheses' do
-      new_source = autocorrect_source(cop, '!  (model)')
+      new_source = autocorrect_source('!  (model)')
 
       expect(new_source).to eq('!(model)')
     end
