@@ -1,7 +1,8 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Layout::SpaceAroundOperators do
+RSpec.describe RuboCop::Cop::Layout::SpaceAroundOperators do
   subject(:cop) { described_class.new(config) }
+
   let(:config) do
     RuboCop::Config
       .new(
@@ -91,12 +92,12 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
   end
 
   it 'accepts an assignment by `for` statement' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       for a in [] do; end
       for A in [] do; end
       for @a in [] do; end
       for @@a in [] do; end
-    END
+    RUBY
   end
 
   it 'accepts an operator called with method syntax' do
@@ -140,14 +141,14 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
   end
 
   it 'auto-corrects unwanted space around **' do
-    new_source = autocorrect_source(cop, <<-END.strip_indent)
+    new_source = autocorrect_source(<<-RUBY.strip_indent)
       x = a * b ** 2
       y = a * b** 2
-    END
-    expect(new_source).to eq(<<-END.strip_indent)
+    RUBY
+    expect(new_source).to eq(<<-RUBY.strip_indent)
       x = a * b**2
       y = a * b**2
-    END
+    RUBY
   end
 
   it 'accepts exponent operator without spaces' do
@@ -195,21 +196,21 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
   describe 'missing space around operators' do
     shared_examples 'modifier with missing space' do |keyword|
       it "registers an offense in presence of modifier #{keyword} statement" do
-        src = <<-END.strip_indent
+        src = <<-RUBY.strip_indent
           a=1 #{keyword} condition
           c=2
-        END
-        inspect_source(cop, src)
+        RUBY
+        inspect_source(src)
         expect(cop.offenses.map(&:line)).to eq([1, 2])
         expect(cop.messages).to eq(
           ['Surrounding space missing for operator `=`.'] * 2
         )
 
-        new_source = autocorrect_source(cop, src)
-        expect(new_source).to eq(<<-END.strip_indent)
+        new_source = autocorrect_source(src)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           a = 1 #{keyword} condition
           c = 2
-        END
+        RUBY
       end
     end
 
@@ -225,7 +226,7 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
     end
 
     it 'auto-corrects assignment without space on both sides' do
-      new_source = autocorrect_source(cop, ['x=0', 'y= 0', 'z =0'])
+      new_source = autocorrect_source(['x=0', 'y= 0', 'z =0'])
       expect(new_source).to eq(['x = 0', 'y = 0', 'z = 0'].join("\n"))
     end
 
@@ -255,7 +256,7 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
       end
 
       it 'auto-corrects a ternary operator without space' do
-        new_source = autocorrect_source(cop, 'x == 0?1:2')
+        new_source = autocorrect_source('x == 0?1:2')
         expect(new_source).to eq('x == 0 ? 1 : 2')
       end
     end
@@ -277,7 +278,7 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
     end
 
     it 'auto-corrects missing space in binary operators that could be unary' do
-      new_source = autocorrect_source(cop, ['a-3', 'x&0xff', 'z+0'])
+      new_source = autocorrect_source(['a-3', 'x&0xff', 'z+0'])
       expect(new_source).to eq(['a - 3', 'x & 0xff', 'z + 0'].join("\n"))
     end
 
@@ -289,12 +290,12 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
     end
 
     it 'auto-corrects missing space in arguments to a method' do
-      new_source = autocorrect_source(cop, 'puts 1+2')
+      new_source = autocorrect_source('puts 1+2')
       expect(new_source).to eq('puts 1 + 2')
     end
 
     it 'registers an offense for operators without spaces' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         x+= a+b-c*d/e%f^g|h&i||j
          ^^ Surrounding space missing for operator `+=`.
              ^ Surrounding space missing for operator `+`.
@@ -309,18 +310,18 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
         y -=k&&l
           ^^ Surrounding space missing for operator `-=`.
              ^^ Surrounding space missing for operator `&&`.
-      END
+      RUBY
     end
 
     it 'auto-corrects missing space' do
-      new_source = autocorrect_source(cop, <<-END.strip_indent)
+      new_source = autocorrect_source(<<-RUBY.strip_indent)
         x+= a+b-c*d/e%f^g|h&i||j
         y -=k&&l
-      END
-      expect(new_source).to eq(<<-END.strip_indent)
+      RUBY
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         x += a + b - c * d / e % f ^ g | h & i || j
         y -= k && l
-      END
+      RUBY
     end
 
     it 'registers an offense for a setter call without spaces' do
@@ -331,7 +332,7 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
     end
 
     context 'when a hash literal is on a single line' do
-      before { inspect_source(cop, '{ 1=>2, a: b }') }
+      before { inspect_source('{ 1=>2, a: b }') }
 
       context 'and Layout/AlignHash:EnforcedHashRocketStyle is key' do
         let(:hash_style) { 'key' }
@@ -354,12 +355,12 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
 
     context 'when a hash literal is on multiple lines' do
       before do
-        inspect_source(cop, <<-END.strip_indent)
+        inspect_source(<<-RUBY.strip_indent)
           {
             1=>2,
             a: b
           }
-        END
+        RUBY
       end
 
       context 'and Layout/AlignHash:EnforcedHashRocketStyle is key' do
@@ -386,16 +387,16 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
     end
 
     it 'registers an offense for match operators without space' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         x=~/abc/
          ^^ Surrounding space missing for operator `=~`.
         y !~/abc/
           ^^ Surrounding space missing for operator `!~`.
-      END
+      RUBY
     end
 
     it 'registers an offense for various assignments without space' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         x||=0
          ^^^ Surrounding space missing for operator `||=`.
         y&&=0
@@ -416,7 +417,7 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
           ^ Surrounding space missing for operator `=`.
         A||=0
          ^^^ Surrounding space missing for operator `||=`.
-      END
+      RUBY
     end
 
     it 'registers an offense for equality operators without space' do
@@ -438,87 +439,87 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
     end
 
     it 'registers an offense for inheritance < without space' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         class ShowSourceTestClass<ShowSourceTestSuperClass
                                  ^ Surrounding space missing for operator `<`.
         end
-      END
+      RUBY
     end
 
     it 'registers an offense for hash rocket without space at rescue' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         begin
         rescue Exception=>e
                         ^^ Surrounding space missing for operator `=>`.
         end
-      END
+      RUBY
     end
 
     it "doesn't eat a newline when auto-correcting" do
-      new_source = autocorrect_source(cop, <<-END.strip_indent)
+      new_source = autocorrect_source(<<-RUBY.strip_indent)
         'Here is a'+
         'joined string'+
         'across three lines'
-      END
-      expect(new_source).to eq(<<-END.strip_indent)
+      RUBY
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         'Here is a' +
         'joined string' +
         'across three lines'
-      END
+      RUBY
     end
 
     it "doesn't register an offense for operators with newline on right" do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         'Here is a' +
         'joined string' +
         'across three lines'
-      END
+      RUBY
     end
   end
 
   describe 'extra space around operators' do
     shared_examples 'modifier with extra space' do |keyword|
       it "registers an offense in presence of modifier #{keyword} statement" do
-        src = <<-END.strip_indent
+        src = <<-RUBY.strip_indent
           a =  1 #{keyword} condition
           c =   2
-        END
-        inspect_source(cop, src)
+        RUBY
+        inspect_source(src)
         expect(cop.offenses.map(&:line)).to eq([1, 2])
         expect(cop.messages).to eq(
           ['Operator `=` should be surrounded by a single space.'] * 2
         )
 
-        new_source = autocorrect_source(cop, src)
-        expect(new_source).to eq(<<-END.strip_indent)
+        new_source = autocorrect_source(src)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           a = 1 #{keyword} condition
           c = 2
-        END
+        RUBY
       end
     end
 
     it 'registers an offense for assignment with many spaces on either side' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         x   = 0
             ^ Operator `=` should be surrounded by a single space.
         y +=   0
           ^^ Operator `+=` should be surrounded by a single space.
         z[0]  =  0
               ^ Operator `=` should be surrounded by a single space.
-      END
+      RUBY
     end
 
     it 'auto-corrects assignment with too many spaces on either side' do
-      new_source = autocorrect_source(cop, <<-END.strip_indent)
+      new_source = autocorrect_source(<<-RUBY.strip_indent)
         x  = 0
         y =   0
         z  =   0
-      END
-      expect(new_source).to eq(<<-END.strip_indent)
+      RUBY
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         x = 0
         y = 0
         z = 0
-      END
+      RUBY
     end
 
     it 'registers an offense for ternary operator with too many spaces' do
@@ -530,7 +531,7 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
     end
 
     it 'auto-corrects a ternary operator too many spaces' do
-      new_source = autocorrect_source(cop, 'x == 0  ? 1 :  2')
+      new_source = autocorrect_source('x == 0  ? 1 :  2')
       expect(new_source).to eq('x == 0 ? 1 : 2')
     end
 
@@ -540,27 +541,27 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
     it_behaves_like 'modifier with extra space', 'until'
 
     it 'registers an offense for binary operators that could be unary' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         a -  3
           ^ Operator `-` should be surrounded by a single space.
         x &   0xff
           ^ Operator `&` should be surrounded by a single space.
         z +  0
           ^ Operator `+` should be surrounded by a single space.
-      END
+      RUBY
     end
 
     it 'auto-corrects missing space in binary operators that could be unary' do
-      new_source = autocorrect_source(cop, <<-END.strip_indent)
+      new_source = autocorrect_source(<<-RUBY.strip_indent)
         a -  3
         x &   0xff
         z +  0
-      END
-      expect(new_source).to eq(<<-END.strip_indent)
+      RUBY
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         a - 3
         x & 0xff
         z + 0
-      END
+      RUBY
     end
 
     it 'registers an offense for arguments to a method' do
@@ -571,12 +572,12 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
     end
 
     it 'auto-corrects missing space in arguments to a method' do
-      new_source = autocorrect_source(cop, 'puts 1 +  2')
+      new_source = autocorrect_source('puts 1 +  2')
       expect(new_source).to eq('puts 1 + 2')
     end
 
     it 'registers an offense for operators with too many spaces' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         x +=  a
           ^^ Operator `+=` should be surrounded by a single space.
         a  + b
@@ -600,21 +601,20 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
         y  -=  k   &&        l
            ^^ Operator `-=` should be surrounded by a single space.
                    ^^ Operator `&&` should be surrounded by a single space.
-      END
+      RUBY
     end
 
     it 'auto-corrects missing space' do
       new_source = autocorrect_source(
-        cop,
-        <<-END.strip_indent
+        <<-RUBY.strip_indent
           x +=  a  + b -  c  * d /  e  % f  ^ g   | h &  i  ||  j
           y  -=  k   &&        l
-        END
+        RUBY
       )
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         x += a + b - c * d / e % f ^ g | h & i || j
         y -= k && l
-      END
+      RUBY
     end
 
     it 'registers an offense for a setter call with too many spaces' do
@@ -633,11 +633,11 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
 
     it 'registers an offense for a hash rocket with an extra space' \
       'on multiple line' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         {
           1 =>  2
         }
-      END
+      RUBY
       expect(cop.messages).to eq(
         ['Operator `=>` should be surrounded by a single space.']
       )
@@ -645,40 +645,40 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
 
     it 'accepts for a hash rocket with an extra space for alignment' \
       'on multiple line' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         {
           1 =>  2,
           11 => 3
         }
-      END
-      expect(cop.offenses).to be_empty
+      RUBY
+      expect(cop.offenses.empty?).to be(true)
     end
 
     context 'when does not allowed for alignment' do
       let(:allow_for_alignment) { false }
 
       it 'accepts an extra space' do
-        expect_offense(<<-END.strip_indent)
+        expect_offense(<<-RUBY.strip_indent)
           {
             1 =>  2,
               ^^ Operator `=>` should be surrounded by a single space.
             11 => 3
           }
-        END
+        RUBY
       end
     end
 
     it 'registers an offense for match operators with too many spaces' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         x  =~ /abc/
            ^^ Operator `=~` should be surrounded by a single space.
         y !~   /abc/
           ^^ Operator `!~` should be surrounded by a single space.
-      END
+      RUBY
     end
 
     it 'registers an offense for various assignments with too many spaces' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         x ||=  0
           ^^^ Operator `||=` should be surrounded by a single space.
         y  &&=  0
@@ -701,7 +701,7 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
            ^^^ Operator `||=` should be surrounded by a single space.
         A  +=    0
            ^^ Operator `+=` should be surrounded by a single space.
-      END
+      RUBY
     end
 
     it 'registers an offense for equality operators with too many spaces' do
@@ -717,26 +717,26 @@ describe RuboCop::Cop::Layout::SpaceAroundOperators do
 
     it 'registers an offense for - with too many spaces with ' \
        'negative lhs operand' do
-      inspect_source(cop, '-1  - arg')
+      inspect_source('-1  - arg')
       expect(cop.messages)
         .to eq(['Operator `-` should be surrounded by a single space.'])
     end
 
     it 'registers an offense for inheritance < with too many spaces' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         class Foo  <  Bar
                    ^ Operator `<` should be surrounded by a single space.
         end
-      END
+      RUBY
     end
 
     it 'registers an offense for hash rocket with too many spaces at rescue' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         begin
         rescue Exception   =>      e
                            ^^ Operator `=>` should be surrounded by a single space.
         end
-      END
+      RUBY
     end
   end
 end
