@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Layout::SpaceBeforeComma do
+RSpec.describe RuboCop::Cop::Layout::SpaceBeforeComma do
   subject(:cop) { described_class.new }
 
   it 'registers an offense for block argument with space before comma' do
@@ -29,14 +29,12 @@ describe RuboCop::Cop::Layout::SpaceBeforeComma do
   end
 
   it 'auto-corrects space before comma' do
-    new_source = autocorrect_source(cop,
-                                    'each { |s , t| a(1 , formats[0 , 1])}')
+    new_source = autocorrect_source('each { |s , t| a(1 , formats[0 , 1])}')
     expect(new_source).to eq('each { |s, t| a(1, formats[0, 1])}')
   end
 
   it 'handles more than one space before a comma' do
-    new_source = autocorrect_source(cop,
-                                    'each { |s  , t| a(1  , formats[0  , 1])}')
+    new_source = autocorrect_source('each { |s  , t| a(1  , formats[0  , 1])}')
     expect(new_source).to eq('each { |s, t| a(1, formats[0, 1])}')
   end
 end
