@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Layout::SpaceBeforeComment do
+RSpec.describe RuboCop::Cop::Layout::SpaceBeforeComment do
   subject(:cop) { described_class.new }
 
   it 'registers an offense for missing space before an EOL comment' do
@@ -19,15 +19,15 @@ describe RuboCop::Cop::Layout::SpaceBeforeComment do
   end
 
   it 'accepts a doc comment' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       =begin
       Doc comment
       =end
-    END
+    RUBY
   end
 
   it 'auto-corrects missing space' do
-    new_source = autocorrect_source(cop, 'a += 1# increment')
+    new_source = autocorrect_source('a += 1# increment')
     expect(new_source).to eq('a += 1 # increment')
   end
 end
