@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Lint::AmbiguousRegexpLiteral do
+RSpec.describe RuboCop::Cop::Lint::AmbiguousRegexpLiteral do
   subject(:cop) { described_class.new }
 
   context 'with a regexp literal in the first argument' do
@@ -8,7 +8,7 @@ describe RuboCop::Cop::Lint::AmbiguousRegexpLiteral do
       let(:source) { 'p /pattern/' }
 
       it 'registers an offense' do
-        inspect_source(cop, source)
+        inspect_source(source)
         expect(cop.offenses.size).to eq(1)
         expect(cop.offenses.first.message).to eq(
           'Ambiguous regexp literal. Parenthesize the method arguments ' \
