@@ -1,52 +1,53 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Lint::BlockAlignment, :config do
+RSpec.describe RuboCop::Cop::Lint::BlockAlignment, :config do
   subject(:cop) { described_class.new(config) }
+
   let(:cop_config) do
     { 'EnforcedStyleAlignWith' => 'either' }
   end
 
   context 'when the block has no arguments' do
     it 'registers an offense for mismatched block end' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         test do
           end
           ^^^ `end` at 2, 2 is not aligned with `test do` at 1, 0.
-      END
+      RUBY
     end
 
     it 'auto-corrects alignment' do
-      new_source = autocorrect_source(cop, <<-END.strip_indent)
+      new_source = autocorrect_source(<<-RUBY.strip_indent)
         test do
           end
-      END
+      RUBY
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         test do
         end
-      END
+      RUBY
     end
   end
 
   context 'when the block has arguments' do
     it 'registers an offense for mismatched block end' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         test do |ala|
           end
           ^^^ `end` at 2, 2 is not aligned with `test do |ala|` at 1, 0.
-      END
+      RUBY
     end
 
     it 'auto-corrects alignment' do
-      new_source = autocorrect_source(cop, <<-END.strip_indent)
+      new_source = autocorrect_source(<<-RUBY.strip_indent)
         test do |ala|
           end
-      END
+      RUBY
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         test do |ala|
         end
-      END
+      RUBY
     end
   end
 
@@ -59,108 +60,107 @@ describe RuboCop::Cop::Lint::BlockAlignment, :config do
 
   context 'when the block is a logical operand' do
     it 'accepts a correctly aligned block end' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         (value.is_a? Array) && value.all? do |subvalue|
           type_check_value(subvalue, array_type)
         end
         a || b do
         end
-      END
+      RUBY
     end
   end
 
   it 'accepts end aligned with a variable' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       variable = test do |ala|
       end
-    END
+    RUBY
   end
 
   context 'when there is an assignment chain' do
     it 'registers an offense for an end aligned with the 2nd variable' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         a = b = c = test do |ala|
             end
             ^^^ `end` at 2, 4 is not aligned with `a = b = c = test do |ala|` at 1, 0.
-      END
+      RUBY
     end
 
     it 'accepts end aligned with the first variable' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         a = b = c = test do |ala|
         end
-      END
+      RUBY
     end
 
     it 'auto-corrects alignment to the first variable' do
-      new_source = autocorrect_source(cop, <<-END.strip_indent)
+      new_source = autocorrect_source(<<-RUBY.strip_indent)
         a = b = c = test do |ala|
             end
-      END
+      RUBY
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         a = b = c = test do |ala|
         end
-      END
+      RUBY
     end
   end
 
   context 'and the block is an operand' do
     it 'accepts end aligned with a variable' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         b = 1 + preceding_line.reduce(0) do |a, e|
           a + e.length + newline_length
         end + 1
-      END
+      RUBY
     end
   end
 
   it 'registers an offense for mismatched block end with a variable' do
-    expect_offense(<<-END.strip_indent)
+    expect_offense(<<-RUBY.strip_indent)
       variable = test do |ala|
         end
         ^^^ `end` at 2, 2 is not aligned with `variable = test do |ala|` at 1, 0.
-    END
+    RUBY
   end
 
   context 'when the block is defined on the next line' do
     it 'accepts end aligned with the block expression' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         variable =
           a_long_method_that_dont_fit_on_the_line do |v|
             v.foo
           end
-      END
+      RUBY
     end
 
     it 'registers an offenses for mismatched end alignment' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         variable =
           a_long_method_that_dont_fit_on_the_line do |v|
             v.foo
         end
         ^^^ `end` at 4, 0 is not aligned with `a_long_method_that_dont_fit_on_the_line do |v|` at 2, 2.
-      END
+      RUBY
     end
 
     it 'auto-corrects alignment' do
       new_source = autocorrect_source(
-        cop,
-        <<-END.strip_indent
+        <<-RUBY.strip_indent
           variable =
             a_long_method_that_dont_fit_on_the_line do |v|
               v.foo
           end
-        END
+        RUBY
       )
 
       expect(new_source)
-        .to eq(<<-END.strip_indent)
+        .to eq(<<-RUBY.strip_indent)
           variable =
             a_long_method_that_dont_fit_on_the_line do |v|
               v.foo
             end
-        END
+        RUBY
     end
   end
 
@@ -183,7 +183,7 @@ describe RuboCop::Cop::Lint::BlockAlignment, :config do
     end
 
     it 'registers offenses for misaligned ends' do
-      src = <<-END.strip_indent
+      src = <<-RUBY.strip_indent
         def foo(bar)
           bar.get_stuffs
               .reject do |stuff|
@@ -195,8 +195,8 @@ describe RuboCop::Cop::Lint::BlockAlignment, :config do
                 stuff.another_very_long_expression_that_doesnt_fit_the_line
                 end
         end
-      END
-      inspect_source(cop, src)
+      RUBY
+      inspect_source(src)
       expect(cop.messages)
         .to eq(['`end` at 5, 8 is not aligned with `bar.get_stuffs` at 2, 2' \
                 ' or `.reject do |stuff|` at 3, 6.',
@@ -240,7 +240,7 @@ describe RuboCop::Cop::Lint::BlockAlignment, :config do
     end
 
     it 'auto-corrects misaligned ends with the start of the expression' do
-      src = <<-END.strip_indent
+      src = <<-RUBY.strip_indent
         def foo(bar)
           bar.get_stuffs
               .reject do |stuff|
@@ -252,9 +252,9 @@ describe RuboCop::Cop::Lint::BlockAlignment, :config do
                 stuff.another_very_long_expression_that_doesnt_fit_the_line
                 end
         end
-      END
+      RUBY
 
-      aligned_src = <<-END.strip_indent
+      aligned_src = <<-RUBY.strip_indent
         def foo(bar)
           bar.get_stuffs
               .reject do |stuff|
@@ -266,9 +266,9 @@ describe RuboCop::Cop::Lint::BlockAlignment, :config do
                 stuff.another_very_long_expression_that_doesnt_fit_the_line
           end
         end
-      END
+      RUBY
 
-      new_source = autocorrect_source(cop, src)
+      new_source = autocorrect_source(src)
       expect(new_source).to eq(aligned_src)
     end
   end
@@ -284,131 +284,131 @@ describe RuboCop::Cop::Lint::BlockAlignment, :config do
     end
 
     it 'registers an offense for end aligned with the block' do
-      src = <<-END.strip_indent
+      src = <<-RUBY.strip_indent
         e,
         f = [5, 6].map do |i|
           i - 5
             end
-      END
-      inspect_source(cop, src)
+      RUBY
+      inspect_source(src)
       expect(cop.messages)
         .to eq(['`end` at 4, 4 is not aligned with `e,` at 1, 0 or' \
                 ' `f = [5, 6].map do |i|` at 2, 0.'])
     end
 
     it 'auto-corrects' do
-      src = <<-END.strip_indent
+      src = <<-RUBY.strip_indent
         e,
         f = [5, 6].map do |i|
           i - 5
             end
-      END
-      corrected = <<-END.strip_indent
+      RUBY
+      corrected = <<-RUBY.strip_indent
         e,
         f = [5, 6].map do |i|
           i - 5
         end
-      END
-      new_source = autocorrect_source(cop, src)
+      RUBY
+      new_source = autocorrect_source(src)
       expect(new_source).to eq(corrected)
     end
   end
 
   it 'accepts end aligned with an instance variable' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       @variable = test do |ala|
       end
-    END
+    RUBY
   end
 
   it 'registers an offense for mismatched block end with' \
      ' an instance variable' do
-    inspect_source(cop, <<-END.strip_indent)
+    inspect_source(<<-RUBY.strip_indent)
       @variable = test do |ala|
         end
-    END
+    RUBY
     expect(cop.messages)
       .to eq(['`end` at 2, 2 is not aligned with `@variable = test do |ala|`' \
               ' at 1, 0.'])
   end
 
   it 'accepts end aligned with a class variable' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       @@variable = test do |ala|
       end
-    END
+    RUBY
   end
 
   it 'registers an offense for mismatched block end with a class variable' do
-    expect_offense(<<-END.strip_indent)
+    expect_offense(<<-RUBY.strip_indent)
       @@variable = test do |ala|
         end
         ^^^ `end` at 2, 2 is not aligned with `@@variable = test do |ala|` at 1, 0.
-    END
+    RUBY
   end
 
   it 'accepts end aligned with a global variable' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       $variable = test do |ala|
       end
-    END
+    RUBY
   end
 
   it 'registers an offense for mismatched block end with a global variable' do
-    expect_offense(<<-END.strip_indent)
+    expect_offense(<<-RUBY.strip_indent)
       $variable = test do |ala|
         end
         ^^^ `end` at 2, 2 is not aligned with `$variable = test do |ala|` at 1, 0.
-    END
+    RUBY
   end
 
   it 'accepts end aligned with a constant' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       CONSTANT = test do |ala|
       end
-    END
+    RUBY
   end
 
   it 'registers an offense for mismatched block end with a constant' do
-    expect_offense(<<-END.strip_indent)
+    expect_offense(<<-RUBY.strip_indent)
       Module::CONSTANT = test do |ala|
         end
         ^^^ `end` at 2, 2 is not aligned with `Module::CONSTANT = test do |ala|` at 1, 0.
-    END
+    RUBY
   end
 
   it 'accepts end aligned with a method call' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       parser.children << lambda do |token|
         token << 1
       end
-    END
+    RUBY
   end
 
   it 'registers an offense for mismatched block end with a method call' do
-    expect_offense(<<-END.strip_indent)
+    expect_offense(<<-RUBY.strip_indent)
       parser.children << lambda do |token|
         token << 1
         end
         ^^^ `end` at 3, 2 is not aligned with `parser.children << lambda do |token|` at 1, 0.
-    END
+    RUBY
   end
 
   it 'accepts end aligned with a method call with arguments' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       @h[:f] = f.each_pair.map do |f, v|
         v = 1
       end
-    END
+    RUBY
   end
 
   it 'registers an offense for mismatched end with a method call' \
      ' with arguments' do
-    inspect_source(cop, <<-END.strip_indent)
+    inspect_source(<<-RUBY.strip_indent)
       @h[:f] = f.each_pair.map do |f, v|
         v = 1
         end
-    END
+    RUBY
     expect(cop.messages)
       .to eq(['`end` at 3, 2 is not aligned with' \
               ' `@h[:f] = f.each_pair.map do |f, v|` at 1, 0.'])
@@ -419,95 +419,95 @@ describe RuboCop::Cop::Lint::BlockAlignment, :config do
   end
 
   it 'accepts end aligned with the block when the block is a method argument' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       expect(arr.all? do |o|
                o.valid?
              end)
-    END
+    RUBY
   end
 
   it 'registers an offense for mismatched end not aligned with the block' \
      ' that is an argument' do
-    inspect_source(cop, <<-END.strip_indent)
+    inspect_source(<<-RUBY.strip_indent)
       expect(arr.all? do |o|
         o.valid?
         end)
-    END
+    RUBY
     expect(cop.messages)
       .to eq(['`end` at 3, 2 is not aligned with `arr.all? do |o|` at 1, 7 or' \
               ' `expect(arr.all? do |o|` at 1, 0.'])
   end
 
   it 'accepts end aligned with an op-asgn (+=, -=)' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       rb += files.select do |file|
         file << something
       end
-    END
+    RUBY
   end
 
   it 'registers an offense for mismatched block end with an op-asgn (+=, -=)' do
-    expect_offense(<<-END.strip_indent)
+    expect_offense(<<-RUBY.strip_indent)
       rb += files.select do |file|
         file << something
         end
         ^^^ `end` at 3, 2 is not aligned with `rb` at 1, 0.
-    END
+    RUBY
   end
 
   it 'accepts end aligned with an and-asgn (&&=)' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       variable &&= test do |ala|
       end
-    END
+    RUBY
   end
 
   it 'registers an offense for mismatched block end with an and-asgn (&&=)' do
-    expect_offense(<<-END.strip_indent)
+    expect_offense(<<-RUBY.strip_indent)
       variable &&= test do |ala|
         end
         ^^^ `end` at 2, 2 is not aligned with `variable &&= test do |ala|` at 1, 0.
-    END
+    RUBY
   end
 
   it 'accepts end aligned with an or-asgn (||=)' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       variable ||= test do |ala|
       end
-    END
+    RUBY
   end
 
   it 'registers an offense for mismatched block end with an or-asgn (||=)' do
-    expect_offense(<<-END.strip_indent)
+    expect_offense(<<-RUBY.strip_indent)
       variable ||= test do |ala|
         end
         ^^^ `end` at 2, 2 is not aligned with `variable ||= test do |ala|` at 1, 0.
-    END
+    RUBY
   end
 
   it 'accepts end aligned with a mass assignment' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       var1, var2 = lambda do |test|
         [1, 2]
       end
-    END
+    RUBY
   end
 
   it 'accepts end aligned with a call chain left hand side' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       parser.diagnostics.consumer = lambda do |diagnostic|
         diagnostics << diagnostic
       end
-    END
+    RUBY
   end
 
   it 'registers an offense for mismatched block end with a mass assignment' do
-    expect_offense(<<-END.strip_indent)
+    expect_offense(<<-RUBY.strip_indent)
       var1, var2 = lambda do |test|
         [1, 2]
         end
         ^^^ `end` at 3, 2 is not aligned with `var1, var2` at 1, 0.
-    END
+    RUBY
   end
 
   context 'when multiple similar-looking blocks have misaligned ends' do
@@ -525,139 +525,139 @@ describe RuboCop::Cop::Lint::BlockAlignment, :config do
 
   context 'on a splatted method call' do
     it 'aligns end with the splat operator' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         def get_gems_by_name
           @gems ||= Hash[*get_latest_gems.map { |gem|
                            [gem.name, gem, gem.full_name, gem]
                          }.flatten]
         end
-      END
+      RUBY
     end
 
     it 'autocorrects' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         def get_gems_by_name
           @gems ||= Hash[*get_latest_gems.map { |gem|
                            [gem.name, gem, gem.full_name, gem]
                       }.flatten]
         end
-      END
-      corrected = <<-END.strip_indent
+      RUBY
+      corrected = <<-RUBY.strip_indent
         def get_gems_by_name
           @gems ||= Hash[*get_latest_gems.map { |gem|
                            [gem.name, gem, gem.full_name, gem]
                          }.flatten]
         end
-      END
+      RUBY
 
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(corrected)
     end
   end
 
   context 'on a bit-flipped method call' do
     it 'aligns end with the ~ operator' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         def abc
           @abc ||= A[~xyz { |x|
                        x
                      }.flatten]
         end
-      END
+      RUBY
     end
 
     it 'autocorrects' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         def abc
           @abc ||= A[~xyz { |x|
                        x
                                 }.flatten]
         end
-      END
-      corrected = <<-END.strip_indent
+      RUBY
+      corrected = <<-RUBY.strip_indent
         def abc
           @abc ||= A[~xyz { |x|
                        x
                      }.flatten]
         end
-      END
+      RUBY
 
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(corrected)
     end
   end
 
   context 'on a logically negated method call' do
     it 'aligns end with the ! operator' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         def abc
           @abc ||= A[!xyz { |x|
                        x
                      }.flatten]
         end
-      END
+      RUBY
     end
 
     it 'autocorrects' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         def abc
           @abc ||= A[!xyz { |x|
                        x
         }.flatten]
         end
-      END
-      corrected = <<-END.strip_indent
+      RUBY
+      corrected = <<-RUBY.strip_indent
         def abc
           @abc ||= A[!xyz { |x|
                        x
                      }.flatten]
         end
-      END
+      RUBY
 
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(corrected)
     end
   end
 
   context 'on an arithmetically negated method call' do
     it 'aligns end with the - operator' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         def abc
           @abc ||= A[-xyz { |x|
                        x
                      }.flatten]
         end
-      END
+      RUBY
     end
 
     it 'autocorrects' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         def abc
           @abc ||= A[-xyz { |x|
                        x
                           }.flatten]
         end
-      END
-      corrected = <<-END.strip_indent
+      RUBY
+      corrected = <<-RUBY.strip_indent
         def abc
           @abc ||= A[-xyz { |x|
                        x
                      }.flatten]
         end
-      END
+      RUBY
 
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(corrected)
     end
   end
 
   context 'when the block is terminated by }' do
     it 'mentions } (not end) in the message' do
-      expect_offense(<<-END.strip_indent)
+      expect_offense(<<-RUBY.strip_indent)
         test {
           }
           ^ `}` at 2, 2 is not aligned with `test {` at 1, 0.
-      END
+      RUBY
     end
   end
 
@@ -676,33 +676,33 @@ describe RuboCop::Cop::Lint::BlockAlignment, :config do
     end
 
     it 'errors when do aligned' do
-      src = <<-END.strip_indent
+      src = <<-RUBY.strip_indent
         foo.bar
           .each do
             baz
           end
-      END
-      inspect_source(cop, src)
+      RUBY
+      inspect_source(src)
       expect(cop.messages)
         .to eq(['`end` at 4, 2 is not aligned with ' \
                 '`foo.bar` at 1, 0.'])
     end
 
     it 'autocorrects' do
-      src = <<-END.strip_indent
+      src = <<-RUBY.strip_indent
         foo.bar
           .each do
             baz
           end
-      END
-      corrected = <<-END.strip_indent
+      RUBY
+      corrected = <<-RUBY.strip_indent
         foo.bar
           .each do
             baz
         end
-      END
+      RUBY
 
-      new_source = autocorrect_source(cop, src)
+      new_source = autocorrect_source(src)
       expect(new_source).to eq(corrected)
     end
   end
@@ -722,33 +722,33 @@ describe RuboCop::Cop::Lint::BlockAlignment, :config do
     end
 
     it 'errors when start_of_line aligned' do
-      src = <<-END.strip_indent
+      src = <<-RUBY.strip_indent
         foo.bar
           .each do
             baz
         end
-      END
-      inspect_source(cop, src)
+      RUBY
+      inspect_source(src)
       expect(cop.messages)
         .to eq(['`end` at 4, 0 is not aligned with ' \
                 '`.each do` at 2, 2.'])
     end
 
     it 'autocorrects' do
-      src = <<-END.strip_indent
+      src = <<-RUBY.strip_indent
         foo.bar
           .each do
             baz
         end
-      END
-      corrected = <<-END.strip_indent
+      RUBY
+      corrected = <<-RUBY.strip_indent
         foo.bar
           .each do
             baz
           end
-      END
+      RUBY
 
-      new_source = autocorrect_source(cop, src)
+      new_source = autocorrect_source(src)
       expect(new_source).to eq(corrected)
     end
   end
