@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Lint::EachWithObjectArgument do
+RSpec.describe RuboCop::Cop::Lint::EachWithObjectArgument do
   subject(:cop) { described_class.new }
 
   it 'registers an offense for fixnum argument' do
