@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Lint::ElseLayout do
+RSpec.describe RuboCop::Cop::Lint::ElseLayout do
   subject(:cop) { described_class.new }
 
   it 'registers an offense for expr on same line as else' do
@@ -16,23 +16,23 @@ describe RuboCop::Cop::Lint::ElseLayout do
   end
 
   it 'accepts proper else' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       if something
         test
       else
         something
         test
       end
-    END
+    RUBY
   end
 
   it 'accepts single-expr else regardless of layout' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       if something
         test
       else bala
       end
-    END
+    RUBY
   end
 
   it 'can handle elsifs' do
