@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Lint::EnsureReturn do
+RSpec.describe RuboCop::Cop::Lint::EnsureReturn do
   subject(:cop) { described_class.new }
 
   it 'registers an offense for return in ensure' do
@@ -16,24 +16,24 @@ describe RuboCop::Cop::Lint::EnsureReturn do
   end
 
   it 'does not register an offense for return outside ensure' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       begin
         something
         return
       ensure
         file.close
       end
-    END
+    RUBY
   end
 
   it 'does not check when ensure block has no body' do
     expect do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         begin
           something
         ensure
         end
-      END
+      RUBY
     end.not_to raise_exception
   end
 end
