@@ -1,11 +1,11 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Lint::InheritException, :config do
+RSpec.describe RuboCop::Cop::Lint::InheritException, :config do
   subject(:cop) { described_class.new(config) }
 
   shared_examples 'registers an offense' do |message|
     it 'registers an offense' do
-      inspect_source(cop, source)
+      inspect_source(source)
 
       expect(cop.offenses.size).to eq(1)
       expect(cop.messages).to eq([message])
@@ -14,7 +14,7 @@ describe RuboCop::Cop::Lint::InheritException, :config do
 
   shared_examples 'auto-correct' do |expected|
     it 'auto-corrects' do
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
 
       expect(new_source).to eq(expected)
     end
