@@ -1,22 +1,22 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Lint::UselessComparison do
+RSpec.describe RuboCop::Cop::Lint::UselessComparison do
   subject(:cop) { described_class.new }
 
   described_class::OPS.each do |op|
     it "registers an offense for a simple comparison with #{op}" do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         5 #{op} 5
         a #{op} a
-      END
+      RUBY
       expect(cop.offenses.size).to eq(2)
     end
 
     it "registers an offense for a complex comparison with #{op}" do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         5 + 10 * 30 #{op} 5 + 10 * 30
         a.top(x) #{op} a.top(x)
-      END
+      RUBY
       expect(cop.offenses.size).to eq(2)
     end
   end
