@@ -1,15 +1,15 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Performance::LstripRstrip do
+RSpec.describe RuboCop::Cop::Performance::LstripRstrip do
   subject(:cop) { described_class.new }
 
   it 'autocorrects str.lstrip.rstrip' do
-    new_source = autocorrect_source(cop, 'str.lstrip.rstrip')
+    new_source = autocorrect_source('str.lstrip.rstrip')
     expect(new_source).to eq 'str.strip'
   end
 
   it 'autocorrects str.rstrip.lstrip' do
-    new_source = autocorrect_source(cop, 'str.rstrip.lstrip')
+    new_source = autocorrect_source('str.rstrip.lstrip')
     expect(new_source).to eq 'str.strip'
   end
 
