@@ -1,25 +1,25 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Performance::RangeInclude do
+RSpec.describe RuboCop::Cop::Performance::RangeInclude do
   subject(:cop) { described_class.new }
 
   it 'autocorrects (a..b).include? without parens' do
-    new_source = autocorrect_source(cop, '(a..b).include? 1')
+    new_source = autocorrect_source('(a..b).include? 1')
     expect(new_source).to eq '(a..b).cover? 1'
   end
 
   it 'autocorrects (a...b).include? without parens' do
-    new_source = autocorrect_source(cop, '(a...b).include? 1')
+    new_source = autocorrect_source('(a...b).include? 1')
     expect(new_source).to eq '(a...b).cover? 1'
   end
 
   it 'autocorrects (a..b).include? with parens' do
-    new_source = autocorrect_source(cop, '(a..b).include?(1)')
+    new_source = autocorrect_source('(a..b).include?(1)')
     expect(new_source).to eq '(a..b).cover?(1)'
   end
 
   it 'autocorrects (a...b).include? with parens' do
-    new_source = autocorrect_source(cop, '(a...b).include?(1)')
+    new_source = autocorrect_source('(a...b).include?(1)')
     expect(new_source).to eq '(a...b).cover?(1)'
   end
 
