@@ -1,24 +1,24 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Performance::RedundantSortBy do
+RSpec.describe RuboCop::Cop::Performance::RedundantSortBy do
   subject(:cop) { described_class.new }
 
   it 'autocorrects array.sort_by { |x| x }' do
-    new_source = autocorrect_source(cop, 'array.sort_by { |x| x }')
+    new_source = autocorrect_source('array.sort_by { |x| x }')
     expect(new_source).to eq 'array.sort'
   end
 
   it 'autocorrects array.sort_by { |y| y }' do
-    new_source = autocorrect_source(cop, 'array.sort_by { |y| y }')
+    new_source = autocorrect_source('array.sort_by { |y| y }')
     expect(new_source).to eq 'array.sort'
   end
 
   it 'autocorrects array.sort_by do |x| x end' do
-    new_source = autocorrect_source(cop, <<-END.strip_indent)
+    new_source = autocorrect_source(<<-RUBY.strip_indent)
       array.sort_by do |x|
         x
       end
-    END
+    RUBY
     expect(new_source).to eq "array.sort\n"
   end
 
