@@ -1,11 +1,11 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Rails::FindBy do
+RSpec.describe RuboCop::Cop::Rails::FindBy do
   subject(:cop) { described_class.new }
 
   shared_examples 'registers_offense' do |selector|
     it "when using where.#{selector}" do
-      inspect_source(cop, "User.where(id: x).#{selector}")
+      inspect_source("User.where(id: x).#{selector}")
 
       expect(cop.messages)
         .to eq(["Use `find_by` instead of `where.#{selector}`."])
@@ -20,13 +20,13 @@ describe RuboCop::Cop::Rails::FindBy do
   end
 
   it 'autocorrects where.take to find_by' do
-    new_source = autocorrect_source(cop, 'User.where(id: x).take')
+    new_source = autocorrect_source('User.where(id: x).take')
 
     expect(new_source).to eq('User.find_by(id: x)')
   end
 
   it 'does not autocorrect where.first' do
-    new_source = autocorrect_source(cop, 'User.where(id: x).first')
+    new_source = autocorrect_source('User.where(id: x).first')
 
     expect(new_source).to eq('User.where(id: x).first')
   end
