@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Rails::HttpPositionalArguments do
+RSpec.describe RuboCop::Cop::Rails::HttpPositionalArguments do
   context 'rails 4', :rails4, :config do
     subject(:cop) { described_class.new(config) }
 
@@ -40,8 +40,8 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
         end
 
         it 'does not register an offense' do
-          inspect_source(cop, source)
-          expect(cop.messages).to be_empty
+          inspect_source(source)
+          expect(cop.messages.empty?).to be(true)
         end
       end
     end
@@ -56,7 +56,7 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
       end
 
       it 'does not auto-correct' do
-        new_source = autocorrect_source(cop, source)
+        new_source = autocorrect_source(source)
         expect(new_source).to eq(source)
       end
 
@@ -69,7 +69,7 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
 
     describe '.patch' do
       let(:source) do
-        <<-EOS.strip_indent
+        <<-RUBY.strip_indent
         patch :update,
                   id: @user.id,
                   ac: {
@@ -77,7 +77,7 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
                     profile_id: @profile1.id,
                     content: 'Some Text'
                   }
-        EOS
+        RUBY
       end
 
       it 'does not register an offense' do
@@ -93,14 +93,14 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
       end
 
       it 'does not auto-correct' do
-        new_source = autocorrect_source(cop, source)
+        new_source = autocorrect_source(source)
         expect(new_source).to eq(source)
       end
     end
 
     describe '.post' do
       let(:source) do
-        <<-EOS.strip_indent
+        <<-RUBY.strip_indent
         post :create,
                   id: @user.id,
                   ac: {
@@ -108,7 +108,7 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
                     profile_id: @profile1.id,
                     content: 'Some Text'
                   }
-        EOS
+        RUBY
       end
 
       it 'does not register an offense' do
@@ -124,7 +124,7 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
       end
 
       it 'does not auto-correct' do
-        new_source = autocorrect_source(cop, source)
+        new_source = autocorrect_source(source)
         expect(new_source).to eq(source)
       end
     end
@@ -132,32 +132,32 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
     %w[post get patch put delete].each do |keyword|
       it 'does not register an offense when keyword' do
         source = "@user.#{keyword}.id = ''"
-        inspect_source(cop, source)
+        inspect_source(source)
         expect(cop.offenses.size).to eq(0)
       end
     end
 
     it 'does not auto-correct http action when method' do
       source = 'post user_attrs, id: 1'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(0)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(source)
     end
 
     it 'does not auto-correct http action when symbol' do
       source = 'post :user_attrs, id: 1'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(0)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(source)
     end
 
     it 'does not auto-correct' do
       source = 'post(:user_attrs, id: 1)'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(0)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(source)
     end
 
@@ -171,20 +171,20 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
 
     it 'does not remove quotes when single quoted' do
       source = "get '/auth/linkedin/callback'"
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq("get '/auth/linkedin/callback'")
     end
 
     it 'does not remove quotes when double quoted' do
       source = 'get "/auth/linkedin/callback"'
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq('get "/auth/linkedin/callback"')
     end
 
     it 'does not add headers keyword when env or headers are used' do
       source = 'get some_path(profile.id), {},'
       source += " 'HTTP_REFERER' => p_url(p.id).to_s"
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(source)
     end
 
@@ -192,58 +192,62 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
       source = 'get some_path(profile.id), '
       source += '{ user_id: @user.id, profile_id: p.id },'
       source += " 'HTTP_REFERER' => p_url(p.id).to_s"
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(source)
     end
 
     it 'does not auto-correct http action when params is a method call' do
       source = 'post :create, confirmation_data'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(0)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
+      expect(new_source).to eq(source)
+    end
+
+    it 'does not auto-correct http action when params and action names ' \
+      'are method calls' do
+      source = 'post user_attrs, params'
+      inspect_source(source)
+      expect(cop.offenses.size).to eq(0)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(source)
     end
 
     # rubocop:disable LineLength
     it 'does not auto-correct http action when parameter matches keyword name' do
       source = 'post :create, id: 7, comment: { body: "hei" }'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(0)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(source)
     end
 
-    it 'does not auto-correct http action when format keyword included but not alone' do
+    it 'does not auto-correct http action when format keyword included ' \
+      'but not alone' do
       source = 'post :create, id: 7, format: :rss'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(0)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(source)
     end
 
     it 'does not auto-correct when params is a lvar' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         params = { id: 1 }
         post user_attrs, params
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
       expect(cop.offenses.size).to eq(0)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(source)
     end
 
-    it 'does not auto-correct http action when params is a method call' do
-      source = 'post user_attrs, params'
-      inspect_source(cop, source)
-      expect(cop.offenses.size).to eq(0)
-      new_source = autocorrect_source(cop, source)
-      expect(new_source).to eq(source)
-    end
-    it 'does not auto-correct http action when params is a method call with chain' do
+    it 'does not auto-correct http action when params is a method call ' \
+      'with chain' do
       source = 'post user_attrs, params.merge(foo: bar)'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(0)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq(source)
     end
   end
@@ -253,19 +257,19 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
 
     it 'registers an offense for post method' do
       source = 'post :create, user_id: @user.id'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
     end
 
     it 'registers an offense for patch method' do
       source = 'patch :update, user_id: @user.id'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
     end
 
     it 'registers an offense for delete method' do
       source = 'delete :destroy, id: @user.id'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
     end
 
@@ -293,8 +297,8 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
         end
 
         it 'does not register an offense' do
-          inspect_source(cop, source)
-          expect(cop.messages).to be_empty
+          inspect_source(source)
+          expect(cop.messages.empty?).to be(true)
         end
       end
     end
@@ -316,7 +320,7 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
       end
 
       it 'autocorrects offense' do
-        new_source = autocorrect_source(cop, source)
+        new_source = autocorrect_source(source)
         expect(new_source).to eq(corrected_result)
       end
 
@@ -329,7 +333,7 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
 
     describe '.patch' do
       let(:source) do
-        <<-EOS.strip_indent
+        <<-RUBY.strip_indent
         patch :update,
                   id: @user.id,
                   ac: {
@@ -337,17 +341,17 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
                     profile_id: @profile1.id,
                     content: 'Some Text'
                   }
-        EOS
+        RUBY
       end
 
       let(:corrected_result) do
-        <<-EOS.strip_indent
+        <<-RUBY.strip_indent
         patch :update, params: { id: @user.id, ac: {
                     article_id: @article1.id,
                     profile_id: @profile1.id,
                     content: 'Some Text'
                   } }
-        EOS
+        RUBY
       end
 
       it 'registers an offense' do
@@ -364,14 +368,14 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
       end
 
       it 'autocorrects offense' do
-        new_source = autocorrect_source(cop, source)
+        new_source = autocorrect_source(source)
         expect(new_source).to eq(corrected_result)
       end
     end
 
     describe '.post' do
       let(:source) do
-        <<-EOS.strip_indent
+        <<-RUBY.strip_indent
         post :create,
                   id: @user.id,
                   ac: {
@@ -379,17 +383,17 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
                     profile_id: @profile1.id,
                     content: 'Some Text'
                   }
-        EOS
+        RUBY
       end
 
       let(:corrected_result) do
-        <<-EOS.strip_indent
+        <<-RUBY.strip_indent
         post :create, params: { id: @user.id, ac: {
                     article_id: @article1.id,
                     profile_id: @profile1.id,
                     content: 'Some Text'
                   } }
-        EOS
+        RUBY
       end
 
       it 'registers an offense' do
@@ -406,7 +410,7 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
       end
 
       it 'autocorrects offense' do
-        new_source = autocorrect_source(cop, source)
+        new_source = autocorrect_source(source)
         expect(new_source).to eq(corrected_result)
       end
     end
@@ -414,34 +418,34 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
     %w[post get patch put delete].each do |keyword|
       it 'does not register an offense when keyword' do
         source = "@user.#{keyword}.id = ''"
-        inspect_source(cop, source)
+        inspect_source(source)
         expect(cop.offenses.size).to eq(0)
       end
     end
 
     it 'auto-corrects http action when method' do
       source = 'post user_attrs, id: 1'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expected = 'post user_attrs, params: { id: 1 }'
       expect(new_source).to eq(expected)
     end
 
     it 'auto-corrects http action when symbol' do
       source = 'post :user_attrs, id: 1'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expected = 'post :user_attrs, params: { id: 1 }'
       expect(new_source).to eq(expected)
     end
 
     it 'maintains parentheses in auto-correcting' do
       source = 'post(:user_attrs, id: 1)'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expected = 'post(:user_attrs, params: { id: 1 })'
       expect(new_source).to eq(expected)
     end
@@ -456,20 +460,20 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
 
     it 'does not remove quotes when single quoted' do
       source = "get '/auth/linkedin/callback'"
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq("get '/auth/linkedin/callback'")
     end
 
     it 'does not remove quotes when double quoted' do
       source = 'get "/auth/linkedin/callback"'
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expect(new_source).to eq('get "/auth/linkedin/callback"')
     end
 
     it 'does add headers keyword when env or headers are used' do
       source = 'get some_path(profile.id), {},'
       source += " 'HTTP_REFERER' => p_url(p.id).to_s"
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       output = 'get some_path(profile.id),'
       output += " headers: { 'HTTP_REFERER' => p_url(p.id).to_s }"
       expect(new_source).to eq(output)
@@ -479,7 +483,7 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
       source = 'get some_path(profile.id), '
       source += '{ user_id: @user.id, profile_id: p.id },'
       source += " 'HTTP_REFERER' => p_url(p.id).to_s"
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       output = 'get some_path(profile.id), params:'
       output += ' { user_id: @user.id, profile_id: p.id },'
       output += " headers: { 'HTTP_REFERER' => p_url(p.id).to_s }"
@@ -488,61 +492,62 @@ describe RuboCop::Cop::Rails::HttpPositionalArguments do
 
     it 'auto-corrects http action when params is a method call' do
       source = 'post :create, confirmation_data'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       output = 'post :create, params: confirmation_data'
       expect(new_source).to eq(output)
     end
 
     it 'auto-corrects http action when parameter matches special keyword name' do
       source = 'post :create, id: 7, comment: { body: "hei" }'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       output = 'post :create, params: { id: 7, comment: { body: "hei" } }'
       expect(new_source).to eq(output)
     end
 
     it 'auto-corrects http action when format keyword included but not alone' do
       source = 'post :create, id: 7, format: :rss'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       output = 'post :create, params: { id: 7, format: :rss }'
       expect(new_source).to eq(output)
     end
 
     it 'auto-corrects http action when params is a lvar' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         params = { id: 1 }
         post user_attrs, params
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
-      new_source = autocorrect_source(cop, source)
-      expect(new_source).to eq(<<-END.strip_indent)
+      new_source = autocorrect_source(source)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         params = { id: 1 }
         post user_attrs, params: params
-      END
+      RUBY
     end
 
-    it 'auto-corrects http action when params is a method call' do
+    it 'auto-corrects http action when params and action name are method calls' do
       source = 'post user_attrs, params'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expected = 'post user_attrs, params: params'
       expect(new_source).to eq(expected)
     end
 
     it 'auto-corrects http action when params is a method call with chain' do
       source = 'post user_attrs, params.merge(foo: bar)'
-      inspect_source(cop, source)
+      inspect_source(source)
       expect(cop.offenses.size).to eq(1)
-      new_source = autocorrect_source(cop, source)
+      new_source = autocorrect_source(source)
       expected = 'post user_attrs, params: params.merge(foo: bar)'
       expect(new_source).to eq(expected)
     end
   end
 end
+# rubocop:enable LineLength
