@@ -1,16 +1,16 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Rails::Output do
+RSpec.describe RuboCop::Cop::Rails::Output do
   subject(:cop) { described_class.new }
 
   it 'records an offense for methods without a receiver' do
-    source = <<-END.strip_indent
+    source = <<-RUBY.strip_indent
       p "edmond dantes"
       puts "sinbad"
       print "abbe busoni"
       pp "monte cristo"
-    END
-    inspect_source(cop, source)
+    RUBY
+    inspect_source(source)
     expect(cop.offenses.size).to eq(4)
   end
 
