@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Rails::ScopeArgs do
+RSpec.describe RuboCop::Cop::Rails::ScopeArgs do
   subject(:cop) { described_class.new }
 
   it 'registers an offense a scope with a method arg' do
@@ -35,11 +35,11 @@ describe RuboCop::Cop::Rails::ScopeArgs do
   end
 
   it 'accepts a lambda with a multiline block' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       scope :active, (lambda do |active|
                        where(active: active)
                      end)
-    END
+    RUBY
   end
 
   it 'accepts a proc' do
