@@ -1,25 +1,24 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Rails::Validation do
+RSpec.describe RuboCop::Cop::Rails::Validation do
   subject(:cop) { described_class.new }
 
   described_class::BLACKLIST.each_with_index do |validation, number|
     it "registers an offense for #{validation}" do
-      inspect_source(cop, "#{validation} :name")
+      inspect_source("#{validation} :name")
       expect(cop.offenses.size).to eq(1)
     end
 
     it "outputs the correct message for #{validation}" do
-      inspect_source(cop, "#{validation} :name")
+      inspect_source("#{validation} :name")
       expect(cop.offenses.first.message)
         .to include(described_class::WHITELIST[number])
     end
   end
 
-  described_class::TYPES.each_with_index do |parameter|
+  described_class::TYPES.each do |parameter|
     it "autocorrect validates_#{parameter}_of" do
       new_source = autocorrect_source(
-        cop,
         "validates_#{parameter}_of :full_name, :birth_date"
       )
       expect(new_source).to eq(
@@ -34,7 +33,6 @@ describe RuboCop::Cop::Rails::Validation do
 
   it 'autocorrect validates_length_of' do
     new_source = autocorrect_source(
-      cop,
       'validates_numericality_of :age, minimum: 0, maximum: 122'
     )
     expect(new_source).to eq(
