@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Security::YAMLLoad, :config do
+RSpec.describe RuboCop::Cop::Security::YAMLLoad, :config do
   subject(:cop) { described_class.new(config) }
 
   it 'does not register an offense for YAML.dump' do
@@ -30,7 +30,7 @@ describe RuboCop::Cop::Security::YAMLLoad, :config do
   end
 
   it 'autocorrects load to safe_load' do
-    expect(autocorrect_source(cop, '::YAML.load("-- foo")')).to eq(
+    expect(autocorrect_source('::YAML.load("-- foo")')).to eq(
       '::YAML.safe_load("-- foo")'
     )
   end
