@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Style::AutoResourceCleanup do
+RSpec.describe RuboCop::Cop::Style::AutoResourceCleanup do
   subject(:cop) { described_class.new }
 
   it 'registers an offense for File.open without block' do
@@ -17,4 +17,8 @@ describe RuboCop::Cop::Style::AutoResourceCleanup do
   it 'does not register an offense for File.open with block-pass' do
     expect_no_offenses('File.open("file", &:read)')
   end
+
+  it 'does not register an offense for File.open with immediate close' do
+    expect_no_offenses('File.open("file", "w", 0o777).close')
+  end
 end
