@@ -1,36 +1,36 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Style::ConditionalAssignment do
+RSpec.describe RuboCop::Cop::Style::ConditionalAssignment do
   subject(:cop) { described_class.new(config) }
 
   shared_examples 'all variable types' do |variable|
     it 'registers an offense assigning any variable type to ternary' do
-      inspect_source(cop, "#{variable} = foo? ? 1 : 2")
+      inspect_source("#{variable} = foo? ? 1 : 2")
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'allows assigning any variable type inside ternary' do
-      inspect_source(cop, "foo? ? #{variable} = 1 : #{variable} = 2")
+      inspect_source("foo? ? #{variable} = 1 : #{variable} = 2")
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'registers an offense assigning any variable type to if else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         #{variable} = if foo
                         1
                       else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'registers an offense assigning any variable type to if elsif else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         #{variable} = if foo
                         1
                       elsif baz
@@ -38,140 +38,140 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                       else
                         3
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'registers an offense assigning any variable type to if else' \
       'with multiple assignment' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         #{variable}, #{variable} = if foo
                         something
                       else
                         something_else
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'allows assigning any variable type inside if else' \
       'with multiple assignment' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         if foo
           #{variable}, #{variable} = something
         else
           #{variable}, #{variable} = something_else
         end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
-      expect(cop.messages).to be_empty
+      expect(cop.messages.empty?).to be(true)
     end
 
     it 'allows assigning any variable type inside if else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         if foo
           #{variable} = 1
         else
           #{variable} = 2
         end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'allows assignment to if without else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         #{variable} = if foo
                         1
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'registers an offense assigning any variable type to unless else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         #{variable} = unless foo
                         1
                       else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'allows assigning any variable type inside unless else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         unless foo
           #{variable} = 1
         else
           #{variable} = 2
         end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'registers an offense for assigning any variable type to case when' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         #{variable} = case foo
                       when "a"
                         1
                       else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'allows assigning any variable type inside case when' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         case foo
         when "a"
           #{variable} = 1
         else
           #{variable} = 2
         end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'does not crash for rescue assignment' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         begin
           foo
         rescue => #{variable}
           bar
         end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     context 'auto-correct' do
       it 'corrects assigning any variable type to ternary' do
-        new_source = autocorrect_source(cop, "#{variable} = foo? ? 1 : 2")
+        new_source = autocorrect_source("#{variable} = foo? ? 1 : 2")
 
         expect(new_source).to eq("foo? ? #{variable} = 1 : #{variable} = 2")
       end
 
       it 'corrects assigning any variable type to if elsif else' do
-        source = <<-END.strip_indent
+        source = <<-RUBY.strip_indent
           #{variable} = if foo
                           1
                         elsif baz
@@ -179,10 +179,10 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                         else
                           3
                         end
-        END
-        new_source = autocorrect_source(cop, source)
+        RUBY
+        new_source = autocorrect_source(source)
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           if foo
             #{variable} = 1
           elsif baz
@@ -190,30 +190,30 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
           else
             #{variable} = 3
           end
-        END
+        RUBY
       end
 
       it 'corrects assigning any variable type to unless else' do
-        source = <<-END.strip_indent
+        source = <<-RUBY.strip_indent
           #{variable} = unless foo
                           1
                         else
                           2
                         end
-        END
-        new_source = autocorrect_source(cop, source)
+        RUBY
+        new_source = autocorrect_source(source)
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           unless foo
             #{variable} = 1
           else
             #{variable} = 2
           end
-        END
+        RUBY
       end
 
       it 'corrects assigning any variable type to case when' do
-        source = <<-END.strip_indent
+        source = <<-RUBY.strip_indent
           #{variable} = case foo
                         when "a"
                           1
@@ -222,10 +222,10 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                         else
                           3
                         end
-        END
-        new_source = autocorrect_source(cop, source)
+        RUBY
+        new_source = autocorrect_source(source)
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           case foo
           when "a"
             #{variable} = 1
@@ -234,141 +234,141 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
           else
             #{variable} = 3
           end
-        END
+        RUBY
       end
     end
   end
 
   shared_examples 'all assignment types' do |assignment|
     it 'registers an offense for any assignment to ternary' do
-      inspect_source(cop, "bar #{assignment} (foo? ? 1 : 2)")
+      inspect_source("bar #{assignment} (foo? ? 1 : 2)")
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'registers an offense any assignment to if else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar #{assignment} if foo
                         1
                       else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'allows any assignment to if without else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar #{assignment} if foo
                         1
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'registers an offense for any assignment to unless else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar #{assignment} unless foo
                         1
                       else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'registers an offense any assignment to case when' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar #{assignment} case foo
                       when "a"
                         1
                       else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     context 'auto-correct' do
       it 'corrects any assignment to ternary' do
-        new_source = autocorrect_source(cop, "bar #{assignment} (foo? ? 1 : 2)")
+        new_source = autocorrect_source("bar #{assignment} (foo? ? 1 : 2)")
 
         expect(new_source)
           .to eq("foo? ? bar #{assignment} 1 : bar #{assignment} 2")
       end
 
       it 'corrects any assignment to if else' do
-        source = <<-END.strip_indent
+        source = <<-RUBY.strip_indent
           bar #{assignment} if foo
                           1
                         else
                           2
                         end
-        END
-        new_source = autocorrect_source(cop, source)
+        RUBY
+        new_source = autocorrect_source(source)
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           if foo
             bar #{assignment} 1
           else
             bar #{assignment} 2
           end
-        END
+        RUBY
       end
 
       it 'corrects any assignment to unless else' do
-        source = <<-END.strip_indent
+        source = <<-RUBY.strip_indent
           bar #{assignment} unless foo
                           1
                         else
                           2
                         end
-        END
-        new_source = autocorrect_source(cop, source)
+        RUBY
+        new_source = autocorrect_source(source)
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           unless foo
             bar #{assignment} 1
           else
             bar #{assignment} 2
           end
-        END
+        RUBY
       end
 
       it 'corrects any assignment to case when' do
-        source = <<-END.strip_indent
+        source = <<-RUBY.strip_indent
           bar #{assignment} case foo
                         when "a"
                           1
                         else
                           2
                         end
-        END
-        new_source = autocorrect_source(cop, source)
+        RUBY
+        new_source = autocorrect_source(source)
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           case foo
           when "a"
             bar #{assignment} 1
           else
             bar #{assignment} 2
           end
-        END
+        RUBY
       end
     end
   end
 
   shared_examples 'multiline all variable types' do |variable, expected|
     it 'assigning any variable type to a multiline if else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         #{variable} = if foo
                         something
                         1
@@ -376,29 +376,29 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                         something_else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq(expected)
     end
 
     it 'assigning any variable type to an if else with multiline ' \
        'in one branch' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         #{variable} = if foo
                         1
                       else
                         something_else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq(expected)
     end
 
     it 'assigning any variable type to a multiline if elsif else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         #{variable} = if foo
                         something
                         1
@@ -412,14 +412,14 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                         something_else
                         4
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq(expected)
     end
 
     it 'assigning any variable type to a multiline unless else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         #{variable} = unless foo
                         something
                         1
@@ -427,14 +427,14 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                         something_else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq(expected)
     end
 
     it 'assigning any variable type to a multiline case when' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         #{variable} = case foo
                       when "a"
                         something
@@ -443,8 +443,8 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                         something_else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq(expected)
     end
@@ -452,7 +452,7 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
 
   shared_examples 'multiline all assignment types' do |assignment, expected|
     it 'any assignment to a multiline if else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar #{assignment} if foo
                         something
                         1
@@ -460,14 +460,14 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                         something_else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq(expected)
     end
 
     it 'any assignment to a multiline unless else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar #{assignment} unless foo
                         something
                         1
@@ -475,14 +475,14 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                         something_else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq(expected)
     end
 
     it 'any assignment to a multiline case when' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar #{assignment} case foo
                       when "a"
                         something
@@ -491,8 +491,8 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                         something_else
                         2
                       end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq(expected)
     end
@@ -500,26 +500,26 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
 
   shared_examples 'single line condition auto-correct' do
     it 'corrects assignment to an if else condition' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = if foo
                 1
               else
                 2
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         if foo
           bar = 1
         else
           bar = 2
         end
-      END
+      RUBY
     end
 
     it 'corrects assignment to an if elsif else condition' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = if foo
                 1
               elsif foobar
@@ -527,10 +527,10 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
               else
                 3
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         if foo
           bar = 1
         elsif foobar
@@ -538,11 +538,11 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
         else
           bar = 3
         end
-      END
+      RUBY
     end
 
     it 'corrects assignment to an if elsif else with multiple elsifs' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = if foo
                 1
               elsif foobar
@@ -552,10 +552,10 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
               else
                 4
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         if foo
           bar = 1
         elsif foobar
@@ -565,51 +565,51 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
         else
           bar = 4
         end
-      END
+      RUBY
     end
 
     it 'corrects assignment to an unless else condition' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = unless foo
                 1
               else
                 2
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         unless foo
           bar = 1
         else
           bar = 2
         end
-      END
+      RUBY
     end
 
     it 'corrects assignment to a case when else condition' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = case foo
               when foobar
                 1
               else
                 2
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         case foo
         when foobar
           bar = 1
         else
           bar = 2
         end
-      END
+      RUBY
     end
 
     it 'corrects assignment to a case when else with multiple whens' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = case foo
               when foobar
                 1
@@ -618,10 +618,10 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
               else
                 3
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         case foo
         when foobar
           bar = 1
@@ -630,11 +630,11 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
         else
           bar = 3
         end
-      END
+      RUBY
     end
 
     it 'corrects assignment to a ternary operator' do
-      new_source = autocorrect_source(cop, 'bar = foo? ? 1 : 2')
+      new_source = autocorrect_source('bar = foo? ? 1 : 2')
 
       expect(new_source).to eq('foo? ? bar = 1 : bar = 2')
     end
@@ -726,43 +726,43 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
 
     it 'registers an offense for assignment using a method that ends with ' \
        'an equal sign' do
-      inspect_source(cop, 'self.attributes = foo? ? 1 : 2')
+      inspect_source('self.attributes = foo? ? 1 : 2')
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'registers an offense for assignment using []=' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         foo[:a] = if bar?
                     1
                   else
                     2
                   end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'registers an offense for assignment to an if then else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = if foo then 1
               else 2
               end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
 
     it 'registers an offense for assignment to case when then else' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         baz = case foo
               when bar then 1
               else 2
               end
-      END
-      inspect_source(cop, source)
+      RUBY
+      inspect_source(source)
 
       expect(cop.messages).to eq([described_class::ASSIGN_TO_CONDITION_MSG])
     end
@@ -777,82 +777,82 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
       it_behaves_like('single line condition auto-correct')
 
       it 'corrects assignment to an if then else' do
-        source = <<-END.strip_indent
+        source = <<-RUBY.strip_indent
           bar = if foo then 1
                 else 2
                 end
-        END
+        RUBY
 
-        new_source = autocorrect_source(cop, source)
+        new_source = autocorrect_source(source)
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           if foo then bar = 1
           else bar = 2
           end
-        END
+        RUBY
       end
 
       it 'corrects assignment to case when then else' do
-        source = <<-END.strip_indent
+        source = <<-RUBY.strip_indent
           baz = case foo
                 when bar then 1
                 else 2
                 end
-        END
+        RUBY
 
-        new_source = autocorrect_source(cop, source)
+        new_source = autocorrect_source(source)
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           case foo
           when bar then baz = 1
           else baz = 2
           end
-        END
+        RUBY
       end
 
       it 'corrects assignment using a method that ends with an equal sign' do
-        new_source = autocorrect_source(cop, 'self.attributes = foo? ? 1 : 2')
+        new_source = autocorrect_source('self.attributes = foo? ? 1 : 2')
 
         expect(new_source)
           .to eq('foo? ? self.attributes = 1 : self.attributes = 2')
       end
 
       it 'corrects assignment using []=' do
-        source = <<-END.strip_indent
+        source = <<-RUBY.strip_indent
           foo[:a] = if bar?
                       1
                     else
                       2
                     end
-        END
-        new_source = autocorrect_source(cop, source)
+        RUBY
+        new_source = autocorrect_source(source)
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           if bar?
             foo[:a] = 1
           else
             foo[:a] = 2
           end
-        END
+        RUBY
       end
 
       it 'corrects assignment to a namespaced constant' do
-        source = <<-END.strip_indent
+        source = <<-RUBY.strip_indent
           FOO::BAR = if baz?
                        1
                      else
                        2
                      end
-        END
-        new_source = autocorrect_source(cop, source)
+        RUBY
+        new_source = autocorrect_source(source)
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           if baz?
             FOO::BAR = 1
           else
             FOO::BAR = 2
           end
-        END
+        RUBY
       end
     end
   end
@@ -968,7 +968,7 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
     it_behaves_like('single line condition auto-correct')
 
     it 'corrects assignment to a multiline if else condition' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = if foo
                 something
                 1
@@ -976,10 +976,10 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                 something_else
                 2
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         if foo
           something
           bar = 1
@@ -987,11 +987,11 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
           something_else
           bar = 2
         end
-      END
+      RUBY
     end
 
     it 'corrects assignment to a multiline if elsif else condition' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = if foo
                 something
                 1
@@ -1002,10 +1002,10 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                 something_else
                 3
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         if foo
           something
           bar = 1
@@ -1016,11 +1016,11 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
           something_else
           bar = 3
         end
-      END
+      RUBY
     end
 
     it 'corrects assignment to an if elsif else with multiple elsifs' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = if foo
                 something
                 1
@@ -1034,10 +1034,10 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                 something_else
                 4
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         if foo
           something
           bar = 1
@@ -1051,11 +1051,11 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
           something_else
           bar = 4
         end
-      END
+      RUBY
     end
 
     it 'corrects assignment to an unless else condition' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = unless foo
                 something
                 1
@@ -1063,10 +1063,10 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                 something_else
                 2
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         unless foo
           something
           bar = 1
@@ -1074,11 +1074,11 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
           something_else
           bar = 2
         end
-      END
+      RUBY
     end
 
     it 'corrects assignment to a case when else condition' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = case foo
               when foobar
                 something
@@ -1087,10 +1087,10 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                 something_else
                 2
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         case foo
         when foobar
           something
@@ -1099,11 +1099,11 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
           something_else
           bar = 2
         end
-      END
+      RUBY
     end
 
     it 'corrects assignment to a case when else with multiple whens' do
-      source = <<-END.strip_indent
+      source = <<-RUBY.strip_indent
         bar = case foo
               when foobar
                 something
@@ -1115,10 +1115,10 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
                 something_else
                 3
               end
-      END
-      new_source = autocorrect_source(cop, source)
+      RUBY
+      new_source = autocorrect_source(source)
 
-      expect(new_source).to eq(<<-END.strip_indent)
+      expect(new_source).to eq(<<-RUBY.strip_indent)
         case foo
         when foobar
           something
@@ -1130,7 +1130,7 @@ describe RuboCop::Cop::Style::ConditionalAssignment do
           something_else
           bar = 3
         end
-      END
+      RUBY
     end
   end
 
