@@ -1,23 +1,23 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Style::DefWithParentheses do
+RSpec.describe RuboCop::Cop::Style::DefWithParentheses do
   subject(:cop) { described_class.new }
 
   it 'reports an offense for def with empty parens' do
-    src = <<-END.strip_indent
+    src = <<-RUBY.strip_indent
       def func()
       end
-    END
-    inspect_source(cop, src)
+    RUBY
+    inspect_source(src)
     expect(cop.offenses.size).to eq(1)
   end
 
   it 'reports an offense for class def with empty parens' do
-    src = <<-END.strip_indent
+    src = <<-RUBY.strip_indent
       def Test.func()
       end
-    END
-    inspect_source(cop, src)
+    RUBY
+    inspect_source(src)
     expect(cop.offenses.size).to eq(1)
   end
 
@@ -33,15 +33,15 @@ describe RuboCop::Cop::Style::DefWithParentheses do
   end
 
   it 'auto-removes unneeded parens' do
-    new_source = autocorrect_source(cop, <<-END.strip_indent)
+    new_source = autocorrect_source(<<-RUBY.strip_indent)
       def test();
       something
       end
-    END
-    expect(new_source).to eq(<<-END.strip_indent)
+    RUBY
+    expect(new_source).to eq(<<-RUBY.strip_indent)
       def test;
       something
       end
-    END
+    RUBY
   end
 end
