@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
+RSpec.describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
   subject(:cop) { described_class.new(config) }
 
   context 'always' do
@@ -18,22 +18,22 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
     end
 
     it 'accepts a frozen string literal on the top line' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         # frozen_string_literal: true
         puts 1
-      END
+      RUBY
     end
 
     it 'accepts a disabled frozen string literal on the top line' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         # frozen_string_literal: false
         puts 1
-      END
+      RUBY
     end
 
     it 'registers an offense for not having a frozen string literal comment ' \
        'on the top line' do
-      inspect_source(cop, 'puts 1')
+      inspect_source('puts 1')
 
       expect(cop.messages)
         .to eq(['Missing magic comment `# frozen_string_literal: true`.'])
@@ -41,65 +41,65 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'registers an offense for not having a frozen string literal comment ' \
        'under a shebang' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         puts 1
-      END
+      RUBY
 
       expect(cop.messages)
         .to eq(['Missing magic comment `# frozen_string_literal: true`.'])
     end
 
     it 'accepts a frozen string literal below a shebang comment' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # frozen_string_literal: true
         puts 1
-      END
+      RUBY
     end
 
     it 'accepts a disabled frozen string literal below a shebang comment' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # frozen_string_literal: false
         puts 1
-      END
+      RUBY
     end
 
     it 'registers an offense for not having a frozen string literal comment ' \
        'under an encoding comment' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         # encoding: utf-8
         puts 1
-      END
+      RUBY
 
       expect(cop.messages)
         .to eq(['Missing magic comment `# frozen_string_literal: true`.'])
     end
 
     it 'accepts a frozen string literal below an encoding comment' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         # encoding: utf-8
         # frozen_string_literal: true
         puts 1
-      END
+      RUBY
     end
 
     it 'accepts a dsabled frozen string literal below an encoding comment' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         # encoding: utf-8
         # frozen_string_literal: false
         puts 1
-      END
+      RUBY
     end
 
     it 'registers an offense for not having a frozen string literal comment ' \
        'under a shebang and an encoding comment' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # encoding: utf-8
         puts 1
-      END
+      RUBY
 
       expect(cop.messages)
         .to eq(['Missing magic comment `# frozen_string_literal: true`.'])
@@ -107,148 +107,148 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'accepts a frozen string literal comment below shebang and encoding ' \
        'comments' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # encoding: utf-8
         # frozen_string_literal: true
         puts 1
-      END
+      RUBY
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'accepts a disabled frozen string literal comment below shebang and ' \
        'encoding comments' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # encoding: utf-8
         # frozen_string_literal: false
         puts 1
-      END
+      RUBY
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'accepts a frozen string literal comment below shebang above an ' \
        'encoding comments' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # frozen_string_literal: true
         # encoding: utf-8
         puts 1
-      END
+      RUBY
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'accepts a disabled frozen string literal comment below shebang above ' \
        'an encoding comments' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # frozen_string_literal: false
         # encoding: utf-8
         puts 1
-      END
+      RUBY
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'accepts an emacs style combined magic comment' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # -*- encoding: UTF-8; frozen_string_literal: true -*-
           # encoding: utf-8
           puts 1
-        END
+        RUBY
     end
 
     context 'auto-correct' do
       it 'adds a frozen string literal comment to the first line if one is ' \
          'missing' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           # frozen_string_literal: true
           puts 1
-        END
+        RUBY
       end
 
       it 'adds a frozen string literal comment after a shebang' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # frozen_string_literal: true
           puts 1
-        END
+        RUBY
       end
 
       it 'adds a frozen string literal comment after an encoding comment' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           # encoding: utf-8
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           # encoding: utf-8
           # frozen_string_literal: true
           puts 1
-        END
+        RUBY
       end
 
       it 'adds a frozen string literal comment after a shebang and encoding ' \
          'comment' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # encoding: utf-8
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # encoding: utf-8
           # frozen_string_literal: true
           puts 1
-        END
+        RUBY
       end
 
       it 'adds a frozen string literal comment after a shebang and encoding ' \
          'comment when there is an empty line before the code' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # encoding: utf-8
 
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # encoding: utf-8
           # frozen_string_literal: true
 
           puts 1
-        END
+        RUBY
       end
 
       it 'adds a frozen string literal comment after an encoding comment ' \
          'when there is an empty line before the code' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           # encoding: utf-8
 
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           # encoding: utf-8
           # frozen_string_literal: true
 
           puts 1
-        END
+        RUBY
       end
     end
   end
@@ -275,17 +275,17 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
           end
 
           it 'accepts calling freeze on a variable' do
-            expect_no_offenses(<<-END.strip_indent)
+            expect_no_offenses(<<-RUBY.strip_indent)
               foo = "x"
                 foo.freeze
-            END
+            RUBY
           end
 
           it 'accepts calling shovel on a variable' do
-            expect_no_offenses(<<-END.strip_indent)
+            expect_no_offenses(<<-RUBY.strip_indent)
               foo = "x"
                 foo << "y"
-            END
+            RUBY
           end
 
           it 'accepts freezing a string' do
@@ -299,73 +299,71 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
         it 'accepts freezing a string when there is a frozen string literal ' \
            'comment' do
-          inspect_source(cop, <<-END.strip_indent)
+          inspect_source(<<-RUBY.strip_indent)
             # frozen_string_literal: true
             "x".freeze
-          END
+          RUBY
 
-          expect(cop.offenses).to be_empty
+          expect(cop.offenses.empty?).to be(true)
         end
 
         it 'accepts shoveling into a string when there is a frozen string ' \
            'literal comment' do
-          inspect_source(cop, <<-END.strip_indent)
+          inspect_source(<<-RUBY.strip_indent)
             # frozen_string_literal: true
             "x" << "y"
-          END
+          RUBY
 
-          expect(cop.offenses).to be_empty
+          expect(cop.offenses.empty?).to be(true)
         end
       end
     end
 
-    context 'ruby < 2.3' do
-      context 'target_ruby_version < 2.3', :ruby19 do
-        it 'accepts freezing a string' do
-          expect_no_offenses('"x".freeze')
-        end
-
-        it 'accepts calling << on a string' do
-          expect_no_offenses('"x" << "y"')
-        end
-
-        it 'accepts freezing a string with interpolation' do
-          expect_no_offenses('"#{foo}bar".freeze')
-        end
-
-        it 'accepts calling << on a string with interpolation' do
-          expect_no_offenses('"#{foo}bar" << "baz"')
-        end
+    context 'target_ruby_version < 2.3', :ruby22 do
+      it 'accepts freezing a string' do
+        expect_no_offenses('"x".freeze')
       end
 
-      context 'target_ruby_version 2.3+', :ruby23 do
-        it 'accepts freezing a string' do
-          expect_offense(<<-RUBY.strip_indent)
-            "x".freeze
-            ^ Missing magic comment `# frozen_string_literal: true`.
-          RUBY
-        end
+      it 'accepts calling << on a string' do
+        expect_no_offenses('"x" << "y"')
+      end
 
-        it 'accepts calling << on a string' do
-          expect_offense(<<-RUBY.strip_indent)
-            "x" << "y"
-            ^ Missing magic comment `# frozen_string_literal: true`.
-          RUBY
-        end
+      it 'accepts freezing a string with interpolation' do
+        expect_no_offenses('"#{foo}bar".freeze')
+      end
 
-        it 'accepts freezing a string with interpolation' do
-          expect_offense(<<-'RUBY'.strip_indent)
-            "#{foo}bar".freeze
-            ^ Missing magic comment `# frozen_string_literal: true`.
-          RUBY
-        end
+      it 'accepts calling << on a string with interpolation' do
+        expect_no_offenses('"#{foo}bar" << "baz"')
+      end
+    end
 
-        it 'accepts calling << on a string with interpolation' do
-          expect_offense(<<-'RUBY'.strip_indent)
-            "#{foo}bar" << "baz"
-            ^ Missing magic comment `# frozen_string_literal: true`.
-          RUBY
-        end
+    context 'target_ruby_version 2.3+', :ruby23 do
+      it 'accepts freezing a string' do
+        expect_offense(<<-RUBY.strip_indent)
+          "x".freeze
+          ^ Missing magic comment `# frozen_string_literal: true`.
+        RUBY
+      end
+
+      it 'accepts calling << on a string' do
+        expect_offense(<<-RUBY.strip_indent)
+          "x" << "y"
+          ^ Missing magic comment `# frozen_string_literal: true`.
+        RUBY
+      end
+
+      it 'accepts freezing a string with interpolation' do
+        expect_offense(<<-'RUBY'.strip_indent)
+          "#{foo}bar".freeze
+          ^ Missing magic comment `# frozen_string_literal: true`.
+        RUBY
+      end
+
+      it 'accepts calling << on a string with interpolation' do
+        expect_offense(<<-'RUBY'.strip_indent)
+          "#{foo}bar" << "baz"
+          ^ Missing magic comment `# frozen_string_literal: true`.
+        RUBY
       end
     end
   end
@@ -386,10 +384,10 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'registers an offense for a frozen string literal comment ' \
       'on the top line' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         # frozen_string_literal: true
         puts 1
-      END
+      RUBY
 
       expect(cop.messages).to eq(['Unnecessary frozen string literal comment.'])
       expect(cop.highlights).to eq(['# frozen_string_literal: true'])
@@ -397,10 +395,10 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'registers an offense for a disabled frozen string literal comment ' \
       'on the top line' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         # frozen_string_literal: false
         puts 1
-      END
+      RUBY
 
       expect(cop.messages).to eq(['Unnecessary frozen string literal comment.'])
       expect(cop.highlights).to eq(['# frozen_string_literal: false'])
@@ -412,21 +410,21 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'accepts not having not having a frozen string literal comment ' \
       'under a shebang' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         puts 1
-      END
+      RUBY
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'registers an offense for a frozen string literal comment ' \
       'below a shebang comment' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # frozen_string_literal: true
         puts 1
-      END
+      RUBY
 
       expect(cop.messages).to eq(['Unnecessary frozen string literal comment.'])
       expect(cop.highlights).to eq(['# frozen_string_literal: true'])
@@ -434,11 +432,11 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'registers an offense for a disabled frozen string literal ' \
       'below a shebang comment' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # frozen_string_literal: false
         puts 1
-      END
+      RUBY
 
       expect(cop.messages).to eq(['Unnecessary frozen string literal comment.'])
       expect(cop.highlights).to eq(['# frozen_string_literal: false'])
@@ -446,21 +444,21 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'allows not having a frozen string literal comment ' \
       'under an encoding comment' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         # encoding: utf-8
         puts 1
-      END
+      RUBY
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'registers an offense for a frozen string literal comment below ' \
       'an encoding comment' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         # encoding: utf-8
         # frozen_string_literal: true
         puts 1
-      END
+      RUBY
 
       expect(cop.messages).to eq(['Unnecessary frozen string literal comment.'])
       expect(cop.highlights).to eq(['# frozen_string_literal: true'])
@@ -468,11 +466,11 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'registers an offense for a dsabled frozen string literal below ' \
       'an encoding comment' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         # encoding: utf-8
         # frozen_string_literal: false
         puts 1
-      END
+      RUBY
 
       expect(cop.messages).to eq(['Unnecessary frozen string literal comment.'])
       expect(cop.highlights).to eq(['# frozen_string_literal: false'])
@@ -480,23 +478,23 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'allows not having a frozen string literal comment ' \
       'under a shebang and an encoding comment' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # encoding: utf-8
         puts 1
-      END
+      RUBY
 
-      expect(cop.offenses).to be_empty
+      expect(cop.offenses.empty?).to be(true)
     end
 
     it 'registers an offense for a frozen string literal comment ' \
       'below shebang and encoding comments' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # encoding: utf-8
         # frozen_string_literal: true
         puts 1
-      END
+      RUBY
 
       expect(cop.messages).to eq(['Unnecessary frozen string literal comment.'])
       expect(cop.highlights).to eq(['# frozen_string_literal: true'])
@@ -504,12 +502,12 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'registers an offense for a disabled frozen string literal comment ' \
       'below shebang and encoding comments' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # encoding: utf-8
         # frozen_string_literal: false
         puts 1
-      END
+      RUBY
 
       expect(cop.messages).to eq(['Unnecessary frozen string literal comment.'])
       expect(cop.highlights).to eq(['# frozen_string_literal: false'])
@@ -517,12 +515,12 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'registers an offense for a frozen string literal comment ' \
       'below shebang above an encoding comments' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # frozen_string_literal: true
         # encoding: utf-8
         puts 1
-      END
+      RUBY
 
       expect(cop.messages).to eq(['Unnecessary frozen string literal comment.'])
       expect(cop.highlights).to eq(['# frozen_string_literal: true'])
@@ -530,12 +528,12 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     it 'registers an offense for a disabled frozen string literal comment ' \
       'below shebang above an encoding comments' do
-      inspect_source(cop, <<-END.strip_indent)
+      inspect_source(<<-RUBY.strip_indent)
         #!/usr/bin/env ruby
         # frozen_string_literal: false
         # encoding: utf-8
         puts 1
-      END
+      RUBY
 
       expect(cop.messages).to eq(['Unnecessary frozen string literal comment.'])
       expect(cop.highlights).to eq(['# frozen_string_literal: false'])
@@ -543,141 +541,141 @@ describe RuboCop::Cop::Style::FrozenStringLiteralComment, :config do
 
     context 'auto-correct' do
       it 'removes the frozen string literal comment from the top line' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           # frozen_string_literal: true
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           puts 1
-        END
+        RUBY
       end
 
       it 'removes a disabled frozen string literal comment on the top line' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           # frozen_string_literal: false
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           puts 1
-        END
+        RUBY
       end
 
       it 'removes a frozen string literal comment below a shebang comment' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # frozen_string_literal: true
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           puts 1
-        END
+        RUBY
       end
 
       it 'removes a disabled frozen string literal below a shebang comment' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # frozen_string_literal: false
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           puts 1
-        END
+        RUBY
       end
 
       it 'removes a frozen string literal comment below an encoding comment' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           # encoding: utf-8
           # frozen_string_literal: true
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           # encoding: utf-8
           puts 1
-        END
+        RUBY
       end
 
       it 'removes a dsabled frozen string literal below an encoding comment' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           # encoding: utf-8
           # frozen_string_literal: false
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           # encoding: utf-8
           puts 1
-        END
+        RUBY
       end
 
       it 'removes a frozen string literal comment ' \
         'below shebang and encoding comments' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # encoding: utf-8
           # frozen_string_literal: true
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # encoding: utf-8
           puts 1
-        END
+        RUBY
       end
 
       it 'removes a disabled frozen string literal comment from ' \
         'below shebang and encoding comments' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # encoding: utf-8
           # frozen_string_literal: false
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # encoding: utf-8
           puts 1
-        END
+        RUBY
       end
 
       it 'removes a frozen string literal comment ' \
         'below shebang above an encoding comments' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # frozen_string_literal: true
           # encoding: utf-8
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # encoding: utf-8
           puts 1
-        END
+        RUBY
       end
 
       it 'removes a disabled frozen string literal comment ' \
         'below shebang above an encoding comments' do
-        new_source = autocorrect_source(cop, <<-END.strip_indent)
+        new_source = autocorrect_source(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # frozen_string_literal: false
           # encoding: utf-8
           puts 1
-        END
+        RUBY
 
-        expect(new_source).to eq(<<-END.strip_indent)
+        expect(new_source).to eq(<<-RUBY.strip_indent)
           #!/usr/bin/env ruby
           # encoding: utf-8
           puts 1
-        END
+        RUBY
       end
     end
   end
