@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Style::HashSyntax, :config do
+RSpec.describe RuboCop::Cop::Style::HashSyntax, :config do
   subject(:cop) { described_class.new(config) }
 
   context 'configured to enforce ruby19 style' do
@@ -27,14 +27,14 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
       let(:cop_config_overrides) { {} }
 
       it 'registers offense for hash rocket syntax when new is possible' do
-        inspect_source(cop, 'x = { :a => 0 }')
+        inspect_source('x = { :a => 0 }')
         expect(cop.messages).to eq(['Use the new Ruby 1.9 hash syntax.'])
         expect(cop.config_to_allow_offenses)
           .to eq('EnforcedStyle' => 'hash_rockets')
       end
 
       it 'registers an offense for mixed syntax when new is possible' do
-        inspect_source(cop, 'x = { :a => 0, b: 1 }')
+        inspect_source('x = { :a => 0, b: 1 }')
         expect(cop.messages).to eq(['Use the new Ruby 1.9 hash syntax.'])
         expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
       end
@@ -67,6 +67,11 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
                   ^^^^^^^^^^^^ Use the new Ruby 1.9 hash syntax.
           RUBY
         end
+
+        it 'preserves quotes during autocorrection' do
+          new_source = autocorrect_source("{ :'&&' => foo }")
+          expect(new_source).to eq("{ '&&': foo }")
+        end
       end
 
       context 'if PreferHashRocketsForNonAlnumEndingSymbols is false' do
@@ -125,16 +130,22 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
       end
 
       it 'auto-corrects old to new style' do
-        new_source = autocorrect_source(cop, '{ :a => 1, :b   =>  2}')
+        new_source = autocorrect_source('{ :a => 1, :b   =>  2}')
         expect(new_source).to eq('{ a: 1, b: 2}')
       end
 
       it 'auto-corrects even if it interferes with SpaceAroundOperators' do
         # Clobbering caused by two cops changing in the same range is dealt with
         # by the auto-correct loop, so there's no reason to avoid a change.
-        new_source = autocorrect_source(cop, '{ :a=>1, :b=>2 }')
+        new_source = autocorrect_source('{ :a=>1, :b=>2 }')
         expect(new_source).to eq('{ a: 1, b: 2 }')
       end
+
+      # Bug: https://github.com/bbatsov/rubocop/issues/5019
+      it 'auto-corrects a missing space when hash is used as argument' do
+        new_source = autocorrect_source('foo:bar => 1')
+        expect(new_source).to eq('foo bar: 1')
+      end
     end
 
     context 'with SpaceAroundOperators disabled' do
@@ -153,7 +164,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
       end
 
       it 'auto-corrects even if there is no space around =>' do
-        new_source = autocorrect_source(cop, '{ :a=>1, :b=>2 }')
+        new_source = autocorrect_source('{ :a=>1, :b=>2 }')
         expect(new_source).to eq('{ a: 1, b: 2 }')
       end
     end
@@ -173,8 +184,8 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
 
       it 'accepts ruby19 syntax when no elements have symbol values ' \
         'in method calls' do
-        inspect_source(cop, 'func(3, a: 0)')
-        expect(cop.messages).to be_empty
+        inspect_source('func(3, a: 0)')
+        expect(cop.messages.empty?).to be(true)
       end
 
       it 'accepts new syntax in method calls' do
@@ -195,13 +206,13 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
 
       it 'registers an offense when any element has a symbol value ' \
         'in method calls' do
-        inspect_source(cop, 'func(3, b: :c)')
+        inspect_source('func(3, b: :c)')
         expect(cop.messages).to eq(['Use hash rockets syntax.'])
       end
 
       it 'registers an offense when using hash rockets ' \
         'and no elements have a symbol value' do
-        inspect_source(cop, 'x = { :a => 1, :b => 2 }')
+        inspect_source('x = { :a => 1, :b => 2 }')
         expect(cop.messages)
           .to eq(['Use the new Ruby 1.9 hash syntax.',
                   'Use the new Ruby 1.9 hash syntax.'])
@@ -217,25 +228,25 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
       end
 
       it 'auto-corrects to ruby19 style when there are no symbol values' do
-        new_source = autocorrect_source(cop, '{ :a => 1, :b => 2 }')
+        new_source = autocorrect_source('{ :a => 1, :b => 2 }')
         expect(new_source).to eq('{ a: 1, b: 2 }')
       end
 
       it 'auto-corrects to hash rockets ' \
         'when there is an element with a symbol value' do
-        new_source = autocorrect_source(cop, '{ a: 1, :b => :c }')
+        new_source = autocorrect_source('{ a: 1, :b => :c }')
         expect(new_source).to eq('{ :a => 1, :b => :c }')
       end
 
       it 'auto-corrects to hash rockets ' \
         'when all elements have symbol value' do
-        new_source = autocorrect_source(cop, '{ a: :b, c: :d }')
+        new_source = autocorrect_source('{ a: :b, c: :d }')
         expect(new_source).to eq('{ :a => :b, :c => :d }')
       end
 
       it 'auto-correct does not change anything when the hash ' \
         'is already ruby19 style and there are no symbol values' do
-        new_source = autocorrect_source(cop, '{ a: 1, b: 2 }')
+        new_source = autocorrect_source('{ a: 1, b: 2 }')
         expect(new_source).to eq('{ a: 1, b: 2 }')
       end
     end
@@ -251,13 +262,13 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
     end
 
     it 'registers offense for Ruby 1.9 style' do
-      inspect_source(cop, 'x = { a: 0 }')
+      inspect_source('x = { a: 0 }')
       expect(cop.messages).to eq(['Use hash rockets syntax.'])
       expect(cop.config_to_allow_offenses).to eq('EnforcedStyle' => 'ruby19')
     end
 
     it 'registers an offense for mixed syntax' do
-      inspect_source(cop, 'x = { :a => 0, b: 1 }')
+      inspect_source('x = { :a => 0, b: 1 }')
       expect(cop.messages).to eq(['Use hash rockets syntax.'])
       expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
     end
@@ -282,7 +293,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
     end
 
     it 'auto-corrects new style to hash rockets' do
-      new_source = autocorrect_source(cop, '{ a: 1, b: 2}')
+      new_source = autocorrect_source('{ a: 1, b: 2}')
       expect(new_source).to eq('{ :a => 1, :b => 2}')
     end
 
@@ -315,14 +326,14 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
       end
 
       it 'registers offense for hash rocket syntax when new is possible' do
-        inspect_source(cop, 'x = { :a => 0 }')
+        inspect_source('x = { :a => 0 }')
         expect(cop.messages).to eq(['Use the new Ruby 1.9 hash syntax.'])
         expect(cop.config_to_allow_offenses)
           .to eq('EnforcedStyle' => 'hash_rockets')
       end
 
       it 'registers an offense for mixed syntax when new is possible' do
-        inspect_source(cop, 'x = { :a => 0, b: 1 }')
+        inspect_source('x = { :a => 0, b: 1 }')
         expect(cop.messages).to eq(['Use the new Ruby 1.9 hash syntax.'])
         expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
       end
@@ -347,7 +358,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
       end
 
       it 'registers an offense when keys have different types and styles' do
-        inspect_source(cop, 'x = { a: 0, "b" => 1 }')
+        inspect_source('x = { a: 0, "b" => 1 }')
         expect(cop.messages).to eq(["Don't mix styles in the same hash."])
         expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
       end
@@ -358,7 +369,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
         end
 
         it 'registers an offense when keys have whitespaces and mix styles' do
-          inspect_source(cop, 'x = { :"t o" => 0, b: 1 }')
+          inspect_source('x = { :"t o" => 0, b: 1 }')
           expect(cop.messages).to eq(["Don't mix styles in the same hash."])
           expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
         end
@@ -369,7 +380,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
 
         it 'registers an offense when keys have special symbols and '\
           'mix styles' do
-          inspect_source(cop, 'x = { :"\tab" => 1, b: 1 }')
+          inspect_source('x = { :"\tab" => 1, b: 1 }')
           expect(cop.messages).to eq(["Don't mix styles in the same hash."])
           expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
         end
@@ -379,7 +390,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
         end
 
         it 'registers an offense when keys start with a digit and mix styles' do
-          inspect_source(cop, 'x = { :"1" => 1, b: 1 }')
+          inspect_source('x = { :"1" => 1, b: 1 }')
           expect(cop.messages).to eq(["Don't mix styles in the same hash."])
           expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
         end
@@ -409,13 +420,13 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
       end
 
       it 'auto-corrects old to new style' do
-        new_source = autocorrect_source(cop, '{ :a => 1, :b => 2 }')
+        new_source = autocorrect_source('{ :a => 1, :b => 2 }')
         expect(new_source).to eq('{ a: 1, b: 2 }')
       end
 
       it 'auto-corrects to hash rockets when new style cannot be used ' \
         'for all' do
-        new_source = autocorrect_source(cop, '{ a: 1, "b" => 2 }')
+        new_source = autocorrect_source('{ a: 1, "b" => 2 }')
         expect(new_source).to eq('{ :a => 1, "b" => 2 }')
       end
     end
@@ -438,19 +449,19 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
 
       it 'registers an offense when any element has a symbol value ' \
         'in method calls' do
-        inspect_source(cop, 'func(3, b: :c)')
+        inspect_source('func(3, b: :c)')
         expect(cop.messages).to eq(['Use hash rockets syntax.'])
       end
 
       it 'auto-corrects to hash rockets ' \
         'when there is an element with a symbol value' do
-        new_source = autocorrect_source(cop, '{ a: 1, :b => :c }')
+        new_source = autocorrect_source('{ a: 1, :b => :c }')
         expect(new_source).to eq('{ :a => 1, :b => :c }')
       end
 
       it 'auto-corrects to hash rockets ' \
         'when all elements have symbol value' do
-        new_source = autocorrect_source(cop, '{ a: :b, c: :d }')
+        new_source = autocorrect_source('{ a: :b, c: :d }')
         expect(new_source).to eq('{ :a => :b, :c => :d }')
       end
 
@@ -459,14 +470,14 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
       end
 
       it 'registers offense for hash rocket syntax when new is possible' do
-        inspect_source(cop, 'x = { :a => 0 }')
+        inspect_source('x = { :a => 0 }')
         expect(cop.messages).to eq(['Use the new Ruby 1.9 hash syntax.'])
         expect(cop.config_to_allow_offenses)
           .to eq('EnforcedStyle' => 'hash_rockets')
       end
 
       it 'registers an offense for mixed syntax when new is possible' do
-        inspect_source(cop, 'x = { :a => 0, b: 1 }')
+        inspect_source('x = { :a => 0, b: 1 }')
         expect(cop.messages).to eq(['Use the new Ruby 1.9 hash syntax.'])
         expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
       end
@@ -491,7 +502,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
       end
 
       it 'registers an offense when keys have different types and styles' do
-        inspect_source(cop, 'x = { a: 0, "b" => 1 }')
+        inspect_source('x = { a: 0, "b" => 1 }')
         expect(cop.messages).to eq(["Don't mix styles in the same hash."])
         expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
       end
@@ -502,7 +513,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
         end
 
         it 'registers an offense when keys have whitespaces and mix styles' do
-          inspect_source(cop, 'x = { :"t o" => 0, b: 1 }')
+          inspect_source('x = { :"t o" => 0, b: 1 }')
           expect(cop.messages).to eq(["Don't mix styles in the same hash."])
           expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
         end
@@ -513,7 +524,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
 
         it 'registers an offense when keys have special symbols and ' \
           'mix styles' do
-          inspect_source(cop, 'x = { :"\tab" => 1, b: 1 }')
+          inspect_source('x = { :"\tab" => 1, b: 1 }')
           expect(cop.messages).to eq(["Don't mix styles in the same hash."])
           expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
         end
@@ -523,7 +534,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
         end
 
         it 'registers an offense when keys start with a digit and mix styles' do
-          inspect_source(cop, 'x = { :"1" => 1, b: 1 }')
+          inspect_source('x = { :"1" => 1, b: 1 }')
           expect(cop.messages).to eq(["Don't mix styles in the same hash."])
           expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
         end
@@ -553,13 +564,13 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
       end
 
       it 'auto-corrects old to new style' do
-        new_source = autocorrect_source(cop, '{ :a => 1, :b => 2 }')
+        new_source = autocorrect_source('{ :a => 1, :b => 2 }')
         expect(new_source).to eq('{ a: 1, b: 2 }')
       end
 
       it 'auto-corrects to hash rockets when new style cannot be used ' \
         'for all' do
-        new_source = autocorrect_source(cop, '{ a: 1, "b" => 2 }')
+        new_source = autocorrect_source('{ a: 1, "b" => 2 }')
         expect(new_source).to eq('{ :a => 1, "b" => 2 }')
       end
     end
@@ -581,7 +592,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
     end
 
     it 'registers an offense for mixed syntax when new is possible' do
-      inspect_source(cop, 'x = { :a => 0, b: 1 }')
+      inspect_source('x = { :a => 0, b: 1 }')
       expect(cop.messages).to eq(['Don\'t mix styles in the same hash.'])
       expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
     end
@@ -603,7 +614,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
     end
 
     it 'registers an offense when keys have different types and styles' do
-      inspect_source(cop, 'x = { a: 0, "b" => 1 }')
+      inspect_source('x = { a: 0, "b" => 1 }')
       expect(cop.messages).to eq(["Don't mix styles in the same hash."])
       expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
     end
@@ -613,7 +624,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
     end
 
     it 'registers an offense when keys have whitespaces and mix styles' do
-      inspect_source(cop, 'x = { :"t o" => 0, b: 1 }')
+      inspect_source('x = { :"t o" => 0, b: 1 }')
       expect(cop.messages).to eq(["Don't mix styles in the same hash."])
       expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
     end
@@ -624,7 +635,7 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
 
     it 'registers an offense when keys have special symbols and '\
       'mix styles' do
-      inspect_source(cop, 'x = { :"\tab" => 1, b: 1 }')
+      inspect_source('x = { :"\tab" => 1, b: 1 }')
       expect(cop.messages).to eq(["Don't mix styles in the same hash."])
       expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
     end
@@ -634,29 +645,29 @@ describe RuboCop::Cop::Style::HashSyntax, :config do
     end
 
     it 'registers an offense when keys start with a digit and mix styles' do
-      inspect_source(cop, 'x = { :"1" => 1, b: 1 }')
+      inspect_source('x = { :"1" => 1, b: 1 }')
       expect(cop.messages).to eq(["Don't mix styles in the same hash."])
       expect(cop.config_to_allow_offenses).to eq('Enabled' => false)
     end
 
     it 'does not auto-correct old to new style' do
-      new_source = autocorrect_source(cop, '{ :a => 1, :b => 2 }')
+      new_source = autocorrect_source('{ :a => 1, :b => 2 }')
       expect(new_source).to eq('{ :a => 1, :b => 2 }')
     end
 
     it 'does not auto-correct new to hash rockets style' do
-      new_source = autocorrect_source(cop, '{ a: 1, b: 2 }')
+      new_source = autocorrect_source('{ a: 1, b: 2 }')
       expect(new_source).to eq('{ a: 1, b: 2 }')
     end
 
     it 'auto-corrects mixed key hashes' do
-      new_source = autocorrect_source(cop, '{ a: 1, :b => 2 }')
+      new_source = autocorrect_source('{ a: 1, :b => 2 }')
       expect(new_source).to eq('{ a: 1, b: 2 }')
     end
 
     it 'auto-corrects to hash rockets when new style cannot be used ' \
       'for all' do
-      new_source = autocorrect_source(cop, '{ a: 1, "b" => 2 }')
+      new_source = autocorrect_source('{ a: 1, "b" => 2 }')
       expect(new_source).to eq('{ :a => 1, "b" => 2 }')
     end
   end
