@@ -1,13 +1,13 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Style::IfUnlessModifierOfIfUnless do
+RSpec.describe RuboCop::Cop::Style::IfUnlessModifierOfIfUnless do
   include StatementModifierHelper
 
   subject(:cop) { described_class.new }
 
   it 'provides a good error message' do
     source = 'condition ? then_part : else_part unless external_condition'
-    inspect_source(cop, source)
+    inspect_source(source)
     expect(cop.messages)
       .to eq(['Avoid modifier `unless` after another conditional.'])
   end
