@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Style::NilComparison do
+RSpec.describe RuboCop::Cop::Style::NilComparison do
   subject(:cop) { described_class.new }
 
   it 'registers an offense for == nil' do
@@ -18,12 +18,12 @@ describe RuboCop::Cop::Style::NilComparison do
   end
 
   it 'autocorrects by replacing == nil with .nil?' do
-    corrected = autocorrect_source(cop, 'x == nil')
+    corrected = autocorrect_source('x == nil')
     expect(corrected).to eq 'x.nil?'
   end
 
   it 'autocorrects by replacing === nil with .nil?' do
-    corrected = autocorrect_source(cop, 'x === nil')
+    corrected = autocorrect_source('x === nil')
     expect(corrected).to eq 'x.nil?'
   end
 end
