@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Style::Proc do
+RSpec.describe RuboCop::Cop::Style::Proc do
   subject(:cop) { described_class.new }
 
   it 'registers an offense for a Proc.new call' do
@@ -19,7 +19,7 @@ describe RuboCop::Cop::Style::Proc do
   end
 
   it 'auto-corrects Proc.new to proc' do
-    corrected = autocorrect_source(cop, ['Proc.new { test }'])
+    corrected = autocorrect_source(['Proc.new { test }'])
     expect(corrected).to eq 'proc { test }'
   end
 end
