@@ -6,10 +6,10 @@ RSpec.describe RuboCop::Cop::Style::StringMethods, :config do
   let(:cop_config) { { 'intern' => 'to_sym' } }
 
   let(:source) { "'something'.intern" }
-  let(:corrected) { autocorrect_source(cop, source) }
+  let(:corrected) { autocorrect_source(source) }
 
   it 'registers an offense' do
-    inspect_source(cop, source)
+    inspect_source(source)
 
     expect(cop.offenses.size).to eq(1)
     expect(cop.messages).to eq(['Prefer `to_sym` over `intern`.'])
