@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Style::StructInheritance do
+RSpec.describe RuboCop::Cop::Style::StructInheritance do
   subject(:cop) { described_class.new }
 
   it 'registers an offense when extending instance of Struct' do
@@ -20,17 +20,17 @@ describe RuboCop::Cop::Style::StructInheritance do
   end
 
   it 'accepts plain class' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       class Person
       end
-    END
+    RUBY
   end
 
   it 'accepts extending DelegateClass' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       class Person < DelegateClass(Animal)
       end
-    END
+    RUBY
   end
 
   it 'accepts assignment to Struct.new' do
