@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Style::SymbolLiteral do
+RSpec.describe RuboCop::Cop::Style::SymbolLiteral do
   subject(:cop) { described_class.new }
 
   it 'registers an offense for word-line symbols using string syntax' do
@@ -23,7 +23,7 @@ describe RuboCop::Cop::Style::SymbolLiteral do
   end
 
   it 'auto-corrects by removing quotes' do
-    new_source = autocorrect_source(cop, '{ :"ala" => 1, :"bala" => 2 }')
+    new_source = autocorrect_source('{ :"ala" => 1, :"bala" => 2 }')
     expect(new_source).to eq('{ :ala => 1, :bala => 2 }')
   end
 end
