@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-describe RuboCop::Cop::Style::WhenThen do
+RSpec.describe RuboCop::Cop::Style::WhenThen do
   subject(:cop) { described_class.new }
 
   it 'registers an offense for when x;' do
@@ -13,15 +13,15 @@ describe RuboCop::Cop::Style::WhenThen do
   end
 
   it 'accepts when x then' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       case a
       when b then c
       end
-    END
+    RUBY
   end
 
   it 'accepts ; separating statements in the body of when' do
-    expect_no_offenses(<<-END.strip_indent)
+    expect_no_offenses(<<-RUBY.strip_indent)
       case a
       when b then c; d
       end
@@ -30,30 +30,30 @@ describe RuboCop::Cop::Style::WhenThen do
       when f
         g; h
       end
-    END
+    RUBY
   end
 
   it 'auto-corrects "when x;" with "when x then"' do
-    new_source = autocorrect_source(cop, <<-END.strip_indent)
+    new_source = autocorrect_source(<<-RUBY.strip_indent)
       case a
       when b; c
       end
-    END
-    expect(new_source).to eq(<<-END.strip_indent)
+    RUBY
+    expect(new_source).to eq(<<-RUBY.strip_indent)
       case a
       when b then c
       end
-    END
+    RUBY
   end
 
   # Regression: https://github.com/bbatsov/rubocop/issues/3868
   context 'when inspecting a case statement with an empty branch' do
     it 'does not register an offense' do
-      expect_no_offenses(<<-END.strip_indent)
+      expect_no_offenses(<<-RUBY.strip_indent)
         case value
         when cond1
         end
-      END
+      RUBY
     end
   end
 end
