@@ -2,7 +2,7 @@
 
 require 'parser/current'
 
-describe RuboCop::NodePattern do
+RSpec.describe RuboCop::NodePattern do
   let(:root_node) do
     buffer = Parser::Source::Buffer.new('(string)', 1)
     buffer.source = ruby
@@ -22,7 +22,7 @@ describe RuboCop::NodePattern do
 
   shared_examples :nonmatching do
     it "doesn't match" do
-      expect(described_class.new(pattern).match(node, *params)).to be_nil
+      expect(described_class.new(pattern).match(node, *params).nil?).to be(true)
     end
   end
 
@@ -76,17 +76,21 @@ describe RuboCop::NodePattern do
 
     context 'on a node with the same type' do
       let(:ruby) { 'obj.method' }
+
       it_behaves_like :matching
     end
 
     context 'on a node with a different type' do
       let(:ruby) { '@ivar' }
+
       it_behaves_like :nonmatching
     end
 
     context 'on a node with a matching, hyphenated type' do
       let(:pattern) { 'op-asgn' }
-      let(:ruby) { 'a += 1' } # this is an (op-asgn ...) node
+      let(:ruby) { 'a += 1' }
+
+      # this is an (op-asgn ...) node
       it_behaves_like :matching
     end
   end
@@ -95,18 +99,65 @@ describe RuboCop::NodePattern do
     context 'negative integer literals' do
       let(:pattern) { '(int -100)' }
       let(:ruby) { '-100' }
+
       it_behaves_like :matching
     end
 
     context 'positive float literals' do
       let(:pattern) { '(float 1.0)' }
       let(:ruby) { '1.0' }
+
       it_behaves_like :matching
     end
 
     context 'negative float literals' do
       let(:pattern) { '(float -2.5)' }
       let(:ruby) { '-2.5' }
+
+      it_behaves_like :matching
+    end
+
+    context 'single quoted string literals' do
+      let(:pattern) { '(str "foo")' }
+      let(:ruby) { '"foo"' }
+
+      it_behaves_like :matching
+    end
+
+    context 'double quoted string literals' do
+      let(:pattern) { '(str "foo")' }
+      let(:ruby) { "'foo'" }
+
+      it_behaves_like :matching
+    end
+
+    context 'symbol literals' do
+      let(:pattern) { '(sym :foo)' }
+      let(:ruby) { ':foo' }
+
+      it_behaves_like :matching
+    end
+  end
+
+  describe 'nil' do
+    context 'nil literals' do
+      let(:pattern) { '(nil)' }
+      let(:ruby) { 'nil' }
+
+      it_behaves_like :matching
+    end
+
+    context 'nil value in AST' do
+      let(:pattern) { '(send nil :foo)' }
+      let(:ruby) { 'foo' }
+
+      it_behaves_like :nonmatching
+    end
+
+    context 'nil value in AST, use nil? method' do
+      let(:pattern) { '(send nil? :foo)' }
+      let(:ruby) { 'foo' }
+
       it_behaves_like :matching
     end
   end
@@ -116,22 +167,26 @@ describe RuboCop::NodePattern do
 
     context 'on a node with the same type and matching children' do
       let(:ruby) { '1 + 1' }
+
       it_behaves_like :matching
     end
 
     context 'on a node with a different type' do
       let(:ruby) { 'a = 1' }
+
       it_behaves_like :nonmatching
     end
 
     context 'on a node with the same type and non-matching children' do
       context 'with non-matching selector' do
         let(:ruby) { '1 - 1' }
+
         it_behaves_like :nonmatching
       end
 
       context 'with non-matching receiver type' do
         let(:ruby) { '1.0 + 1' }
+
         it_behaves_like :nonmatching
       end
     end
@@ -139,17 +194,20 @@ describe RuboCop::NodePattern do
     context 'on a node with too many children' do
       let(:pattern) { '(send int :blah int)' }
       let(:ruby) { '1.blah(1, 2)' }
+
       it_behaves_like :nonmatching
     end
 
     context 'with a nested sequence in head position' do
       let(:pattern) { '((send) int :blah)' }
+
       it_behaves_like :invalid
     end
 
     context 'with a nested sequence in non-head position' do
       let(:pattern) { '(send (send _ :a) :b)' }
       let(:ruby) { 'obj.a.b' }
+
       it_behaves_like :matching
     end
   end
@@ -159,17 +217,20 @@ describe RuboCop::NodePattern do
 
     context 'on a node with the same type and exact number of children' do
       let(:ruby) { '1.blah' }
+
       it_behaves_like :matching
     end
 
     context 'on a node with the same type and more children' do
       context 'with 1 child more' do
         let(:ruby) { '1.blah(1)' }
+
         it_behaves_like :matching
       end
 
       context 'with 2 children more' do
         let(:ruby) { '1.blah(1, :something)' }
+
         it_behaves_like :matching
       end
     end
@@ -177,22 +238,26 @@ describe RuboCop::NodePattern do
     context 'on a node with the same type and fewer children' do
       let(:pattern) { '(send int :blah int int ...)' }
       let(:ruby) { '1.blah(2)' }
+
       it_behaves_like :nonmatching
     end
 
     context 'on a node with fewer children, with a wildcard preceding' do
       let(:pattern) { '(hash _ ...)' }
       let(:ruby) { '{}' }
+
       it_behaves_like :nonmatching
     end
 
     context 'on a node with a different type' do
       let(:ruby) { 'A = 1' }
+
       it_behaves_like :nonmatching
     end
 
     context 'on a node with non-matching children' do
       let(:ruby) { '1.foo' }
+
       it_behaves_like :nonmatching
     end
   end
@@ -202,30 +267,35 @@ describe RuboCop::NodePattern do
       context 'at the root level' do
         let(:pattern) { '_' }
         let(:ruby) { 'class << self; def something; 1; end end.freeze' }
+
         it_behaves_like :matching
       end
 
       context 'within a sequence' do
         let(:pattern) { '(const _ _)' }
         let(:ruby) { 'Const' }
+
         it_behaves_like :matching
       end
 
       context 'within a sequence with other patterns intervening' do
         let(:pattern) { '(ivasgn _ (int _))' }
         let(:ruby) { '@abc = 22' }
+
         it_behaves_like :matching
       end
 
       context 'in head position of a sequence' do
         let(:pattern) { '(_ int ...)' }
         let(:ruby) { '1 + a' }
+
         it_behaves_like :matching
       end
 
       context 'negated' do
         let(:pattern) { '!_' }
         let(:ruby) { '123' }
+
         it_behaves_like :nonmatching
       end
     end
@@ -235,6 +305,7 @@ describe RuboCop::NodePattern do
       context 'at the root level' do
         let(:pattern) { '_node' }
         let(:ruby) { 'class << self; def something; 1; end end.freeze' }
+
         it_behaves_like :matching
       end
 
@@ -242,18 +313,21 @@ describe RuboCop::NodePattern do
         context 'with values which can be unified' do
           let(:pattern) { '(send _num :+ _num)' }
           let(:ruby) { '5 + 5' }
+
           it_behaves_like :matching
         end
 
         context 'with values which cannot be unified' do
           let(:pattern) { '(send _num :+ _num)' }
           let(:ruby) { '5 + 4' }
+
           it_behaves_like :nonmatching
         end
 
         context 'unifying the node type with an argument' do
           let(:pattern) { '(_type _ _type)' }
           let(:ruby) { 'obj.send' }
+
           it_behaves_like :matching
         end
       end
@@ -261,12 +335,14 @@ describe RuboCop::NodePattern do
       context 'within a sequence with other patterns intervening' do
         let(:pattern) { '(ivasgn _ivar (int _val))' }
         let(:ruby) { '@abc = 22' }
+
         it_behaves_like :matching
       end
 
       context 'in head position of a sequence' do
         let(:pattern) { '(_type int ...)' }
         let(:ruby) { '1 + a' }
+
         it_behaves_like :matching
       end
     end
@@ -278,19 +354,29 @@ describe RuboCop::NodePattern do
         context 'when the AST has a matching symbol' do
           let(:pattern) { '(send _ {:a :b})' }
           let(:ruby) { 'obj.b' }
+
           it_behaves_like :matching
         end
 
         context 'when the AST does not have a matching symbol' do
           let(:pattern) { '(send _ {:a :b})' }
           let(:ruby) { 'obj.c' }
+
           it_behaves_like :nonmatching
         end
       end
 
+      context 'containing string literals' do
+        let(:pattern) { '(send (str {"a" "b"}) :upcase)' }
+        let(:ruby) { '"a".upcase' }
+
+        it_behaves_like :matching
+      end
+
       context 'containing integer literals' do
         let(:pattern) { '(send (int {1 10}) :abs)' }
         let(:ruby) { '10.abs' }
+
         it_behaves_like :matching
       end
 
@@ -299,16 +385,19 @@ describe RuboCop::NodePattern do
 
         context 'on a node which meets all requirements of the first []' do
           let(:ruby) { '3' }
+
           it_behaves_like :matching
         end
 
         context 'on a node which meets all requirements of the second []' do
           let(:ruby) { '2.2' }
+
           it_behaves_like :matching
         end
 
         context 'on a node which meets some requirements but not all' do
           let(:ruby) { '2' }
+
           it_behaves_like :nonmatching
         end
       end
@@ -317,12 +406,14 @@ describe RuboCop::NodePattern do
     context 'nested inside a sequence' do
       let(:pattern) { '(send {const int} ...)' }
       let(:ruby) { 'Const.method' }
+
       it_behaves_like :matching
     end
 
     context 'with a nested sequence' do
       let(:pattern) { '{(send int ...) (send const ...)}' }
       let(:ruby) { 'Const.method' }
+
       it_behaves_like :matching
     end
   end
@@ -332,6 +423,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '$_' }
       let(:ruby) { 'begin; raise StandardError; rescue Exception => e; end' }
       let(:captured_val) { node }
+
       it_behaves_like :single_capture
     end
 
@@ -339,6 +431,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '($_ ...)' }
       let(:ruby) { 'A.method' }
       let(:captured_val) { :send }
+
       it_behaves_like :single_capture
     end
 
@@ -346,13 +439,15 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $_ ...)' }
       let(:ruby) { 'A.method' }
       let(:captured_val) { s(:const, nil, :A) }
+
       it_behaves_like :single_capture
     end
 
     context 'in a nested sequence' do
-      let(:pattern) { '(send (const nil $_) ...)' }
+      let(:pattern) { '(send (const nil? $_) ...)' }
       let(:ruby) { 'A.method' }
       let(:captured_val) { :A }
+
       it_behaves_like :single_capture
     end
   end
@@ -362,6 +457,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $(send _ :keys) :each)' }
       let(:ruby) { '{}.keys.each' }
       let(:captured_val) { s(:send, s(:hash), :keys) }
+
       it_behaves_like :single_capture
     end
 
@@ -369,6 +465,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send _ ${:inc :dec})' }
       let(:ruby) { '1.dec' }
       let(:captured_val) { :dec }
+
       it_behaves_like :single_capture
     end
 
@@ -376,6 +473,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send (int $[!odd? !zero?]) :inc)' }
       let(:ruby) { '2.inc' }
       let(:captured_val) { 2 }
+
       it_behaves_like :single_capture
     end
 
@@ -383,6 +481,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $int :inc)' }
       let(:ruby) { '5.inc' }
       let(:captured_val) { s(:int, 5) }
+
       it_behaves_like :single_capture
     end
 
@@ -390,6 +489,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send int $:inc)' }
       let(:ruby) { '5.inc' }
       let(:captured_val) { :inc }
+
       it_behaves_like :single_capture
     end
 
@@ -397,6 +497,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $(int $_) :inc)' }
       let(:ruby) { '5.inc' }
       let(:captured_vals) { [s(:int, 5), 5] }
+
       it_behaves_like :multiple_capture
     end
   end
@@ -406,6 +507,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $...)' }
       let(:ruby) { '5.inc' }
       let(:captured_val) { [s(:int, 5), :inc] }
+
       it_behaves_like :single_capture
     end
 
@@ -413,6 +515,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $... int)' }
       let(:ruby) { '5 + 4' }
       let(:captured_val) { [s(:int, 5), :+] }
+
       it_behaves_like :single_capture
     end
 
@@ -420,6 +523,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $... (int 4))' }
       let(:ruby) { '5 + 4' }
       let(:captured_val) { [s(:int, 5), :+] }
+
       it_behaves_like :single_capture
     end
 
@@ -427,6 +531,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $... {int float})' }
       let(:ruby) { '5 + 4' }
       let(:captured_val) { [s(:int, 5), :+] }
+
       it_behaves_like :single_capture
     end
 
@@ -434,6 +539,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $... [(int even?) (int zero?)])' }
       let(:ruby) { '5 + 0' }
       let(:captured_val) { [s(:int, 5), :+] }
+
       it_behaves_like :single_capture
     end
 
@@ -441,6 +547,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $... :inc)' }
       let(:ruby) { '5.inc' }
       let(:captured_val) { [s(:int, 5)] }
+
       it_behaves_like :single_capture
     end
 
@@ -448,6 +555,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $... _)' }
       let(:ruby) { '5.inc' }
       let(:captured_val) { [s(:int, 5)] }
+
       it_behaves_like :single_capture
     end
 
@@ -455,6 +563,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send $... $_)' }
       let(:ruby) { '5 + 4' }
       let(:captured_vals) { [[s(:int, 5), :+], s(:int, 4)] }
+
       it_behaves_like :multiple_capture
     end
 
@@ -462,6 +571,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '($... (int 1))' }
       let(:ruby) { '10 * 1' }
       let(:captured_val) { [s(:int, 10), :*] }
+
       it_behaves_like :single_capture
     end
   end
@@ -471,6 +581,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '{$send $int $float}' }
       let(:ruby) { '2.0' }
       let(:captured_val) { s(:float, 2.0) }
+
       it_behaves_like :single_capture
     end
 
@@ -478,6 +589,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '{(send $_ $_) (const $_ $_)}' }
       let(:ruby) { 'Namespace::CONST' }
       let(:captured_vals) { [s(:const, nil, :Namespace), :CONST] }
+
       it_behaves_like :multiple_capture
     end
 
@@ -488,11 +600,13 @@ describe RuboCop::NodePattern do
       end
       let(:ruby) { '10.object_id' }
       let(:captured_vals) { [:int, 10] }
+
       it_behaves_like :multiple_capture
     end
 
     context 'with a different number of captures in each branch' do
       let(:pattern) { '{(send $...) (int $...) (send $_ $_)}' }
+
       it_behaves_like :invalid
     end
   end
@@ -503,30 +617,51 @@ describe RuboCop::NodePattern do
 
       context 'with a matching symbol' do
         let(:ruby) { 'obj.abc' }
+
         it_behaves_like :nonmatching
       end
 
       context 'with a non-matching symbol' do
         let(:ruby) { 'obj.xyz' }
+
         it_behaves_like :matching
       end
 
       context 'with a non-matching symbol, but too many children' do
         let(:ruby) { 'obj.xyz(1)' }
+
         it_behaves_like :nonmatching
       end
     end
 
+    context 'on a string' do
+      let(:pattern) { '(send (str !"foo") :upcase)' }
+
+      context 'with a matching string' do
+        let(:ruby) { '"foo".upcase' }
+
+        it_behaves_like :nonmatching
+      end
+
+      context 'with a non-matching symbol' do
+        let(:ruby) { '"bar".upcase' }
+
+        it_behaves_like :matching
+      end
+    end
+
     context 'on a set' do
       let(:pattern) { '(ivasgn _ !(int {1 2}))' }
 
       context 'with a matching value' do
         let(:ruby) { '@a = 1' }
+
         it_behaves_like :nonmatching
       end
 
       context 'with a non-matching value' do
         let(:ruby) { '@a = 3' }
+
         it_behaves_like :matching
       end
     end
@@ -536,16 +671,19 @@ describe RuboCop::NodePattern do
 
       context 'with a matching node' do
         let(:ruby) { '@a = 1' }
+
         it_behaves_like :nonmatching
       end
 
       context 'with a node of different type' do
         let(:ruby) { '@@a = 1' }
+
         it_behaves_like :matching
       end
 
       context 'with a node with non-matching children' do
         let(:ruby) { '@b = 1' }
+
         it_behaves_like :matching
       end
     end
@@ -555,11 +693,13 @@ describe RuboCop::NodePattern do
 
       context 'with a node which meets all requirements of []' do
         let(:ruby) { '"abc"' }
+
         it_behaves_like :nonmatching
       end
 
       context 'with a node which meets only 1 requirement of []' do
         let(:ruby) { '1' }
+
         it_behaves_like :matching
       end
     end
@@ -569,16 +709,19 @@ describe RuboCop::NodePattern do
 
       context 'with (send str :+ (send str :to_i))' do
         let(:ruby) { '"abc" + "1".to_i' }
+
         it_behaves_like :matching
       end
 
       context 'with (send int :- int)' do
         let(:ruby) { '1 - 1' }
+
         it_behaves_like :matching
       end
 
       context 'with (send str :<< str)' do
         let(:ruby) { '"abc" << "xyz"' }
+
         it_behaves_like :nonmatching
       end
     end
@@ -589,42 +732,49 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send array :push ... $_)' }
       let(:ruby) { '[1].push(2, 3, 4)' }
       let(:captured_val) { s(:int, 4) }
+
       it_behaves_like :single_capture
     end
 
     context 'with a wildcard at the end, but no remaining child to match it' do
       let(:pattern) { '(send array :zip array ... _)' }
       let(:ruby) { '[1,2].zip([3,4])' }
+
       it_behaves_like :nonmatching
     end
 
     context 'with a nodetype at the end, but no remaining child to match it' do
       let(:pattern) { '(send array :zip array ... array)' }
       let(:ruby) { '[1,2].zip([3,4])' }
+
       it_behaves_like :nonmatching
     end
 
     context 'with a nested sequence at the end, but no remaining child' do
       let(:pattern) { '(send array :zip array ... (array ...))' }
       let(:ruby) { '[1,2].zip([3,4])' }
+
       it_behaves_like :nonmatching
     end
 
     context 'with a set at the end, but no remaining child to match it' do
       let(:pattern) { '(send array :zip array ... {array})' }
       let(:ruby) { '[1,2].zip([3,4])' }
+
       it_behaves_like :nonmatching
     end
 
     context 'with [] at the end, but no remaining child to match it' do
       let(:pattern) { '(send array :zip array ... [array !nil])' }
       let(:ruby) { '[1,2].zip([3,4])' }
+
       it_behaves_like :nonmatching
     end
 
     context 'at the very beginning of a sequence' do
       let(:pattern) { '(... (int 1))' }
       let(:ruby) { '10 * 1' }
+
       it_behaves_like :matching
     end
   end
@@ -633,6 +783,7 @@ describe RuboCop::NodePattern do
     context 'in root position' do
       let(:pattern) { 'send_type?' }
       let(:ruby) { '1.inc' }
+
       it_behaves_like :matching
     end
 
@@ -640,18 +791,21 @@ describe RuboCop::NodePattern do
       # called on the type symbol
       let(:pattern) { '(!nil? int ...)' }
       let(:ruby) { '1.inc' }
+
       it_behaves_like :matching
     end
 
     context 'applied to an integer for which the predicate is true' do
       let(:pattern) { '(send (int odd?) :inc)' }
       let(:ruby) { '1.inc' }
+
       it_behaves_like :matching
     end
 
     context 'applied to an integer for which the predicate is false' do
       let(:pattern) { '(send (int odd?) :inc)' }
       let(:ruby) { '2.inc' }
+
       it_behaves_like :nonmatching
     end
 
@@ -659,12 +813,14 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send (int $odd?) :inc)' }
       let(:ruby) { '1.inc' }
       let(:captured_val) { 1 }
+
       it_behaves_like :single_capture
     end
 
     context 'when negated' do
       let(:pattern) { '(send int !nil?)' }
       let(:ruby) { '1.inc' }
+
       it_behaves_like :matching
     end
 
@@ -672,6 +828,7 @@ describe RuboCop::NodePattern do
             'been matched' do
       let(:pattern) { '(send int :inc ... !nil?)' }
       let(:ruby) { '1.inc' }
+
       it_behaves_like :nonmatching
     end
 
@@ -681,11 +838,13 @@ describe RuboCop::NodePattern do
 
       context 'for which the predicate is true' do
         let(:params) { [1] }
+
         it_behaves_like :matching
       end
 
       context 'for which the predicate is false' do
         let(:params) { [2] }
+
         it_behaves_like :nonmatching
       end
     end
@@ -696,6 +855,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '%1' }
       let(:params) { [s(:int, 10)] }
       let(:ruby) { '10' }
+
       it_behaves_like :matching
     end
 
@@ -703,6 +863,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send (send _ %2) %1)' }
       let(:params) { %i[inc dec] }
       let(:ruby) { '5.dec.inc' }
+
       it_behaves_like :matching
     end
 
@@ -710,6 +871,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(send ... %1)' }
       let(:params) { [s(:int, 10)] }
       let(:ruby) { '1 + 10' }
+
       it_behaves_like :matching
     end
 
@@ -718,6 +880,7 @@ describe RuboCop::NodePattern do
       let(:params) { [s(:int, 10)] }
       let(:ruby) { '1 + 10' }
       let(:captured_val) { [s(:int, 1), :+] }
+
       it_behaves_like :single_capture
     end
 
@@ -726,6 +889,7 @@ describe RuboCop::NodePattern do
       let(:params) { [:A] }
       let(:ruby) { 'Namespace::A' }
       let(:captured_val) { :A }
+
       it_behaves_like :single_capture
     end
 
@@ -733,6 +897,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(const _ !%1)' }
       let(:params) { [:A] }
       let(:ruby) { 'Namespace::A' }
+
       it_behaves_like :nonmatching
     end
 
@@ -740,6 +905,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(const _ !%1)' }
       let(:params) { [:A] }
       let(:ruby) { 'Namespace::B' }
+
       it_behaves_like :matching
     end
 
@@ -747,6 +913,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(const %2 %)' }
       let(:params) { [:A, s(:const, nil, :Namespace)] }
       let(:ruby) { 'Namespace::A' }
+
       it_behaves_like :matching
     end
 
@@ -754,6 +921,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '{str (int %)}' }
       let(:params) { [10] }
       let(:ruby) { '10' }
+
       it_behaves_like :matching
     end
 
@@ -761,6 +929,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '{str (int %)}' }
       let(:params) { [10] }
       let(:ruby) { '1.0' }
+
       it_behaves_like :nonmatching
     end
 
@@ -768,6 +937,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '(int [!%1 %2 !zero?])' }
       let(:params) { [10, 20] }
       let(:ruby) { '20' }
+
       it_behaves_like :matching
     end
 
@@ -778,11 +948,13 @@ describe RuboCop::NodePattern do
 
       context 'in a position which matches original target node' do
         let(:node) { root_node.children[0] }
+
         it_behaves_like :matching
       end
 
       context 'in a position which does not match original target node' do
         let(:node) { root_node.children[2] }
+
         it_behaves_like :nonmatching
       end
     end
@@ -795,11 +967,13 @@ describe RuboCop::NodePattern do
 
       context 'which matches' do
         let(:pattern) { '^send' }
+
         it_behaves_like :matching
       end
 
       context "which doesn't match" do
         let(:pattern) { '^const' }
+
         it_behaves_like :nonmatching
       end
     end
@@ -809,6 +983,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '^^block' }
       let(:ruby) { '1.inc { something }' }
       let(:node) { root_node.children[0].children[0] }
+
       it_behaves_like :matching
     end
 
@@ -816,6 +991,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '^[!nil send ^(block ...)]' }
       let(:ruby) { '1.inc { something }' }
       let(:node) { root_node.children[0].children[0] }
+
       it_behaves_like :matching
     end
 
@@ -823,6 +999,7 @@ describe RuboCop::NodePattern do
       let(:pattern) { '{^send ^^send}' }
       let(:ruby) { '"str".concat(local += "abc")' }
       let(:node) { root_node.children[2].children[2] }
+
       it_behaves_like :matching
     end
 
@@ -835,11 +1012,13 @@ describe RuboCop::NodePattern do
 
       context 'with self in the right position' do
         let(:node) { root_node.children[2] }
+
         it_behaves_like :matching
       end
 
       context 'with self in the wrong position' do
         let(:node) { root_node.children[0] }
+
         it_behaves_like :nonmatching
       end
     end
@@ -869,62 +1048,72 @@ describe RuboCop::NodePattern do
     context 'without extra arguments' do
       let(:pattern) { '(lvasgn #goodmatch ...)' }
       let(:ruby) { 'a = 1' }
+
       it_behaves_like :matching
     end
   end
 
   describe 'commas' do
-    # commas are just whitespace
     context 'with commas randomly strewn around' do
       let(:pattern) { ',,(,send,, ,int,:+, int ), ' }
       let(:ruby) { '1 + 2' }
-      it_behaves_like :matching
+
+      it_behaves_like :invalid
     end
   end
 
   describe 'bad syntax' do
     context 'with empty parentheses' do
       let(:pattern) { '()' }
+
       it_behaves_like :invalid
     end
 
     context 'with unmatched opening paren' do
       let(:pattern) { '(send (const)' }
+
       it_behaves_like :invalid
     end
 
     context 'with unmatched closing paren' do
       let(:pattern) { '(send (const)))' }
+
       it_behaves_like :invalid
     end
 
     context 'with unmatched opening curly' do
       let(:pattern) { '{send const' }
+
       it_behaves_like :invalid
     end
 
     context 'with unmatched closing curly' do
       let(:pattern) { '{send const}}' }
+
       it_behaves_like :invalid
     end
 
     context 'with negated closing paren' do
       let(:pattern) { '(send (const) !)' }
+
       it_behaves_like :invalid
     end
 
     context 'with negated closing curly' do
       let(:pattern) { '{send const !}' }
+
       it_behaves_like :invalid
     end
 
     context 'with negated ellipsis' do
       let(:pattern) { '(send !...)' }
+
       it_behaves_like :invalid
     end
 
     context 'with doubled ellipsis' do
       let(:pattern) { '(send ... ...)' }
+
       it_behaves_like :invalid
     end
   end
