@@ -1,8 +1,9 @@
 # frozen_string_literal: true
 
-describe RuboCop::Token do
+RSpec.describe RuboCop::Token do
   describe '.from_parser_token' do
     subject(:token) { described_class.from_parser_token(parser_token) }
+
     let(:parser_token) { [type, [text, range]] }
     let(:type) { :kDEF }
     let(:text) { 'def' }
