@@ -1,6 +1,8 @@
 # frozen_string_literal: true
 
-if ENV['TRAVIS'] || ENV['COVERAGE']
+on_master = ENV['TRAVIS_BRANCH'] == 'master' &&
+            ENV['TRAVIS_PULL_REQUEST'] == 'false'
+if on_master || ENV['COVERAGE']
   require 'simplecov'
   SimpleCov.add_filter '/spec/'
   SimpleCov.add_filter '/vendor/bundle/'
