@@ -2,31 +2,31 @@
 
 module StatementModifierHelper
   def check_empty(cop, keyword)
-    inspect_source(cop, <<-END.strip_indent)
+    inspect_source(<<-RUBY.strip_indent)
       #{keyword} cond
       end
-    END
-    expect(cop.offenses).to be_empty
+    RUBY
+    expect(cop.offenses.empty?).to be(true)
   end
 
   def check_really_short(cop, keyword)
-    inspect_source(cop, <<-END.strip_indent)
+    inspect_source(<<-RUBY.strip_indent)
       #{keyword} a
         b
       end
-    END
+    RUBY
     expect(cop.messages).to eq(
       ["Favor modifier `#{keyword}` usage when having a single-line body."]
     )
     expect(cop.offenses.map { |o| o.location.source }).to eq([keyword])
   end
 
-  def autocorrect_really_short(cop, keyword)
-    corrected = autocorrect_source(cop, <<-END.strip_indent)
+  def autocorrect_really_short(keyword)
+    corrected = autocorrect_source(<<-RUBY.strip_indent)
       #{keyword} a
         b
       end
-    END
+    RUBY
     expect(corrected).to eq "b #{keyword} a\n"
   end
 
@@ -36,22 +36,22 @@ module StatementModifierHelper
     body = 'b' * 37
     expect("  #{body} #{keyword} #{condition}".length).to eq(81)
 
-    inspect_source(cop, <<-END.strip_margin('|'))
+    inspect_source(<<-RUBY.strip_margin('|'))
       |  #{keyword} #{condition}
       |    #{body}
       |  end
-    END
+    RUBY
 
-    expect(cop.offenses).to be_empty
+    expect(cop.offenses.empty?).to be(true)
   end
 
   def check_short_multiline(cop, keyword)
-    inspect_source(cop, <<-END.strip_indent)
+    inspect_source(<<-RUBY.strip_indent)
       #{keyword} ENV['COVERAGE']
         require 'simplecov'
         SimpleCov.start
       end
-    END
-    expect(cop.messages).to be_empty
+    RUBY
+    expect(cop.messages.empty?).to be(true)
   end
 end
